// Code generated by smithy-go-codegen DO NOT EDIT.

package datazone

import (
	"context"
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/datazone/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
	"time"
)

// Starts the metadata generation run.
//
// Prerequisites:
//
//   - Asset must be created and belong to the specified domain and project.
//
//   - Asset type must be supported for metadata generation (e.g., Amazon Web
//     Services Glue table).
//
//   - Asset must have a structured schema with valid rows and columns.
//
//   - Valid values for --type: BUSINESS_DESCRIPTIONS, BUSINESS_NAMES,
//     BUSINESS_GLOSSARY_ASSOCIATIONS.
//
//   - The user must have permission to run metadata generation in the
//     domain/project.
func (c *Client) StartMetadataGenerationRun(ctx context.Context, params *StartMetadataGenerationRunInput, optFns ...func(*Options)) (*StartMetadataGenerationRunOutput, error) {
	if params == nil {
		params = &StartMetadataGenerationRunInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "StartMetadataGenerationRun", params, optFns, c.addOperationStartMetadataGenerationRunMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*StartMetadataGenerationRunOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type StartMetadataGenerationRunInput struct {

	// The ID of the Amazon DataZone domain where you want to start a metadata
	// generation run.
	//
	// This member is required.
	DomainIdentifier *string

	// The ID of the project that owns the asset for which you want to start a
	// metadata generation run.
	//
	// This member is required.
	OwningProjectIdentifier *string

	// The asset for which you want to start a metadata generation run.
	//
	// This member is required.
	Target *types.MetadataGenerationRunTarget

	// A unique, case-sensitive identifier to ensure idempotency of the request. This
	// field is automatically populated if not provided.
	ClientToken *string

	// The type of the metadata generation run.
	//
	// Deprecated: This field is going to be deprecated, please use the 'types' field
	// to provide the MetadataGenerationRun types
	Type types.MetadataGenerationRunType

	// The types of the metadata generation run.
	Types []types.MetadataGenerationRunType

	noSmithyDocumentSerde
}

type StartMetadataGenerationRunOutput struct {

	// The ID of the Amazon DataZone domain in which the metadata generation run was
	// started.
	//
	// This member is required.
	DomainId *string

	// The ID of the metadata generation run.
	//
	// This member is required.
	Id *string

	// The timestamp at which the metadata generation run was started.
	CreatedAt *time.Time

	// The ID of the user who started the metadata generation run.
	CreatedBy *string

	// The ID of the project that owns the asset for which the metadata generation run
	// was started.
	OwningProjectId *string

	// The status of the metadata generation run.
	Status types.MetadataGenerationRunStatus

	// The type of the metadata generation run.
	//
	// Deprecated: This field is going to be deprecated, please use the 'types' field
	// to provide the MetadataGenerationRun types
	Type types.MetadataGenerationRunType

	// The types of the metadata generation run.
	Types []types.MetadataGenerationRunType

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationStartMetadataGenerationRunMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpStartMetadataGenerationRun{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpStartMetadataGenerationRun{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addIdempotencyToken_opStartMetadataGenerationRunMiddleware(stack, options); err != nil {
		return err
	}
	if err = addOpStartMetadataGenerationRunValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "StartMetadataGenerationRun"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}

type idempotencyToken_initializeOpStartMetadataGenerationRun struct {
	tokenProvider IdempotencyTokenProvider
}

func (*idempotencyToken_initializeOpStartMetadataGenerationRun) ID() string {
	return "OperationIdempotencyTokenAutoFill"
}

func (m *idempotencyToken_initializeOpStartMetadataGenerationRun) HandleInitialize(ctx context.Context, in middleware.InitializeInput, next middleware.InitializeHandler) (
	out middleware.InitializeOutput, metadata middleware.Metadata, err error,
) {
	if m.tokenProvider == nil {
		return next.HandleInitialize(ctx, in)
	}

	input, ok := in.Parameters.(*StartMetadataGenerationRunInput)
	if !ok {
		return out, metadata, fmt.Errorf("expected middleware input to be of type *StartMetadataGenerationRunInput ")
	}

	if input.ClientToken == nil {
		t, err := m.tokenProvider.GetIdempotencyToken()
		if err != nil {
			return out, metadata, err
		}
		input.ClientToken = &t
	}
	return next.HandleInitialize(ctx, in)
}
func addIdempotencyToken_opStartMetadataGenerationRunMiddleware(stack *middleware.Stack, cfg Options) error {
	return stack.Initialize.Add(&idempotencyToken_initializeOpStartMetadataGenerationRun{tokenProvider: cfg.IdempotencyTokenProvider}, middleware.Before)
}
