// Code generated by smithy-go-codegen DO NOT EDIT.

package ec2

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/ec2/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Describes the Outposts link aggregation groups (LAGs).
//
// LAGs are only available for second-generation Outposts racks at this time.
func (c *Client) DescribeOutpostLags(ctx context.Context, params *DescribeOutpostLagsInput, optFns ...func(*Options)) (*DescribeOutpostLagsOutput, error) {
	if params == nil {
		params = &DescribeOutpostLagsInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DescribeOutpostLags", params, optFns, c.addOperationDescribeOutpostLagsMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DescribeOutpostLagsOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DescribeOutpostLagsInput struct {

	// Checks whether you have the required permissions for the action, without
	// actually making the request, and provides an error response. If you have the
	// required permissions, the error response is DryRunOperation . Otherwise, it is
	// UnauthorizedOperation .
	DryRun *bool

	// The filters to use for narrowing down the request. The following filters are
	// supported:
	//
	//   - service-link-virtual-interface-id - The ID of the service link virtual
	//   interface.
	//
	//   - service-link-virtual-interface-arn - The ARN of the service link virtual
	//   interface.
	//
	//   - outpost-id - The Outpost ID.
	//
	//   - outpost-arn - The Outpost ARN.
	//
	//   - owner-id - The ID of the Amazon Web Services account that owns the service
	//   link virtual interface.
	//
	//   - vlan - The ID of the address pool.
	//
	//   - local-address - The local address.
	//
	//   - peer-address - The peer address.
	//
	//   - peer-bgp-asn - The peer BGP ASN.
	//
	//   - outpost-lag-id - The Outpost LAG ID.
	//
	//   - configuration-state - The configuration state of the service link virtual
	//   interface.
	Filters []types.Filter

	// The maximum number of results to return with a single call. To retrieve the
	// remaining results, make another call with the returned nextToken value.
	MaxResults *int32

	// The token for the next page of results.
	NextToken *string

	// The IDs of the Outpost LAGs.
	OutpostLagIds []string

	noSmithyDocumentSerde
}

type DescribeOutpostLagsOutput struct {

	// The token to use to retrieve the next page of results. This value is null when
	// there are no more results to return.
	NextToken *string

	// The Outpost LAGs.
	OutpostLags []types.OutpostLag

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDescribeOutpostLagsMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsEc2query_serializeOpDescribeOutpostLags{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsEc2query_deserializeOpDescribeOutpostLags{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DescribeOutpostLags"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
