// Code generated by smithy-go-codegen DO NOT EDIT.

package costexplorer

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/costexplorer/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Specifies the parameters of a planned commitment purchase and starts the
// generation of the analysis. This enables you to estimate the cost, coverage, and
// utilization impact of your planned commitment purchases.
func (c *Client) StartCommitmentPurchaseAnalysis(ctx context.Context, params *StartCommitmentPurchaseAnalysisInput, optFns ...func(*Options)) (*StartCommitmentPurchaseAnalysisOutput, error) {
	if params == nil {
		params = &StartCommitmentPurchaseAnalysisInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "StartCommitmentPurchaseAnalysis", params, optFns, c.addOperationStartCommitmentPurchaseAnalysisMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*StartCommitmentPurchaseAnalysisOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type StartCommitmentPurchaseAnalysisInput struct {

	// The configuration for the commitment purchase analysis.
	//
	// This member is required.
	CommitmentPurchaseAnalysisConfiguration *types.CommitmentPurchaseAnalysisConfiguration

	noSmithyDocumentSerde
}

type StartCommitmentPurchaseAnalysisOutput struct {

	// The analysis ID that's associated with the commitment purchase analysis.
	//
	// This member is required.
	AnalysisId *string

	// The start time of the analysis.
	//
	// This member is required.
	AnalysisStartedTime *string

	// The estimated time for when the analysis will complete.
	//
	// This member is required.
	EstimatedCompletionTime *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationStartCommitmentPurchaseAnalysisMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson11_serializeOpStartCommitmentPurchaseAnalysis{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson11_deserializeOpStartCommitmentPurchaseAnalysis{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpStartCommitmentPurchaseAnalysisValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "StartCommitmentPurchaseAnalysis"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
