// Code generated by smithy-go-codegen DO NOT EDIT.

package connect

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/connect/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Describe email address form the specified Connect Customer instance.
func (c *Client) DescribeEmailAddress(ctx context.Context, params *DescribeEmailAddressInput, optFns ...func(*Options)) (*DescribeEmailAddressOutput, error) {
	if params == nil {
		params = &DescribeEmailAddressInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DescribeEmailAddress", params, optFns, c.addOperationDescribeEmailAddressMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DescribeEmailAddressOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DescribeEmailAddressInput struct {

	// The identifier of the email address.
	//
	// This member is required.
	EmailAddressId *string

	// The identifier of the Connect Customer instance. You can [find the instance ID] in the Amazon
	// Resource Name (ARN) of the instance.
	//
	// [find the instance ID]: https://docs.aws.amazon.com/connect/latest/adminguide/find-instance-arn.html
	//
	// This member is required.
	InstanceId *string

	noSmithyDocumentSerde
}

type DescribeEmailAddressOutput struct {

	// A list of alias configurations associated with this email address. Contains
	// details about email addresses that forward to this primary email address. The
	// list can contain at most one alias configuration per email address.
	AliasConfigurations []types.AliasConfiguration

	// The email address creation timestamp in ISO 8601 Datetime.
	CreateTimestamp *string

	// The description of the email address.
	Description *string

	// The display name of email address
	DisplayName *string

	// The email address, including the domain.
	EmailAddress *string

	// The Amazon Resource Name (ARN) of the email address.
	EmailAddressArn *string

	// The identifier of the email address.
	EmailAddressId *string

	// The email address last modification timestamp in ISO 8601 Datetime.
	ModifiedTimestamp *string

	// The tags used to organize, track, or control access for this resource. For
	// example, { "Tags": {"key1":"value1", "key2":"value2"} }.
	Tags map[string]string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDescribeEmailAddressMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpDescribeEmailAddress{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpDescribeEmailAddress{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpDescribeEmailAddressValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DescribeEmailAddress"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
