// Code generated by smithy-go-codegen DO NOT EDIT.

// Package datasync provides the API client, operations, and parameter types for
// AWS DataSync.
//
// # DataSync
//
// DataSync is an online data movement service that simplifies data migration and
// helps you quickly, easily, and securely transfer your file or object data to,
// from, and between Amazon Web Services storage services.
//
// This API interface reference includes documentation for using DataSync
// programmatically. For complete information, see the [DataSync User Guide].
//
// [DataSync User Guide]: https://docs.aws.amazon.com/datasync/latest/userguide/what-is-datasync.html
package datasync
