// Code generated by smithy-go-codegen DO NOT EDIT.

package types

type ArtifactStatus string

// Enum values for ArtifactStatus
const (
	ArtifactStatusApproved   ArtifactStatus = "APPROVED"
	ArtifactStatusRejected   ArtifactStatus = "REJECTED"
	ArtifactStatusInProgress ArtifactStatus = "IN_PROGRESS"
)

// Values returns all known values for ArtifactStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ArtifactStatus) Values() []ArtifactStatus {
	return []ArtifactStatus{
		"APPROVED",
		"REJECTED",
		"IN_PROGRESS",
	}
}

type ChatItemType string

// Enum values for ChatItemType
const (
	ChatItemTypeTyping            ChatItemType = "TYPING"
	ChatItemTypeParticipantJoined ChatItemType = "PARTICIPANT_JOINED"
	ChatItemTypeParticipantLeft   ChatItemType = "PARTICIPANT_LEFT"
	ChatItemTypeChatEnded         ChatItemType = "CHAT_ENDED"
	ChatItemTypeTransferSucceeded ChatItemType = "TRANSFER_SUCCEEDED"
	ChatItemTypeTransferFailed    ChatItemType = "TRANSFER_FAILED"
	ChatItemTypeMessage           ChatItemType = "MESSAGE"
	ChatItemTypeEvent             ChatItemType = "EVENT"
	ChatItemTypeAttachment        ChatItemType = "ATTACHMENT"
	ChatItemTypeConnectionAck     ChatItemType = "CONNECTION_ACK"
	ChatItemTypeMessageDelivered  ChatItemType = "MESSAGE_DELIVERED"
	ChatItemTypeMessageRead       ChatItemType = "MESSAGE_READ"
)

// Values returns all known values for ChatItemType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ChatItemType) Values() []ChatItemType {
	return []ChatItemType{
		"TYPING",
		"PARTICIPANT_JOINED",
		"PARTICIPANT_LEFT",
		"CHAT_ENDED",
		"TRANSFER_SUCCEEDED",
		"TRANSFER_FAILED",
		"MESSAGE",
		"EVENT",
		"ATTACHMENT",
		"CONNECTION_ACK",
		"MESSAGE_DELIVERED",
		"MESSAGE_READ",
	}
}

type ConnectionType string

// Enum values for ConnectionType
const (
	ConnectionTypeWebsocket             ConnectionType = "WEBSOCKET"
	ConnectionTypeConnectionCredentials ConnectionType = "CONNECTION_CREDENTIALS"
	ConnectionTypeWebrtcConnection      ConnectionType = "WEBRTC_CONNECTION"
)

// Values returns all known values for ConnectionType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ConnectionType) Values() []ConnectionType {
	return []ConnectionType{
		"WEBSOCKET",
		"CONNECTION_CREDENTIALS",
		"WEBRTC_CONNECTION",
	}
}

type MeetingFeatureStatus string

// Enum values for MeetingFeatureStatus
const (
	MeetingFeatureStatusAvailable   MeetingFeatureStatus = "AVAILABLE"
	MeetingFeatureStatusUnavailable MeetingFeatureStatus = "UNAVAILABLE"
)

// Values returns all known values for MeetingFeatureStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (MeetingFeatureStatus) Values() []MeetingFeatureStatus {
	return []MeetingFeatureStatus{
		"AVAILABLE",
		"UNAVAILABLE",
	}
}

type MessageProcessingStatus string

// Enum values for MessageProcessingStatus
const (
	MessageProcessingStatusProcessing MessageProcessingStatus = "PROCESSING"
	MessageProcessingStatusFailed     MessageProcessingStatus = "FAILED"
	MessageProcessingStatusRejected   MessageProcessingStatus = "REJECTED"
)

// Values returns all known values for MessageProcessingStatus. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (MessageProcessingStatus) Values() []MessageProcessingStatus {
	return []MessageProcessingStatus{
		"PROCESSING",
		"FAILED",
		"REJECTED",
	}
}

type ParticipantRole string

// Enum values for ParticipantRole
const (
	ParticipantRoleAgent      ParticipantRole = "AGENT"
	ParticipantRoleCustomer   ParticipantRole = "CUSTOMER"
	ParticipantRoleSystem     ParticipantRole = "SYSTEM"
	ParticipantRoleCustomBot  ParticipantRole = "CUSTOM_BOT"
	ParticipantRoleSupervisor ParticipantRole = "SUPERVISOR"
)

// Values returns all known values for ParticipantRole. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ParticipantRole) Values() []ParticipantRole {
	return []ParticipantRole{
		"AGENT",
		"CUSTOMER",
		"SYSTEM",
		"CUSTOM_BOT",
		"SUPERVISOR",
	}
}

type ResourceType string

// Enum values for ResourceType
const (
	ResourceTypeContact        ResourceType = "CONTACT"
	ResourceTypeContactFlow    ResourceType = "CONTACT_FLOW"
	ResourceTypeInstance       ResourceType = "INSTANCE"
	ResourceTypeParticipant    ResourceType = "PARTICIPANT"
	ResourceTypeHierarchyLevel ResourceType = "HIERARCHY_LEVEL"
	ResourceTypeHierarchyGroup ResourceType = "HIERARCHY_GROUP"
	ResourceTypeUser           ResourceType = "USER"
	ResourceTypePhoneNumber    ResourceType = "PHONE_NUMBER"
)

// Values returns all known values for ResourceType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ResourceType) Values() []ResourceType {
	return []ResourceType{
		"CONTACT",
		"CONTACT_FLOW",
		"INSTANCE",
		"PARTICIPANT",
		"HIERARCHY_LEVEL",
		"HIERARCHY_GROUP",
		"USER",
		"PHONE_NUMBER",
	}
}

type ScanDirection string

// Enum values for ScanDirection
const (
	ScanDirectionForward  ScanDirection = "FORWARD"
	ScanDirectionBackward ScanDirection = "BACKWARD"
)

// Values returns all known values for ScanDirection. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ScanDirection) Values() []ScanDirection {
	return []ScanDirection{
		"FORWARD",
		"BACKWARD",
	}
}

type SortKey string

// Enum values for SortKey
const (
	SortKeyDescending SortKey = "DESCENDING"
	SortKeyAscending  SortKey = "ASCENDING"
)

// Values returns all known values for SortKey. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (SortKey) Values() []SortKey {
	return []SortKey{
		"DESCENDING",
		"ASCENDING",
	}
}
