// Code generated by smithy-go-codegen DO NOT EDIT.

package bedrockagentcorecontrol

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/bedrockagentcorecontrol/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Creates a new API key credential provider.
func (c *Client) CreateApiKeyCredentialProvider(ctx context.Context, params *CreateApiKeyCredentialProviderInput, optFns ...func(*Options)) (*CreateApiKeyCredentialProviderOutput, error) {
	if params == nil {
		params = &CreateApiKeyCredentialProviderInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "CreateApiKeyCredentialProvider", params, optFns, c.addOperationCreateApiKeyCredentialProviderMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*CreateApiKeyCredentialProviderOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type CreateApiKeyCredentialProviderInput struct {

	// The name of the API key credential provider. The name must be unique within
	// your account.
	//
	// This member is required.
	Name *string

	// The API key to use for authentication. This value is encrypted and stored
	// securely.
	ApiKey *string

	// A reference to the Amazon Web Services Secrets Manager secret that stores the
	// API key. This includes the secret ID and the JSON key used to extract the API
	// key value from the secret. Required when apiKeySecretSource is set to EXTERNAL .
	ApiKeySecretConfig *types.SecretReference

	// The source type of the API key secret. Use MANAGED if the secret is managed by
	// the service, or EXTERNAL if you manage the secret yourself in Amazon Web
	// Services Secrets Manager.
	ApiKeySecretSource types.SecretSourceType

	// A map of tag keys and values to assign to the API key credential provider. Tags
	// enable you to categorize your resources in different ways, for example, by
	// purpose, owner, or environment.
	Tags map[string]string

	noSmithyDocumentSerde
}

type CreateApiKeyCredentialProviderOutput struct {

	// The Amazon Resource Name (ARN) of the secret containing the API key.
	//
	// This member is required.
	ApiKeySecretArn *types.Secret

	// The Amazon Resource Name (ARN) of the created API key credential provider.
	//
	// This member is required.
	CredentialProviderArn *string

	// The name of the created API key credential provider.
	//
	// This member is required.
	Name *string

	// The JSON key used to extract the API key value from the Amazon Web Services
	// Secrets Manager secret.
	ApiKeySecretJsonKey *string

	// The source type of the API key secret. Either MANAGED if the secret is managed
	// by the service, or EXTERNAL if managed by the user in Amazon Web Services
	// Secrets Manager.
	ApiKeySecretSource types.SecretSourceType

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationCreateApiKeyCredentialProviderMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpCreateApiKeyCredentialProvider{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpCreateApiKeyCredentialProvider{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpCreateApiKeyCredentialProviderValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "CreateApiKeyCredentialProvider"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
