// Code generated by smithy-go-codegen DO NOT EDIT.

package bedrockagentcore

import (
	"context"
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/bedrockagentcore/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Lists memory records in an AgentCore Memory resource based on specified
// criteria. We recommend using pagination to ensure that the operation returns
// quickly and successfully.
//
// To use this operation, you must have the bedrock-agentcore:ListMemoryRecords
// permission.
func (c *Client) ListMemoryRecords(ctx context.Context, params *ListMemoryRecordsInput, optFns ...func(*Options)) (*ListMemoryRecordsOutput, error) {
	if params == nil {
		params = &ListMemoryRecordsInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "ListMemoryRecords", params, optFns, c.addOperationListMemoryRecordsMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*ListMemoryRecordsOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type ListMemoryRecordsInput struct {

	// The identifier of the AgentCore Memory resource for which to list memory
	// records.
	//
	// This member is required.
	MemoryId *string

	// The maximum number of results to return in a single call. The default value is
	// 20.
	MaxResults *int32

	// The memory strategy identifier to filter memory records by. If specified, only
	// memory records with this strategy ID are returned.
	MemoryStrategyId *string

	// A list of metadata filter expressions to scope the returned memory records.
	MetadataFilters []types.MemoryMetadataFilterExpression

	// The namespace prefix to filter memory records by. Returns all memory records in
	// namespaces that start with the provided prefix. Either namespace or
	// namespacePath is required.
	Namespace *string

	// Use namespacePath for hierarchical retrievals. Return all memory records where
	// namespace falls under the same parent hierarchy. Either namespace or
	// namespacePath is required.
	NamespacePath *string

	// The token for the next set of results. Use the value returned in the previous
	// response in the next request to retrieve the next set of results.
	NextToken *string

	noSmithyDocumentSerde
}

type ListMemoryRecordsOutput struct {

	// The list of memory record summaries that match the specified criteria.
	//
	// This member is required.
	MemoryRecordSummaries []types.MemoryRecordSummary

	// The token to use in a subsequent request to get the next set of results. This
	// value is null when there are no more results to return.
	NextToken *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationListMemoryRecordsMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpListMemoryRecords{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpListMemoryRecords{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpListMemoryRecordsValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "ListMemoryRecords"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}

// ListMemoryRecordsPaginatorOptions is the paginator options for ListMemoryRecords
type ListMemoryRecordsPaginatorOptions struct {
	// The maximum number of results to return in a single call. The default value is
	// 20.
	Limit int32

	// Set to true if pagination should stop if the service returns a pagination token
	// that matches the most recent token provided to the service.
	StopOnDuplicateToken bool
}

// ListMemoryRecordsPaginator is a paginator for ListMemoryRecords
type ListMemoryRecordsPaginator struct {
	options   ListMemoryRecordsPaginatorOptions
	client    ListMemoryRecordsAPIClient
	params    *ListMemoryRecordsInput
	nextToken *string
	firstPage bool
}

// NewListMemoryRecordsPaginator returns a new ListMemoryRecordsPaginator
func NewListMemoryRecordsPaginator(client ListMemoryRecordsAPIClient, params *ListMemoryRecordsInput, optFns ...func(*ListMemoryRecordsPaginatorOptions)) *ListMemoryRecordsPaginator {
	if params == nil {
		params = &ListMemoryRecordsInput{}
	}

	options := ListMemoryRecordsPaginatorOptions{}
	if params.MaxResults != nil {
		options.Limit = *params.MaxResults
	}

	for _, fn := range optFns {
		fn(&options)
	}

	return &ListMemoryRecordsPaginator{
		options:   options,
		client:    client,
		params:    params,
		firstPage: true,
		nextToken: params.NextToken,
	}
}

// HasMorePages returns a boolean indicating whether more pages are available
func (p *ListMemoryRecordsPaginator) HasMorePages() bool {
	return p.firstPage || (p.nextToken != nil && len(*p.nextToken) != 0)
}

// NextPage retrieves the next ListMemoryRecords page.
func (p *ListMemoryRecordsPaginator) NextPage(ctx context.Context, optFns ...func(*Options)) (*ListMemoryRecordsOutput, error) {
	if !p.HasMorePages() {
		return nil, fmt.Errorf("no more pages available")
	}

	params := *p.params
	params.NextToken = p.nextToken

	var limit *int32
	if p.options.Limit > 0 {
		limit = &p.options.Limit
	}
	params.MaxResults = limit

	optFns = append([]func(*Options){
		addIsPaginatorUserAgent,
	}, optFns...)
	result, err := p.client.ListMemoryRecords(ctx, &params, optFns...)
	if err != nil {
		return nil, err
	}
	p.firstPage = false

	prevToken := p.nextToken
	p.nextToken = result.NextToken

	if p.options.StopOnDuplicateToken &&
		prevToken != nil &&
		p.nextToken != nil &&
		*prevToken == *p.nextToken {
		p.nextToken = nil
	}

	return result, nil
}

// ListMemoryRecordsAPIClient is a client that implements the ListMemoryRecords
// operation.
type ListMemoryRecordsAPIClient interface {
	ListMemoryRecords(context.Context, *ListMemoryRecordsInput, ...func(*Options)) (*ListMemoryRecordsOutput, error)
}

var _ ListMemoryRecordsAPIClient = (*Client)(nil)
