// Code generated by smithy-go-codegen DO NOT EDIT.

// Package codegurusecurity provides the API client, operations, and parameter
// types for Amazon CodeGuru Security.
//
// On November 20, 2025, AWS will discontinue support for Amazon CodeGuru
// Security. After November 20, 2025, you will no longer be able to access the
// /codeguru/security console, service resources, or documentation. For more
// information, see [https://docs.aws.amazon.com/codeguru/latest/security-ug/end-of-support.html].
//
// This section provides documentation for the Amazon CodeGuru Security API
// operations. CodeGuru Security is a service that uses program analysis and
// machine learning to detect security policy violations and vulnerabilities, and
// recommends ways to address these security risks.
//
// By proactively detecting and providing recommendations for addressing security
// risks, CodeGuru Security improves the overall security of your application code.
// For more information about CodeGuru Security, see the [Amazon CodeGuru Security User Guide].
//
// [https://docs.aws.amazon.com/codeguru/latest/security-ug/end-of-support.html]: https://docs.aws.amazon.com/codeguru/latest/security-ug/end-of-support.html
// [Amazon CodeGuru Security User Guide]: https://docs.aws.amazon.com/codeguru/latest/security-ug/what-is-codeguru-security.html
package codegurusecurity
