// Code generated by smithy-go-codegen DO NOT EDIT.

// Package chatbot provides the API client, operations, and parameter types for
// AWS Chatbot.
//
// The AWS Chatbot API Reference provides descriptions, API request parameters,
// and the XML response for each of the AWS Chatbot API actions.
//
// AWS Chatbot APIs are currently available in the following Regions:
//
//   - US East (Ohio) - us-east-2
//
//   - US West (Oregon) - us-west-2
//
//   - Asia Pacific (Singapore) - ap-southeast-1
//
//   - Europe (Ireland) - eu-west-1
//
// The AWS Chatbot console can only be used in US East (Ohio). Your configuration
// data however, is stored in each of the relevant available Regions.
//
// Your AWS CloudTrail events are logged in whatever Region you call from, not US
// East (N. Virginia) by default.
package chatbot
