// Code generated by smithy-go-codegen DO NOT EDIT.

package types

type ApplyMethod string

// Enum values for ApplyMethod
const (
	ApplyMethodImmediate     ApplyMethod = "immediate"
	ApplyMethodPendingReboot ApplyMethod = "pending-reboot"
)

// Values returns all known values for ApplyMethod. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ApplyMethod) Values() []ApplyMethod {
	return []ApplyMethod{
		"immediate",
		"pending-reboot",
	}
}

type FailoverStatus string

// Enum values for FailoverStatus
const (
	FailoverStatusPending     FailoverStatus = "pending"
	FailoverStatusFailingOver FailoverStatus = "failing-over"
	FailoverStatusCancelling  FailoverStatus = "cancelling"
)

// Values returns all known values for FailoverStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (FailoverStatus) Values() []FailoverStatus {
	return []FailoverStatus{
		"pending",
		"failing-over",
		"cancelling",
	}
}

type GlobalClusterMemberSynchronizationStatus string

// Enum values for GlobalClusterMemberSynchronizationStatus
const (
	GlobalClusterMemberSynchronizationStatusConnected     GlobalClusterMemberSynchronizationStatus = "connected"
	GlobalClusterMemberSynchronizationStatusPendingResync GlobalClusterMemberSynchronizationStatus = "pending-resync"
)

// Values returns all known values for GlobalClusterMemberSynchronizationStatus.
// Note that this can be expanded in the future, and so it is only as up to date as
// the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GlobalClusterMemberSynchronizationStatus) Values() []GlobalClusterMemberSynchronizationStatus {
	return []GlobalClusterMemberSynchronizationStatus{
		"connected",
		"pending-resync",
	}
}

type SourceType string

// Enum values for SourceType
const (
	SourceTypeDbInstance        SourceType = "db-instance"
	SourceTypeDbParameterGroup  SourceType = "db-parameter-group"
	SourceTypeDbSecurityGroup   SourceType = "db-security-group"
	SourceTypeDbSnapshot        SourceType = "db-snapshot"
	SourceTypeDbCluster         SourceType = "db-cluster"
	SourceTypeDbClusterSnapshot SourceType = "db-cluster-snapshot"
)

// Values returns all known values for SourceType. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (SourceType) Values() []SourceType {
	return []SourceType{
		"db-instance",
		"db-parameter-group",
		"db-security-group",
		"db-snapshot",
		"db-cluster",
		"db-cluster-snapshot",
	}
}
