// Code generated by smithy-go-codegen DO NOT EDIT.

package types

type AutomationJobStatus string

// Enum values for AutomationJobStatus
const (
	AutomationJobStatusCreated      AutomationJobStatus = "Created"
	AutomationJobStatusInProgress   AutomationJobStatus = "InProgress"
	AutomationJobStatusSuccess      AutomationJobStatus = "Success"
	AutomationJobStatusServiceError AutomationJobStatus = "ServiceError"
	AutomationJobStatusClientError  AutomationJobStatus = "ClientError"
)

// Values returns all known values for AutomationJobStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AutomationJobStatus) Values() []AutomationJobStatus {
	return []AutomationJobStatus{
		"Created",
		"InProgress",
		"Success",
		"ServiceError",
		"ClientError",
	}
}

type BlueprintStage string

// Enum values for BlueprintStage
const (
	BlueprintStageDevelopment BlueprintStage = "DEVELOPMENT"
	BlueprintStageLive        BlueprintStage = "LIVE"
)

// Values returns all known values for BlueprintStage. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (BlueprintStage) Values() []BlueprintStage {
	return []BlueprintStage{
		"DEVELOPMENT",
		"LIVE",
	}
}

type CustomOutputStatus string

// Enum values for CustomOutputStatus
const (
	CustomOutputStatusMatch   CustomOutputStatus = "MATCH"
	CustomOutputStatusNoMatch CustomOutputStatus = "NO_MATCH"
)

// Values returns all known values for CustomOutputStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (CustomOutputStatus) Values() []CustomOutputStatus {
	return []CustomOutputStatus{
		"MATCH",
		"NO_MATCH",
	}
}

type DataAutomationStage string

// Enum values for DataAutomationStage
const (
	DataAutomationStageLive        DataAutomationStage = "LIVE"
	DataAutomationStageDevelopment DataAutomationStage = "DEVELOPMENT"
)

// Values returns all known values for DataAutomationStage. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (DataAutomationStage) Values() []DataAutomationStage {
	return []DataAutomationStage{
		"LIVE",
		"DEVELOPMENT",
	}
}

type SemanticModality string

// Enum values for SemanticModality
const (
	SemanticModalityDocument SemanticModality = "DOCUMENT"
	SemanticModalityImage    SemanticModality = "IMAGE"
	SemanticModalityAudio    SemanticModality = "AUDIO"
	SemanticModalityVideo    SemanticModality = "VIDEO"
)

// Values returns all known values for SemanticModality. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (SemanticModality) Values() []SemanticModality {
	return []SemanticModality{
		"DOCUMENT",
		"IMAGE",
		"AUDIO",
		"VIDEO",
	}
}
