// Code generated by smithy-go-codegen DO NOT EDIT.

// Package dsql provides the API client, operations, and parameter types for
// Amazon Aurora DSQL.
//
// This is an interface reference for Amazon Aurora DSQL. It contains
// documentation for one of the programming or command line interfaces you can use
// to manage Amazon Aurora DSQL.
//
// Amazon Aurora DSQL is a serverless, distributed SQL database suitable for
// workloads of any size. is available in both single-Region and multi-Region
// configurations, so your clusters and databases are always available even if an
// Availability Zone or an Amazon Web Services Region are unavailable. lets you
// focus on using your data to acquire new insights for your business and
// customers.
package dsql
