// Code generated by smithy-go-codegen DO NOT EDIT.

package bedrockagentcorecontrol

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/bedrockagentcorecontrol/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Synchronizes the gateway targets by fetching the latest tool definitions from
// the target endpoints.
//
// You cannot synchronize a target that is in a pending authorization state (
// CREATE_PENDING_AUTH , UPDATE_PENDING_AUTH , or SYNCHRONIZE_PENDING_AUTH ). Wait
// for the authorization to complete or fail before synchronizing.
//
// You cannot synchronize a target that has a static tool schema ( mcpToolSchema )
// configured. Remove the static schema through an UpdateGatewayTarget call to
// enable dynamic tool synchronization.
func (c *Client) SynchronizeGatewayTargets(ctx context.Context, params *SynchronizeGatewayTargetsInput, optFns ...func(*Options)) (*SynchronizeGatewayTargetsOutput, error) {
	if params == nil {
		params = &SynchronizeGatewayTargetsInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "SynchronizeGatewayTargets", params, optFns, c.addOperationSynchronizeGatewayTargetsMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*SynchronizeGatewayTargetsOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type SynchronizeGatewayTargetsInput struct {

	// The gateway Identifier.
	//
	// This member is required.
	GatewayIdentifier *string

	// The target ID list.
	//
	// This member is required.
	TargetIdList []string

	noSmithyDocumentSerde
}

type SynchronizeGatewayTargetsOutput struct {

	// The gateway targets for synchronization.
	Targets []types.GatewayTarget

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationSynchronizeGatewayTargetsMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpSynchronizeGatewayTargets{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpSynchronizeGatewayTargets{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpSynchronizeGatewayTargetsValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "SynchronizeGatewayTargets"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
