// Code generated by smithy-go-codegen DO NOT EDIT.

package apprunner

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/apprunner/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Create an App Runner VPC connector resource. App Runner requires this resource
// when you want to associate your App Runner service to a custom Amazon Virtual
// Private Cloud (Amazon VPC).
func (c *Client) CreateVpcConnector(ctx context.Context, params *CreateVpcConnectorInput, optFns ...func(*Options)) (*CreateVpcConnectorOutput, error) {
	if params == nil {
		params = &CreateVpcConnectorInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "CreateVpcConnector", params, optFns, c.addOperationCreateVpcConnectorMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*CreateVpcConnectorOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type CreateVpcConnectorInput struct {

	// A list of IDs of subnets that App Runner should use when it associates your
	// service with a custom Amazon VPC. Specify IDs of subnets of a single Amazon VPC.
	// App Runner determines the Amazon VPC from the subnets you specify.
	//
	// App Runner only supports subnets of IP address type IPv4 and dual stack (IPv4
	// and IPv6).
	//
	// This member is required.
	Subnets []string

	// A name for the VPC connector.
	//
	// This member is required.
	VpcConnectorName *string

	// A list of IDs of security groups that App Runner should use for access to
	// Amazon Web Services resources under the specified subnets. If not specified, App
	// Runner uses the default security group of the Amazon VPC. The default security
	// group allows all outbound traffic.
	SecurityGroups []string

	// A list of metadata items that you can associate with your VPC connector
	// resource. A tag is a key-value pair.
	Tags []types.Tag

	noSmithyDocumentSerde
}

type CreateVpcConnectorOutput struct {

	// A description of the App Runner VPC connector that's created by this request.
	//
	// This member is required.
	VpcConnector *types.VpcConnector

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationCreateVpcConnectorMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson10_serializeOpCreateVpcConnector{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson10_deserializeOpCreateVpcConnector{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpCreateVpcConnectorValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "CreateVpcConnector"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
