// Code generated by smithy-go-codegen DO NOT EDIT.

package acm

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/acm/types"
	"github.com/aws/smithy-go/middleware"
	"github.com/aws/smithy-go/ptr"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Updates the configuration of an existing ACME endpoint. You can change the
// authorization behavior, contact requirement, or certificate authority settings.
func (c *Client) UpdateAcmeEndpoint(ctx context.Context, params *UpdateAcmeEndpointInput, optFns ...func(*Options)) (*UpdateAcmeEndpointOutput, error) {
	if params == nil {
		params = &UpdateAcmeEndpointInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "UpdateAcmeEndpoint", params, optFns, c.addOperationUpdateAcmeEndpointMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*UpdateAcmeEndpointOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type UpdateAcmeEndpointInput struct {

	// The Amazon Resource Name (ARN) of the ACME endpoint to update.
	//
	// This member is required.
	AcmeEndpointArn *string

	// The updated authorization behavior.
	AuthorizationBehavior types.AcmeAuthorizationBehavior

	// The updated certificate authority configuration.
	CertificateAuthority types.CertificateAuthority

	// The updated contact requirement.
	Contact types.AcmeContact

	noSmithyDocumentSerde
}

func (in *UpdateAcmeEndpointInput) bindEndpointParams(p *EndpointParameters) {

	p.ServiceType = ptr.String("ACM-ACME")
}

type UpdateAcmeEndpointOutput struct {
	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationUpdateAcmeEndpointMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson11_serializeOpUpdateAcmeEndpoint{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson11_deserializeOpUpdateAcmeEndpoint{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpUpdateAcmeEndpointValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "UpdateAcmeEndpoint"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
