// Code generated by smithy-go-codegen DO NOT EDIT.

// Package autoscalingplans provides the API client, operations, and parameter
// types for AWS Auto Scaling Plans.
//
// # AWS Auto Scaling
//
// Use AWS Auto Scaling to create scaling plans for your applications to
// automatically scale your scalable AWS resources.
//
// # API Summary
//
// You can use the AWS Auto Scaling service API to accomplish the following tasks:
//
//   - Create and manage scaling plans
//
//   - Define target tracking scaling policies to dynamically scale your resources
//     based on utilization
//
//   - Scale Amazon EC2 Auto Scaling groups using predictive scaling and dynamic
//     scaling to scale your Amazon EC2 capacity faster
//
//   - Set minimum and maximum capacity limits
//
//   - Retrieve information on existing scaling plans
//
//   - Access current forecast data and historical forecast data for up to 56 days
//     previous
//
// To learn more about AWS Auto Scaling, including information about granting IAM
// users required permissions for AWS Auto Scaling actions, see the [AWS Auto Scaling User Guide].
//
// [AWS Auto Scaling User Guide]: https://docs.aws.amazon.com/autoscaling/plans/userguide/what-is-aws-auto-scaling.html
package autoscalingplans
