// Code generated by smithy-go-codegen DO NOT EDIT.

// Package costexplorer provides the API client, operations, and parameter types
// for AWS Cost Explorer Service.
//
// You can use the Cost Explorer API to programmatically query your cost and usage
// data. You can query for aggregated data such as total monthly costs or total
// daily usage. You can also query for granular data. This might include the number
// of daily write operations for Amazon DynamoDB database tables in your production
// environment.
//
// # Service Endpoint
//
// The Cost Explorer API provides the following endpoint:
//
//   - https://ce.us-east-1.amazonaws.com
//
// For information about the costs that are associated with the Cost Explorer API,
// see [Amazon Web Services Cost Management Pricing].
//
// [Amazon Web Services Cost Management Pricing]: http://aws.amazon.com/aws-cost-management/pricing/
package costexplorer
