// Code generated by smithy-go-codegen DO NOT EDIT.

package deadline

import (
	"context"
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/deadline/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Lists session actions.
func (c *Client) ListSessionActions(ctx context.Context, params *ListSessionActionsInput, optFns ...func(*Options)) (*ListSessionActionsOutput, error) {
	if params == nil {
		params = &ListSessionActionsInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "ListSessionActions", params, optFns, c.addOperationListSessionActionsMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*ListSessionActionsOutput)
	out.ResultMetadata = metadata
	return out, nil
}

// Shared pagination fields for List operation inputs (nextToken + maxResults).
type ListSessionActionsInput struct {

	// The farm ID for the session actions list.
	//
	// This member is required.
	FarmId *string

	// The job ID for the session actions list.
	//
	// This member is required.
	JobId *string

	// The queue ID for the session actions list.
	//
	// This member is required.
	QueueId *string

	// The maximum number of results to return. Use this parameter with NextToken to
	// get results as a set of sequential pages.
	MaxResults *int32

	// The token for the next set of results, or null to start from the beginning.
	NextToken *string

	// The session ID to include on the sessions action list.
	SessionId *string

	// The task ID for the session actions list.
	TaskId *string

	noSmithyDocumentSerde
}

// Shared pagination field for List operation outputs (nextToken).
type ListSessionActionsOutput struct {

	// The session actions.
	//
	// This member is required.
	SessionActions []types.SessionActionSummary

	// If Deadline Cloud returns nextToken , then there are more results available. The
	// value of nextToken is a unique pagination token for each page. To retrieve the
	// next page, call the operation again using the returned token. Keep all other
	// arguments unchanged. If no results remain, then nextToken is set to null . Each
	// pagination token expires after 24 hours. If you provide a token that isn't
	// valid, then you receive an HTTP 400 ValidationException error.
	NextToken *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationListSessionActionsMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpListSessionActions{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpListSessionActions{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addEndpointPrefix_opListSessionActionsMiddleware(stack); err != nil {
		return err
	}
	if err = addOpListSessionActionsValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "ListSessionActions"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}

// ListSessionActionsPaginatorOptions is the paginator options for
// ListSessionActions
type ListSessionActionsPaginatorOptions struct {
	// The maximum number of results to return. Use this parameter with NextToken to
	// get results as a set of sequential pages.
	Limit int32

	// Set to true if pagination should stop if the service returns a pagination token
	// that matches the most recent token provided to the service.
	StopOnDuplicateToken bool
}

// ListSessionActionsPaginator is a paginator for ListSessionActions
type ListSessionActionsPaginator struct {
	options   ListSessionActionsPaginatorOptions
	client    ListSessionActionsAPIClient
	params    *ListSessionActionsInput
	nextToken *string
	firstPage bool
}

// NewListSessionActionsPaginator returns a new ListSessionActionsPaginator
func NewListSessionActionsPaginator(client ListSessionActionsAPIClient, params *ListSessionActionsInput, optFns ...func(*ListSessionActionsPaginatorOptions)) *ListSessionActionsPaginator {
	if params == nil {
		params = &ListSessionActionsInput{}
	}

	options := ListSessionActionsPaginatorOptions{}
	if params.MaxResults != nil {
		options.Limit = *params.MaxResults
	}

	for _, fn := range optFns {
		fn(&options)
	}

	return &ListSessionActionsPaginator{
		options:   options,
		client:    client,
		params:    params,
		firstPage: true,
		nextToken: params.NextToken,
	}
}

// HasMorePages returns a boolean indicating whether more pages are available
func (p *ListSessionActionsPaginator) HasMorePages() bool {
	return p.firstPage || (p.nextToken != nil && len(*p.nextToken) != 0)
}

// NextPage retrieves the next ListSessionActions page.
func (p *ListSessionActionsPaginator) NextPage(ctx context.Context, optFns ...func(*Options)) (*ListSessionActionsOutput, error) {
	if !p.HasMorePages() {
		return nil, fmt.Errorf("no more pages available")
	}

	params := *p.params
	params.NextToken = p.nextToken

	var limit *int32
	if p.options.Limit > 0 {
		limit = &p.options.Limit
	}
	params.MaxResults = limit

	optFns = append([]func(*Options){
		addIsPaginatorUserAgent,
	}, optFns...)
	result, err := p.client.ListSessionActions(ctx, &params, optFns...)
	if err != nil {
		return nil, err
	}
	p.firstPage = false

	prevToken := p.nextToken
	p.nextToken = result.NextToken

	if p.options.StopOnDuplicateToken &&
		prevToken != nil &&
		p.nextToken != nil &&
		*prevToken == *p.nextToken {
		p.nextToken = nil
	}

	return result, nil
}

type endpointPrefix_opListSessionActionsMiddleware struct {
}

func (*endpointPrefix_opListSessionActionsMiddleware) ID() string {
	return "EndpointHostPrefix"
}

func (m *endpointPrefix_opListSessionActionsMiddleware) HandleFinalize(ctx context.Context, in middleware.FinalizeInput, next middleware.FinalizeHandler) (
	out middleware.FinalizeOutput, metadata middleware.Metadata, err error,
) {
	if smithyhttp.GetHostnameImmutable(ctx) || smithyhttp.IsEndpointHostPrefixDisabled(ctx) {
		return next.HandleFinalize(ctx, in)
	}

	req, ok := in.Request.(*smithyhttp.Request)
	if !ok {
		return out, metadata, fmt.Errorf("unknown transport type %T", in.Request)
	}

	req.URL.Host = "management." + req.URL.Host

	return next.HandleFinalize(ctx, in)
}
func addEndpointPrefix_opListSessionActionsMiddleware(stack *middleware.Stack) error {
	return stack.Finalize.Insert(&endpointPrefix_opListSessionActionsMiddleware{}, "ResolveEndpointV2", middleware.After)
}

// ListSessionActionsAPIClient is a client that implements the ListSessionActions
// operation.
type ListSessionActionsAPIClient interface {
	ListSessionActions(context.Context, *ListSessionActionsInput, ...func(*Options)) (*ListSessionActionsOutput, error)
}

var _ ListSessionActionsAPIClient = (*Client)(nil)
