// Code generated by smithy-go-codegen DO NOT EDIT.

package bcmpricingcalculator

import (
	"context"
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/bcmpricingcalculator/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

//	Create Amazon Web Services service usage that you want to model in a Bill
//
// Scenario.
//
// The BatchCreateBillScenarioUsageModification operation doesn't have its own IAM
// permission. To authorize this operation for Amazon Web Services principals,
// include the permission
// bcm-pricing-calculator:CreateBillScenarioUsageModification in your policies.
func (c *Client) BatchCreateBillScenarioUsageModification(ctx context.Context, params *BatchCreateBillScenarioUsageModificationInput, optFns ...func(*Options)) (*BatchCreateBillScenarioUsageModificationOutput, error) {
	if params == nil {
		params = &BatchCreateBillScenarioUsageModificationInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "BatchCreateBillScenarioUsageModification", params, optFns, c.addOperationBatchCreateBillScenarioUsageModificationMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*BatchCreateBillScenarioUsageModificationOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type BatchCreateBillScenarioUsageModificationInput struct {

	//  The ID of the Bill Scenario for which you want to create the modeled usage.
	//
	// This member is required.
	BillScenarioId *string

	//  List of usage that you want to model in the Bill Scenario.
	//
	// This member is required.
	UsageModifications []types.BatchCreateBillScenarioUsageModificationEntry

	//  A unique, case-sensitive identifier that you provide to ensure the idempotency
	// of the request.
	ClientToken *string

	noSmithyDocumentSerde
}

type BatchCreateBillScenarioUsageModificationOutput struct {

	//  Returns the list of errors reason and the usage item keys that cannot be
	// created in the Bill Scenario.
	Errors []types.BatchCreateBillScenarioUsageModificationError

	//  Returns the list of successful usage line items that were created for the Bill
	// Scenario.
	Items []types.BatchCreateBillScenarioUsageModificationItem

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationBatchCreateBillScenarioUsageModificationMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson10_serializeOpBatchCreateBillScenarioUsageModification{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson10_deserializeOpBatchCreateBillScenarioUsageModification{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addIdempotencyToken_opBatchCreateBillScenarioUsageModificationMiddleware(stack, options); err != nil {
		return err
	}
	if err = addOpBatchCreateBillScenarioUsageModificationValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "BatchCreateBillScenarioUsageModification"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}

type idempotencyToken_initializeOpBatchCreateBillScenarioUsageModification struct {
	tokenProvider IdempotencyTokenProvider
}

func (*idempotencyToken_initializeOpBatchCreateBillScenarioUsageModification) ID() string {
	return "OperationIdempotencyTokenAutoFill"
}

func (m *idempotencyToken_initializeOpBatchCreateBillScenarioUsageModification) HandleInitialize(ctx context.Context, in middleware.InitializeInput, next middleware.InitializeHandler) (
	out middleware.InitializeOutput, metadata middleware.Metadata, err error,
) {
	if m.tokenProvider == nil {
		return next.HandleInitialize(ctx, in)
	}

	input, ok := in.Parameters.(*BatchCreateBillScenarioUsageModificationInput)
	if !ok {
		return out, metadata, fmt.Errorf("expected middleware input to be of type *BatchCreateBillScenarioUsageModificationInput ")
	}

	if input.ClientToken == nil {
		t, err := m.tokenProvider.GetIdempotencyToken()
		if err != nil {
			return out, metadata, err
		}
		input.ClientToken = &t
	}
	return next.HandleInitialize(ctx, in)
}
func addIdempotencyToken_opBatchCreateBillScenarioUsageModificationMiddleware(stack *middleware.Stack, cfg Options) error {
	return stack.Initialize.Add(&idempotencyToken_initializeOpBatchCreateBillScenarioUsageModification{tokenProvider: cfg.IdempotencyTokenProvider}, middleware.Before)
}
