// Code generated by smithy-go-codegen DO NOT EDIT.

package controltower

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/controltower/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Updates an EnabledBaseline resource's applied parameters or version. For usage
// examples, see [the Amazon Web Services Control Tower User Guide].
//
// [the Amazon Web Services Control Tower User Guide]: https://docs.aws.amazon.com/controltower/latest/userguide/baseline-api-examples.html
func (c *Client) UpdateEnabledBaseline(ctx context.Context, params *UpdateEnabledBaselineInput, optFns ...func(*Options)) (*UpdateEnabledBaselineOutput, error) {
	if params == nil {
		params = &UpdateEnabledBaselineInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "UpdateEnabledBaseline", params, optFns, c.addOperationUpdateEnabledBaselineMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*UpdateEnabledBaselineOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type UpdateEnabledBaselineInput struct {

	// Specifies the new Baseline version, to which the EnabledBaseline should be
	// updated.
	//
	// This member is required.
	BaselineVersion *string

	// Specifies the EnabledBaseline resource to be updated.
	//
	// This member is required.
	EnabledBaselineIdentifier *string

	// Parameters to apply when making an update.
	Parameters []types.EnabledBaselineParameter

	noSmithyDocumentSerde
}

type UpdateEnabledBaselineOutput struct {

	// The ID (in UUID format) of the asynchronous UpdateEnabledBaseline operation.
	// This operationIdentifier is used to track status through calls to the
	// GetBaselineOperation API.
	//
	// This member is required.
	OperationIdentifier *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationUpdateEnabledBaselineMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpUpdateEnabledBaseline{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpUpdateEnabledBaseline{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpUpdateEnabledBaselineValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "UpdateEnabledBaseline"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
