// Code generated by smithy-go-codegen DO NOT EDIT.

package cloudfront

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/cloudfront/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Get the configuration information about a streaming distribution.
func (c *Client) GetStreamingDistributionConfig(ctx context.Context, params *GetStreamingDistributionConfigInput, optFns ...func(*Options)) (*GetStreamingDistributionConfigOutput, error) {
	if params == nil {
		params = &GetStreamingDistributionConfigInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetStreamingDistributionConfig", params, optFns, c.addOperationGetStreamingDistributionConfigMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetStreamingDistributionConfigOutput)
	out.ResultMetadata = metadata
	return out, nil
}

// To request to get a streaming distribution configuration.
type GetStreamingDistributionConfigInput struct {

	// The streaming distribution's ID.
	//
	// This member is required.
	Id *string

	noSmithyDocumentSerde
}

// The returned result of the corresponding request.
type GetStreamingDistributionConfigOutput struct {

	// The current version of the configuration. For example: E2QWRUHAPOMQZL .
	ETag *string

	// The streaming distribution's configuration information.
	StreamingDistributionConfig *types.StreamingDistributionConfig

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetStreamingDistributionConfigMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestxml_serializeOpGetStreamingDistributionConfig{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestxml_deserializeOpGetStreamingDistributionConfig{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetStreamingDistributionConfigValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetStreamingDistributionConfig"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
