// Code generated by smithy-go-codegen DO NOT EDIT.

package ec2

import (
	"context"
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/ec2/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

//	Activates or deactivates tag keys for monitoring by EC2 Capacity Manager.
//
// Activated tag keys are included as dimensions in capacity metric data, enabling
// you to group and filter metrics by tag values.
func (c *Client) UpdateCapacityManagerMonitoredTagKeys(ctx context.Context, params *UpdateCapacityManagerMonitoredTagKeysInput, optFns ...func(*Options)) (*UpdateCapacityManagerMonitoredTagKeysOutput, error) {
	if params == nil {
		params = &UpdateCapacityManagerMonitoredTagKeysInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "UpdateCapacityManagerMonitoredTagKeys", params, optFns, c.addOperationUpdateCapacityManagerMonitoredTagKeysMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*UpdateCapacityManagerMonitoredTagKeysOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type UpdateCapacityManagerMonitoredTagKeysInput struct {

	//  The tag keys to activate for monitoring. Once activated, these tag keys will
	// be included as dimensions in capacity metric data.
	ActivateTagKeys []string

	//  Unique, case-sensitive identifier that you provide to ensure the idempotency
	// of the request.
	ClientToken *string

	//  The tag keys to deactivate. Deactivated tag keys will no longer be included as
	// dimensions in capacity metric data.
	DeactivateTagKeys []string

	//  Checks whether you have the required permissions for the action, without
	// actually making the request, and provides an error response. If you have the
	// required permissions, the error response is DryRunOperation . Otherwise, it is
	// UnauthorizedOperation .
	DryRun *bool

	noSmithyDocumentSerde
}

type UpdateCapacityManagerMonitoredTagKeysOutput struct {

	//  The list of tag keys affected by the update, including their current status
	// and metadata.
	CapacityManagerTagKeys []types.CapacityManagerMonitoredTagKey

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationUpdateCapacityManagerMonitoredTagKeysMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsEc2query_serializeOpUpdateCapacityManagerMonitoredTagKeys{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsEc2query_deserializeOpUpdateCapacityManagerMonitoredTagKeys{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addIdempotencyToken_opUpdateCapacityManagerMonitoredTagKeysMiddleware(stack, options); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "UpdateCapacityManagerMonitoredTagKeys"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}

type idempotencyToken_initializeOpUpdateCapacityManagerMonitoredTagKeys struct {
	tokenProvider IdempotencyTokenProvider
}

func (*idempotencyToken_initializeOpUpdateCapacityManagerMonitoredTagKeys) ID() string {
	return "OperationIdempotencyTokenAutoFill"
}

func (m *idempotencyToken_initializeOpUpdateCapacityManagerMonitoredTagKeys) HandleInitialize(ctx context.Context, in middleware.InitializeInput, next middleware.InitializeHandler) (
	out middleware.InitializeOutput, metadata middleware.Metadata, err error,
) {
	if m.tokenProvider == nil {
		return next.HandleInitialize(ctx, in)
	}

	input, ok := in.Parameters.(*UpdateCapacityManagerMonitoredTagKeysInput)
	if !ok {
		return out, metadata, fmt.Errorf("expected middleware input to be of type *UpdateCapacityManagerMonitoredTagKeysInput ")
	}

	if input.ClientToken == nil {
		t, err := m.tokenProvider.GetIdempotencyToken()
		if err != nil {
			return out, metadata, err
		}
		input.ClientToken = &t
	}
	return next.HandleInitialize(ctx, in)
}
func addIdempotencyToken_opUpdateCapacityManagerMonitoredTagKeysMiddleware(stack *middleware.Stack, cfg Options) error {
	return stack.Initialize.Add(&idempotencyToken_initializeOpUpdateCapacityManagerMonitoredTagKeys{tokenProvider: cfg.IdempotencyTokenProvider}, middleware.Before)
}
