// Code generated by smithy-go-codegen DO NOT EDIT.

// Package devopsguru provides the API client, operations, and parameter types for
// Amazon DevOps Guru.
//
//	Amazon DevOps Guru is a fully managed service that helps you identify
//
// anomalous behavior in business critical operational applications. You specify
// the Amazon Web Services resources that you want DevOps Guru to cover, then the
// Amazon CloudWatch metrics and Amazon Web Services CloudTrail events related to
// those resources are analyzed. When anomalous behavior is detected, DevOps Guru
// creates an insight that includes recommendations, related events, and related
// metrics that can help you improve your operational applications. For more
// information, see [What is Amazon DevOps Guru].
//
// You can specify 1 or 2 Amazon Simple Notification Service topics so you are
// notified every time a new insight is created. You can also enable DevOps Guru to
// generate an OpsItem in Amazon Web Services Systems Manager for each insight to
// help you manage and track your work addressing insights.
//
// To learn about the DevOps Guru workflow, see [How DevOps Guru works]. To learn about DevOps Guru
// concepts, see [Concepts in DevOps Guru].
//
// [How DevOps Guru works]: https://docs.aws.amazon.com/devops-guru/latest/userguide/welcome.html#how-it-works
// [What is Amazon DevOps Guru]: https://docs.aws.amazon.com/devops-guru/latest/userguide/welcome.html
// [Concepts in DevOps Guru]: https://docs.aws.amazon.com/devops-guru/latest/userguide/concepts.html
package devopsguru
