// Code generated by smithy-go-codegen DO NOT EDIT.

package ec2

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/ec2/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Gets the allocation rules for an IPAM policy.
//
// An IPAM policy is a set of rules that define how public IPv4 addresses from
// IPAM pools are allocated to Amazon Web Services resources. Each rule maps an
// Amazon Web Services service to IPAM pools that the service will use to get IP
// addresses. A single policy can have multiple rules and be applied to multiple
// Amazon Web Services Regions. If the IPAM pool run out of addresses then the
// services fallback to Amazon-provided IP addresses. A policy can be applied to an
// individual Amazon Web Services account or an entity within Amazon Web Services
// Organizations.
//
// Allocation rules are optional configurations within an IPAM policy that map
// Amazon Web Services resource types to specific IPAM pools. If no rules are
// defined, the resource types default to using Amazon-provided IP addresses.
func (c *Client) GetIpamPolicyAllocationRules(ctx context.Context, params *GetIpamPolicyAllocationRulesInput, optFns ...func(*Options)) (*GetIpamPolicyAllocationRulesOutput, error) {
	if params == nil {
		params = &GetIpamPolicyAllocationRulesInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetIpamPolicyAllocationRules", params, optFns, c.addOperationGetIpamPolicyAllocationRulesMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetIpamPolicyAllocationRulesOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetIpamPolicyAllocationRulesInput struct {

	// The ID of the IPAM policy for which to get allocation rules.
	//
	// This member is required.
	IpamPolicyId *string

	// A check for whether you have the required permissions for the action without
	// actually making the request and provides an error response. If you have the
	// required permissions, the error response is DryRunOperation . Otherwise, it is
	// UnauthorizedOperation .
	DryRun *bool

	// One or more filters for the allocation rules.
	Filters []types.Filter

	// The locale for which to get the allocation rules.
	Locale *string

	// The maximum number of results to return in a single call.
	MaxResults *int32

	// The token for the next page of results.
	NextToken *string

	// The resource type for which to get the allocation rules.
	//
	// The Amazon Web Services service or resource type that can use IP addresses
	// through IPAM policies. Supported services and resource types include:
	//
	//   - Elastic IP addresses
	ResourceType types.IpamPolicyResourceType

	noSmithyDocumentSerde
}

type GetIpamPolicyAllocationRulesOutput struct {

	// The IPAM policy documents containing the allocation rules.
	//
	// Allocation rules are optional configurations within an IPAM policy that map
	// Amazon Web Services resource types to specific IPAM pools. If no rules are
	// defined, the resource types default to using Amazon-provided IP addresses.
	IpamPolicyDocuments []types.IpamPolicyDocument

	// The token to use to retrieve the next page of results.
	NextToken *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetIpamPolicyAllocationRulesMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsEc2query_serializeOpGetIpamPolicyAllocationRules{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsEc2query_deserializeOpGetIpamPolicyAllocationRules{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetIpamPolicyAllocationRulesValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetIpamPolicyAllocationRules"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
