// Code generated by smithy-go-codegen DO NOT EDIT.

package acm

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/acm/types"
	"github.com/aws/smithy-go/middleware"
	"github.com/aws/smithy-go/ptr"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Updates the prevalidation configuration of an existing domain validation.
func (c *Client) UpdateAcmeDomainValidation(ctx context.Context, params *UpdateAcmeDomainValidationInput, optFns ...func(*Options)) (*UpdateAcmeDomainValidationOutput, error) {
	if params == nil {
		params = &UpdateAcmeDomainValidationInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "UpdateAcmeDomainValidation", params, optFns, c.addOperationUpdateAcmeDomainValidationMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*UpdateAcmeDomainValidationOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type UpdateAcmeDomainValidationInput struct {

	// The Amazon Resource Name (ARN) of the ACME domain validation to update.
	//
	// This member is required.
	AcmeDomainValidationArn *string

	// The updated prevalidation options.
	PrevalidationOptions types.PrevalidationOptions

	noSmithyDocumentSerde
}

func (in *UpdateAcmeDomainValidationInput) bindEndpointParams(p *EndpointParameters) {

	p.ServiceType = ptr.String("ACM-ACME")
}

type UpdateAcmeDomainValidationOutput struct {
	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationUpdateAcmeDomainValidationMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson11_serializeOpUpdateAcmeDomainValidation{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson11_deserializeOpUpdateAcmeDomainValidation{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpUpdateAcmeDomainValidationValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "UpdateAcmeDomainValidation"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
