// Code generated by smithy-go-codegen DO NOT EDIT.

package bedrockagentcorecontrol

import (
	"context"
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/bedrockagentcorecontrol/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Update an Amazon Bedrock AgentCore Memory resource memory.
func (c *Client) UpdateMemory(ctx context.Context, params *UpdateMemoryInput, optFns ...func(*Options)) (*UpdateMemoryOutput, error) {
	if params == nil {
		params = &UpdateMemoryInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "UpdateMemory", params, optFns, c.addOperationUpdateMemoryMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*UpdateMemoryOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type UpdateMemoryInput struct {

	// The unique identifier of the memory to update.
	//
	// This member is required.
	MemoryId *string

	// Additional metadata keys to index. Previously indexed keys cannot be removed.
	AddIndexedKeys []types.IndexedKey

	// A client token is used for keeping track of idempotent requests. It can contain
	// a session id which can be around 250 chars, combined with a unique AWS
	// identifier.
	ClientToken *string

	// The updated description of the AgentCore Memory resource.
	Description *string

	// The number of days after which memory events will expire, between 7 and 365
	// days.
	EventExpiryDuration *int32

	// The ARN of the IAM role that provides permissions for the AgentCore Memory
	// resource.
	MemoryExecutionRoleArn *string

	// The memory strategies to add, modify, or delete.
	MemoryStrategies *types.ModifyMemoryStrategies

	// Configuration for streaming memory record data to external resources.
	StreamDeliveryResources *types.StreamDeliveryResources

	noSmithyDocumentSerde
}

type UpdateMemoryOutput struct {

	// The updated AgentCore Memory resource details.
	Memory *types.Memory

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationUpdateMemoryMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpUpdateMemory{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpUpdateMemory{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addIdempotencyToken_opUpdateMemoryMiddleware(stack, options); err != nil {
		return err
	}
	if err = addOpUpdateMemoryValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "UpdateMemory"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}

type idempotencyToken_initializeOpUpdateMemory struct {
	tokenProvider IdempotencyTokenProvider
}

func (*idempotencyToken_initializeOpUpdateMemory) ID() string {
	return "OperationIdempotencyTokenAutoFill"
}

func (m *idempotencyToken_initializeOpUpdateMemory) HandleInitialize(ctx context.Context, in middleware.InitializeInput, next middleware.InitializeHandler) (
	out middleware.InitializeOutput, metadata middleware.Metadata, err error,
) {
	if m.tokenProvider == nil {
		return next.HandleInitialize(ctx, in)
	}

	input, ok := in.Parameters.(*UpdateMemoryInput)
	if !ok {
		return out, metadata, fmt.Errorf("expected middleware input to be of type *UpdateMemoryInput ")
	}

	if input.ClientToken == nil {
		t, err := m.tokenProvider.GetIdempotencyToken()
		if err != nil {
			return out, metadata, err
		}
		input.ClientToken = &t
	}
	return next.HandleInitialize(ctx, in)
}
func addIdempotencyToken_opUpdateMemoryMiddleware(stack *middleware.Stack, cfg Options) error {
	return stack.Initialize.Add(&idempotencyToken_initializeOpUpdateMemory{tokenProvider: cfg.IdempotencyTokenProvider}, middleware.Before)
}
