// Code generated by internal/repotools/cmd/updatemodulemeta DO NOT EDIT.

package costandusagereportservice

// goModuleVersion is the tagged release for this module
const goModuleVersion = "1.35.7"
