// Code generated by smithy-go-codegen DO NOT EDIT.

package datazone

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/datazone/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
	"time"
)

// Gets an evinronment profile in Amazon DataZone.
func (c *Client) GetEnvironmentProfile(ctx context.Context, params *GetEnvironmentProfileInput, optFns ...func(*Options)) (*GetEnvironmentProfileOutput, error) {
	if params == nil {
		params = &GetEnvironmentProfileInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetEnvironmentProfile", params, optFns, c.addOperationGetEnvironmentProfileMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetEnvironmentProfileOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetEnvironmentProfileInput struct {

	// The ID of the Amazon DataZone domain in which this environment profile exists.
	//
	// This member is required.
	DomainIdentifier *string

	// The ID of the environment profile.
	//
	// This member is required.
	Identifier *string

	noSmithyDocumentSerde
}

type GetEnvironmentProfileOutput struct {

	// The Amazon DataZone user who created this environment profile.
	//
	// This member is required.
	CreatedBy *string

	// The ID of the Amazon DataZone domain in which this environment profile exists.
	//
	// This member is required.
	DomainId *string

	// The ID of the blueprint with which this environment profile is created.
	//
	// This member is required.
	EnvironmentBlueprintId *string

	// The ID of the environment profile.
	//
	// This member is required.
	Id *string

	// The name of the environment profile.
	//
	// This member is required.
	Name *string

	// The ID of the Amazon Web Services account where this environment profile exists.
	AwsAccountId *string

	// The Amazon Web Services region where this environment profile exists.
	AwsAccountRegion *string

	// The timestamp of when this environment profile was created.
	CreatedAt *time.Time

	// The description of the environment profile.
	Description *string

	// The ID of the Amazon DataZone project in which this environment profile is
	// created.
	ProjectId *string

	// The timestamp of when this environment profile was upated.
	UpdatedAt *time.Time

	// The user parameters of the environment profile.
	UserParameters []types.CustomParameter

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetEnvironmentProfileMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpGetEnvironmentProfile{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpGetEnvironmentProfile{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetEnvironmentProfileValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetEnvironmentProfile"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
