// Code generated by smithy-go-codegen DO NOT EDIT.

package computeoptimizerautomation

import (
	"context"
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/computeoptimizerautomation/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Returns a summary of the recommended actions that match your rule preview
// configuration and criteria.
func (c *Client) ListAutomationRulePreviewSummaries(ctx context.Context, params *ListAutomationRulePreviewSummariesInput, optFns ...func(*Options)) (*ListAutomationRulePreviewSummariesOutput, error) {
	if params == nil {
		params = &ListAutomationRulePreviewSummariesInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "ListAutomationRulePreviewSummaries", params, optFns, c.addOperationListAutomationRulePreviewSummariesMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*ListAutomationRulePreviewSummariesOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type ListAutomationRulePreviewSummariesInput struct {

	// The types of recommended actions to include in the preview.
	//
	// This member is required.
	RecommendedActionTypes []types.RecommendedActionType

	// The type of rule.
	//
	// This member is required.
	RuleType types.RuleType

	//  A set of conditions that specify which recommended action qualify for
	// implementation. When a rule is active and a recommended action matches these
	// criteria, Compute Optimizer implements the action at the scheduled run time. You
	// can specify up to 20 conditions per filter criteria and 20 values per condition.
	Criteria *types.Criteria

	// The maximum number of automation rule preview summaries to return in a single
	// response. Valid range is 1-1000.
	MaxResults *int32

	// A token used for pagination to retrieve the next set of results when the
	// response is truncated.
	NextToken *string

	// The organizational scope for the rule preview.
	OrganizationScope *types.OrganizationScope

	noSmithyDocumentSerde
}

type ListAutomationRulePreviewSummariesOutput struct {

	// A token used for pagination. If present, indicates there are more results
	// available and can be used in subsequent requests.
	NextToken *string

	// The list of automation rule preview summaries that match the specified criteria.
	PreviewResultSummaries []types.PreviewResultSummary

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationListAutomationRulePreviewSummariesMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&smithyRpcv2cbor_serializeOpListAutomationRulePreviewSummaries{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&smithyRpcv2cbor_deserializeOpListAutomationRulePreviewSummaries{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addUserAgentFeatureProtocolRPCV2CBOR(stack, options); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpListAutomationRulePreviewSummariesValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "ListAutomationRulePreviewSummaries"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}

// ListAutomationRulePreviewSummariesPaginatorOptions is the paginator options for
// ListAutomationRulePreviewSummaries
type ListAutomationRulePreviewSummariesPaginatorOptions struct {
	// The maximum number of automation rule preview summaries to return in a single
	// response. Valid range is 1-1000.
	Limit int32

	// Set to true if pagination should stop if the service returns a pagination token
	// that matches the most recent token provided to the service.
	StopOnDuplicateToken bool
}

// ListAutomationRulePreviewSummariesPaginator is a paginator for
// ListAutomationRulePreviewSummaries
type ListAutomationRulePreviewSummariesPaginator struct {
	options   ListAutomationRulePreviewSummariesPaginatorOptions
	client    ListAutomationRulePreviewSummariesAPIClient
	params    *ListAutomationRulePreviewSummariesInput
	nextToken *string
	firstPage bool
}

// NewListAutomationRulePreviewSummariesPaginator returns a new
// ListAutomationRulePreviewSummariesPaginator
func NewListAutomationRulePreviewSummariesPaginator(client ListAutomationRulePreviewSummariesAPIClient, params *ListAutomationRulePreviewSummariesInput, optFns ...func(*ListAutomationRulePreviewSummariesPaginatorOptions)) *ListAutomationRulePreviewSummariesPaginator {
	if params == nil {
		params = &ListAutomationRulePreviewSummariesInput{}
	}

	options := ListAutomationRulePreviewSummariesPaginatorOptions{}
	if params.MaxResults != nil {
		options.Limit = *params.MaxResults
	}

	for _, fn := range optFns {
		fn(&options)
	}

	return &ListAutomationRulePreviewSummariesPaginator{
		options:   options,
		client:    client,
		params:    params,
		firstPage: true,
		nextToken: params.NextToken,
	}
}

// HasMorePages returns a boolean indicating whether more pages are available
func (p *ListAutomationRulePreviewSummariesPaginator) HasMorePages() bool {
	return p.firstPage || (p.nextToken != nil && len(*p.nextToken) != 0)
}

// NextPage retrieves the next ListAutomationRulePreviewSummaries page.
func (p *ListAutomationRulePreviewSummariesPaginator) NextPage(ctx context.Context, optFns ...func(*Options)) (*ListAutomationRulePreviewSummariesOutput, error) {
	if !p.HasMorePages() {
		return nil, fmt.Errorf("no more pages available")
	}

	params := *p.params
	params.NextToken = p.nextToken

	var limit *int32
	if p.options.Limit > 0 {
		limit = &p.options.Limit
	}
	params.MaxResults = limit

	optFns = append([]func(*Options){
		addIsPaginatorUserAgent,
	}, optFns...)
	result, err := p.client.ListAutomationRulePreviewSummaries(ctx, &params, optFns...)
	if err != nil {
		return nil, err
	}
	p.firstPage = false

	prevToken := p.nextToken
	p.nextToken = result.NextToken

	if p.options.StopOnDuplicateToken &&
		prevToken != nil &&
		p.nextToken != nil &&
		*prevToken == *p.nextToken {
		p.nextToken = nil
	}

	return result, nil
}

// ListAutomationRulePreviewSummariesAPIClient is a client that implements the
// ListAutomationRulePreviewSummaries operation.
type ListAutomationRulePreviewSummariesAPIClient interface {
	ListAutomationRulePreviewSummaries(context.Context, *ListAutomationRulePreviewSummariesInput, ...func(*Options)) (*ListAutomationRulePreviewSummariesOutput, error)
}

var _ ListAutomationRulePreviewSummariesAPIClient = (*Client)(nil)
