// Code generated by smithy-go-codegen DO NOT EDIT.

package controltower

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/controltower/document"
	"github.com/aws/aws-sdk-go-v2/service/controltower/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Creates a new landing zone. This API call starts an asynchronous operation that
// creates and configures a landing zone, based on the parameters specified in the
// manifest JSON file.
func (c *Client) CreateLandingZone(ctx context.Context, params *CreateLandingZoneInput, optFns ...func(*Options)) (*CreateLandingZoneOutput, error) {
	if params == nil {
		params = &CreateLandingZoneInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "CreateLandingZone", params, optFns, c.addOperationCreateLandingZoneMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*CreateLandingZoneOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type CreateLandingZoneInput struct {

	// The landing zone version, for example, 3.0.
	//
	// This member is required.
	Version *string

	// The manifest JSON file is a text file that describes your Amazon Web Services
	// resources. For examples, review [Launch your landing zone].
	//
	// [Launch your landing zone]: https://docs.aws.amazon.com/controltower/latest/userguide/lz-api-launch
	Manifest document.Interface

	// Specifies the types of remediation actions to apply when creating the landing
	// zone, such as automatic drift correction or compliance enforcement.
	RemediationTypes []types.RemediationType

	// Tags to be applied to the landing zone.
	Tags map[string]string

	noSmithyDocumentSerde
}

type CreateLandingZoneOutput struct {

	// The ARN of the landing zone resource.
	//
	// This member is required.
	Arn *string

	// A unique identifier assigned to a CreateLandingZone operation. You can use this
	// identifier as an input of GetLandingZoneOperation to check the operation's
	// status.
	//
	// This member is required.
	OperationIdentifier *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationCreateLandingZoneMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpCreateLandingZone{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpCreateLandingZone{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpCreateLandingZoneValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "CreateLandingZone"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
