// Code generated by smithy-go-codegen DO NOT EDIT.

package drs

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/drs/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Stops replication for a Source Network. This action would make the Source
// Network unprotected.
func (c *Client) StopSourceNetworkReplication(ctx context.Context, params *StopSourceNetworkReplicationInput, optFns ...func(*Options)) (*StopSourceNetworkReplicationOutput, error) {
	if params == nil {
		params = &StopSourceNetworkReplicationInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "StopSourceNetworkReplication", params, optFns, c.addOperationStopSourceNetworkReplicationMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*StopSourceNetworkReplicationOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type StopSourceNetworkReplicationInput struct {

	// ID of the Source Network to stop replication.
	//
	// This member is required.
	SourceNetworkID *string

	noSmithyDocumentSerde
}

type StopSourceNetworkReplicationOutput struct {

	// Source Network which was requested to stop replication.
	SourceNetwork *types.SourceNetwork

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationStopSourceNetworkReplicationMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpStopSourceNetworkReplication{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpStopSourceNetworkReplication{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpStopSourceNetworkReplicationValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "StopSourceNetworkReplication"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
