// Code generated by smithy-go-codegen DO NOT EDIT.

package cloudfront

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/cloudfront/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Updates a CloudFront origin access control.
func (c *Client) UpdateOriginAccessControl(ctx context.Context, params *UpdateOriginAccessControlInput, optFns ...func(*Options)) (*UpdateOriginAccessControlOutput, error) {
	if params == nil {
		params = &UpdateOriginAccessControlInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "UpdateOriginAccessControl", params, optFns, c.addOperationUpdateOriginAccessControlMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*UpdateOriginAccessControlOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type UpdateOriginAccessControlInput struct {

	// The unique identifier of the origin access control that you are updating.
	//
	// This member is required.
	Id *string

	// An origin access control.
	//
	// This member is required.
	OriginAccessControlConfig *types.OriginAccessControlConfig

	// The current version ( ETag value) of the origin access control that you are
	// updating.
	IfMatch *string

	noSmithyDocumentSerde
}

type UpdateOriginAccessControlOutput struct {

	// The new version of the origin access control after it has been updated.
	ETag *string

	// The origin access control after it has been updated.
	OriginAccessControl *types.OriginAccessControl

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationUpdateOriginAccessControlMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestxml_serializeOpUpdateOriginAccessControl{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestxml_deserializeOpUpdateOriginAccessControl{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpUpdateOriginAccessControlValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "UpdateOriginAccessControl"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
