// Code generated by smithy-go-codegen DO NOT EDIT.

package types

type AdvancedPromptOptimizationJobStatus string

// Enum values for AdvancedPromptOptimizationJobStatus
const (
	AdvancedPromptOptimizationJobStatusInProgress         AdvancedPromptOptimizationJobStatus = "InProgress"
	AdvancedPromptOptimizationJobStatusCompleted          AdvancedPromptOptimizationJobStatus = "Completed"
	AdvancedPromptOptimizationJobStatusFailed             AdvancedPromptOptimizationJobStatus = "Failed"
	AdvancedPromptOptimizationJobStatusPartiallyCompleted AdvancedPromptOptimizationJobStatus = "PartiallyCompleted"
	AdvancedPromptOptimizationJobStatusStopping           AdvancedPromptOptimizationJobStatus = "Stopping"
	AdvancedPromptOptimizationJobStatusStopped            AdvancedPromptOptimizationJobStatus = "Stopped"
	AdvancedPromptOptimizationJobStatusDeleting           AdvancedPromptOptimizationJobStatus = "Deleting"
)

// Values returns all known values for AdvancedPromptOptimizationJobStatus. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AdvancedPromptOptimizationJobStatus) Values() []AdvancedPromptOptimizationJobStatus {
	return []AdvancedPromptOptimizationJobStatus{
		"InProgress",
		"Completed",
		"Failed",
		"PartiallyCompleted",
		"Stopping",
		"Stopped",
		"Deleting",
	}
}

type AgreementStatus string

// Enum values for AgreementStatus
const (
	AgreementStatusAvailable    AgreementStatus = "AVAILABLE"
	AgreementStatusPending      AgreementStatus = "PENDING"
	AgreementStatusNotAvailable AgreementStatus = "NOT_AVAILABLE"
	AgreementStatusError        AgreementStatus = "ERROR"
)

// Values returns all known values for AgreementStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AgreementStatus) Values() []AgreementStatus {
	return []AgreementStatus{
		"AVAILABLE",
		"PENDING",
		"NOT_AVAILABLE",
		"ERROR",
	}
}

type ApplicationType string

// Enum values for ApplicationType
const (
	ApplicationTypeModelEvaluation ApplicationType = "ModelEvaluation"
	ApplicationTypeRagEvaluation   ApplicationType = "RagEvaluation"
)

// Values returns all known values for ApplicationType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ApplicationType) Values() []ApplicationType {
	return []ApplicationType{
		"ModelEvaluation",
		"RagEvaluation",
	}
}

type AttributeType string

// Enum values for AttributeType
const (
	AttributeTypeString     AttributeType = "STRING"
	AttributeTypeNumber     AttributeType = "NUMBER"
	AttributeTypeBoolean    AttributeType = "BOOLEAN"
	AttributeTypeStringList AttributeType = "STRING_LIST"
)

// Values returns all known values for AttributeType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AttributeType) Values() []AttributeType {
	return []AttributeType{
		"STRING",
		"NUMBER",
		"BOOLEAN",
		"STRING_LIST",
	}
}

type AuthorizationStatus string

// Enum values for AuthorizationStatus
const (
	AuthorizationStatusAuthorized    AuthorizationStatus = "AUTHORIZED"
	AuthorizationStatusNotAuthorized AuthorizationStatus = "NOT_AUTHORIZED"
)

// Values returns all known values for AuthorizationStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AuthorizationStatus) Values() []AuthorizationStatus {
	return []AuthorizationStatus{
		"AUTHORIZED",
		"NOT_AUTHORIZED",
	}
}

type AutomatedReasoningCheckLogicWarningType string

// Enum values for AutomatedReasoningCheckLogicWarningType
const (
	AutomatedReasoningCheckLogicWarningTypeAlwaysTrue  AutomatedReasoningCheckLogicWarningType = "ALWAYS_TRUE"
	AutomatedReasoningCheckLogicWarningTypeAlwaysFalse AutomatedReasoningCheckLogicWarningType = "ALWAYS_FALSE"
)

// Values returns all known values for AutomatedReasoningCheckLogicWarningType.
// Note that this can be expanded in the future, and so it is only as up to date as
// the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AutomatedReasoningCheckLogicWarningType) Values() []AutomatedReasoningCheckLogicWarningType {
	return []AutomatedReasoningCheckLogicWarningType{
		"ALWAYS_TRUE",
		"ALWAYS_FALSE",
	}
}

type AutomatedReasoningCheckResult string

// Enum values for AutomatedReasoningCheckResult
const (
	AutomatedReasoningCheckResultValid                AutomatedReasoningCheckResult = "VALID"
	AutomatedReasoningCheckResultInvalid              AutomatedReasoningCheckResult = "INVALID"
	AutomatedReasoningCheckResultSatisfiable          AutomatedReasoningCheckResult = "SATISFIABLE"
	AutomatedReasoningCheckResultImpossible           AutomatedReasoningCheckResult = "IMPOSSIBLE"
	AutomatedReasoningCheckResultTranslationAmbiguous AutomatedReasoningCheckResult = "TRANSLATION_AMBIGUOUS"
	AutomatedReasoningCheckResultTooComplex           AutomatedReasoningCheckResult = "TOO_COMPLEX"
	AutomatedReasoningCheckResultNoTranslation        AutomatedReasoningCheckResult = "NO_TRANSLATION"
)

// Values returns all known values for AutomatedReasoningCheckResult. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AutomatedReasoningCheckResult) Values() []AutomatedReasoningCheckResult {
	return []AutomatedReasoningCheckResult{
		"VALID",
		"INVALID",
		"SATISFIABLE",
		"IMPOSSIBLE",
		"TRANSLATION_AMBIGUOUS",
		"TOO_COMPLEX",
		"NO_TRANSLATION",
	}
}

type AutomatedReasoningPolicyAnnotationStatus string

// Enum values for AutomatedReasoningPolicyAnnotationStatus
const (
	AutomatedReasoningPolicyAnnotationStatusApplied AutomatedReasoningPolicyAnnotationStatus = "APPLIED"
	AutomatedReasoningPolicyAnnotationStatusFailed  AutomatedReasoningPolicyAnnotationStatus = "FAILED"
)

// Values returns all known values for AutomatedReasoningPolicyAnnotationStatus.
// Note that this can be expanded in the future, and so it is only as up to date as
// the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AutomatedReasoningPolicyAnnotationStatus) Values() []AutomatedReasoningPolicyAnnotationStatus {
	return []AutomatedReasoningPolicyAnnotationStatus{
		"APPLIED",
		"FAILED",
	}
}

type AutomatedReasoningPolicyBuildDocumentContentType string

// Enum values for AutomatedReasoningPolicyBuildDocumentContentType
const (
	AutomatedReasoningPolicyBuildDocumentContentTypePdf  AutomatedReasoningPolicyBuildDocumentContentType = "pdf"
	AutomatedReasoningPolicyBuildDocumentContentTypeText AutomatedReasoningPolicyBuildDocumentContentType = "txt"
)

// Values returns all known values for
// AutomatedReasoningPolicyBuildDocumentContentType. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AutomatedReasoningPolicyBuildDocumentContentType) Values() []AutomatedReasoningPolicyBuildDocumentContentType {
	return []AutomatedReasoningPolicyBuildDocumentContentType{
		"pdf",
		"txt",
	}
}

type AutomatedReasoningPolicyBuildMessageType string

// Enum values for AutomatedReasoningPolicyBuildMessageType
const (
	AutomatedReasoningPolicyBuildMessageTypeInfo    AutomatedReasoningPolicyBuildMessageType = "INFO"
	AutomatedReasoningPolicyBuildMessageTypeWarning AutomatedReasoningPolicyBuildMessageType = "WARNING"
	AutomatedReasoningPolicyBuildMessageTypeError   AutomatedReasoningPolicyBuildMessageType = "ERROR"
)

// Values returns all known values for AutomatedReasoningPolicyBuildMessageType.
// Note that this can be expanded in the future, and so it is only as up to date as
// the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AutomatedReasoningPolicyBuildMessageType) Values() []AutomatedReasoningPolicyBuildMessageType {
	return []AutomatedReasoningPolicyBuildMessageType{
		"INFO",
		"WARNING",
		"ERROR",
	}
}

type AutomatedReasoningPolicyBuildResultAssetType string

// Enum values for AutomatedReasoningPolicyBuildResultAssetType
const (
	AutomatedReasoningPolicyBuildResultAssetTypeBuildLog           AutomatedReasoningPolicyBuildResultAssetType = "BUILD_LOG"
	AutomatedReasoningPolicyBuildResultAssetTypeQualityReport      AutomatedReasoningPolicyBuildResultAssetType = "QUALITY_REPORT"
	AutomatedReasoningPolicyBuildResultAssetTypePolicyDefinition   AutomatedReasoningPolicyBuildResultAssetType = "POLICY_DEFINITION"
	AutomatedReasoningPolicyBuildResultAssetTypeGeneratedTestCases AutomatedReasoningPolicyBuildResultAssetType = "GENERATED_TEST_CASES"
	AutomatedReasoningPolicyBuildResultAssetTypePolicyScenarios    AutomatedReasoningPolicyBuildResultAssetType = "POLICY_SCENARIOS"
	AutomatedReasoningPolicyBuildResultAssetTypeFidelityReport     AutomatedReasoningPolicyBuildResultAssetType = "FIDELITY_REPORT"
	AutomatedReasoningPolicyBuildResultAssetTypeAssetManifest      AutomatedReasoningPolicyBuildResultAssetType = "ASSET_MANIFEST"
	AutomatedReasoningPolicyBuildResultAssetTypeSourceDocument     AutomatedReasoningPolicyBuildResultAssetType = "SOURCE_DOCUMENT"
)

// Values returns all known values for
// AutomatedReasoningPolicyBuildResultAssetType. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AutomatedReasoningPolicyBuildResultAssetType) Values() []AutomatedReasoningPolicyBuildResultAssetType {
	return []AutomatedReasoningPolicyBuildResultAssetType{
		"BUILD_LOG",
		"QUALITY_REPORT",
		"POLICY_DEFINITION",
		"GENERATED_TEST_CASES",
		"POLICY_SCENARIOS",
		"FIDELITY_REPORT",
		"ASSET_MANIFEST",
		"SOURCE_DOCUMENT",
	}
}

type AutomatedReasoningPolicyBuildWorkflowStatus string

// Enum values for AutomatedReasoningPolicyBuildWorkflowStatus
const (
	AutomatedReasoningPolicyBuildWorkflowStatusScheduled       AutomatedReasoningPolicyBuildWorkflowStatus = "SCHEDULED"
	AutomatedReasoningPolicyBuildWorkflowStatusCancelRequested AutomatedReasoningPolicyBuildWorkflowStatus = "CANCEL_REQUESTED"
	AutomatedReasoningPolicyBuildWorkflowStatusPreprocessing   AutomatedReasoningPolicyBuildWorkflowStatus = "PREPROCESSING"
	AutomatedReasoningPolicyBuildWorkflowStatusBuilding        AutomatedReasoningPolicyBuildWorkflowStatus = "BUILDING"
	AutomatedReasoningPolicyBuildWorkflowStatusTesting         AutomatedReasoningPolicyBuildWorkflowStatus = "TESTING"
	AutomatedReasoningPolicyBuildWorkflowStatusCompleted       AutomatedReasoningPolicyBuildWorkflowStatus = "COMPLETED"
	AutomatedReasoningPolicyBuildWorkflowStatusFailed          AutomatedReasoningPolicyBuildWorkflowStatus = "FAILED"
	AutomatedReasoningPolicyBuildWorkflowStatusCancelled       AutomatedReasoningPolicyBuildWorkflowStatus = "CANCELLED"
)

// Values returns all known values for
// AutomatedReasoningPolicyBuildWorkflowStatus. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AutomatedReasoningPolicyBuildWorkflowStatus) Values() []AutomatedReasoningPolicyBuildWorkflowStatus {
	return []AutomatedReasoningPolicyBuildWorkflowStatus{
		"SCHEDULED",
		"CANCEL_REQUESTED",
		"PREPROCESSING",
		"BUILDING",
		"TESTING",
		"COMPLETED",
		"FAILED",
		"CANCELLED",
	}
}

type AutomatedReasoningPolicyBuildWorkflowType string

// Enum values for AutomatedReasoningPolicyBuildWorkflowType
const (
	AutomatedReasoningPolicyBuildWorkflowTypeIngestContent            AutomatedReasoningPolicyBuildWorkflowType = "INGEST_CONTENT"
	AutomatedReasoningPolicyBuildWorkflowTypeRefinePolicy             AutomatedReasoningPolicyBuildWorkflowType = "REFINE_POLICY"
	AutomatedReasoningPolicyBuildWorkflowTypeImportPolicy             AutomatedReasoningPolicyBuildWorkflowType = "IMPORT_POLICY"
	AutomatedReasoningPolicyBuildWorkflowTypeGenerateFidelityReport   AutomatedReasoningPolicyBuildWorkflowType = "GENERATE_FIDELITY_REPORT"
	AutomatedReasoningPolicyBuildWorkflowTypeGeneratePolicyScenarios  AutomatedReasoningPolicyBuildWorkflowType = "GENERATE_POLICY_SCENARIOS"
	AutomatedReasoningPolicyBuildWorkflowTypeResolvePolicyAmbiguities AutomatedReasoningPolicyBuildWorkflowType = "RESOLVE_POLICY_AMBIGUITIES"
	AutomatedReasoningPolicyBuildWorkflowTypeIterativelyRefinePolicy  AutomatedReasoningPolicyBuildWorkflowType = "ITERATIVELY_REFINE_POLICY"
)

// Values returns all known values for AutomatedReasoningPolicyBuildWorkflowType.
// Note that this can be expanded in the future, and so it is only as up to date as
// the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AutomatedReasoningPolicyBuildWorkflowType) Values() []AutomatedReasoningPolicyBuildWorkflowType {
	return []AutomatedReasoningPolicyBuildWorkflowType{
		"INGEST_CONTENT",
		"REFINE_POLICY",
		"IMPORT_POLICY",
		"GENERATE_FIDELITY_REPORT",
		"GENERATE_POLICY_SCENARIOS",
		"RESOLVE_POLICY_AMBIGUITIES",
		"ITERATIVELY_REFINE_POLICY",
	}
}

type AutomatedReasoningPolicyTestRunResult string

// Enum values for AutomatedReasoningPolicyTestRunResult
const (
	AutomatedReasoningPolicyTestRunResultPassed AutomatedReasoningPolicyTestRunResult = "PASSED"
	AutomatedReasoningPolicyTestRunResultFailed AutomatedReasoningPolicyTestRunResult = "FAILED"
)

// Values returns all known values for AutomatedReasoningPolicyTestRunResult. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AutomatedReasoningPolicyTestRunResult) Values() []AutomatedReasoningPolicyTestRunResult {
	return []AutomatedReasoningPolicyTestRunResult{
		"PASSED",
		"FAILED",
	}
}

type AutomatedReasoningPolicyTestRunStatus string

// Enum values for AutomatedReasoningPolicyTestRunStatus
const (
	AutomatedReasoningPolicyTestRunStatusNotStarted AutomatedReasoningPolicyTestRunStatus = "NOT_STARTED"
	AutomatedReasoningPolicyTestRunStatusScheduled  AutomatedReasoningPolicyTestRunStatus = "SCHEDULED"
	AutomatedReasoningPolicyTestRunStatusInProgress AutomatedReasoningPolicyTestRunStatus = "IN_PROGRESS"
	AutomatedReasoningPolicyTestRunStatusCompleted  AutomatedReasoningPolicyTestRunStatus = "COMPLETED"
	AutomatedReasoningPolicyTestRunStatusFailed     AutomatedReasoningPolicyTestRunStatus = "FAILED"
)

// Values returns all known values for AutomatedReasoningPolicyTestRunStatus. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (AutomatedReasoningPolicyTestRunStatus) Values() []AutomatedReasoningPolicyTestRunStatus {
	return []AutomatedReasoningPolicyTestRunStatus{
		"NOT_STARTED",
		"SCHEDULED",
		"IN_PROGRESS",
		"COMPLETED",
		"FAILED",
	}
}

type CommitmentDuration string

// Enum values for CommitmentDuration
const (
	CommitmentDurationOneMonth  CommitmentDuration = "OneMonth"
	CommitmentDurationSixMonths CommitmentDuration = "SixMonths"
)

// Values returns all known values for CommitmentDuration. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (CommitmentDuration) Values() []CommitmentDuration {
	return []CommitmentDuration{
		"OneMonth",
		"SixMonths",
	}
}

type ConfigurationOwner string

// Enum values for ConfigurationOwner
const (
	// Configuration owned by the account
	ConfigurationOwnerAccount ConfigurationOwner = "ACCOUNT"
)

// Values returns all known values for ConfigurationOwner. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ConfigurationOwner) Values() []ConfigurationOwner {
	return []ConfigurationOwner{
		"ACCOUNT",
	}
}

type CustomizationType string

// Enum values for CustomizationType
const (
	CustomizationTypeFineTuning              CustomizationType = "FINE_TUNING"
	CustomizationTypeContinuedPreTraining    CustomizationType = "CONTINUED_PRE_TRAINING"
	CustomizationTypeDistillation            CustomizationType = "DISTILLATION"
	CustomizationTypeReinforcementFineTuning CustomizationType = "REINFORCEMENT_FINE_TUNING"
	CustomizationTypeImported                CustomizationType = "IMPORTED"
)

// Values returns all known values for CustomizationType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (CustomizationType) Values() []CustomizationType {
	return []CustomizationType{
		"FINE_TUNING",
		"CONTINUED_PRE_TRAINING",
		"DISTILLATION",
		"REINFORCEMENT_FINE_TUNING",
		"IMPORTED",
	}
}

type CustomModelDeploymentStatus string

// Enum values for CustomModelDeploymentStatus
const (
	CustomModelDeploymentStatusCreating CustomModelDeploymentStatus = "Creating"
	CustomModelDeploymentStatusActive   CustomModelDeploymentStatus = "Active"
	CustomModelDeploymentStatusFailed   CustomModelDeploymentStatus = "Failed"
)

// Values returns all known values for CustomModelDeploymentStatus. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (CustomModelDeploymentStatus) Values() []CustomModelDeploymentStatus {
	return []CustomModelDeploymentStatus{
		"Creating",
		"Active",
		"Failed",
	}
}

type CustomModelDeploymentUpdateStatus string

// Enum values for CustomModelDeploymentUpdateStatus
const (
	CustomModelDeploymentUpdateStatusUpdating        CustomModelDeploymentUpdateStatus = "Updating"
	CustomModelDeploymentUpdateStatusUpdateCompleted CustomModelDeploymentUpdateStatus = "UpdateCompleted"
	CustomModelDeploymentUpdateStatusUpdateFailed    CustomModelDeploymentUpdateStatus = "UpdateFailed"
)

// Values returns all known values for CustomModelDeploymentUpdateStatus. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (CustomModelDeploymentUpdateStatus) Values() []CustomModelDeploymentUpdateStatus {
	return []CustomModelDeploymentUpdateStatus{
		"Updating",
		"UpdateCompleted",
		"UpdateFailed",
	}
}

type DataRetentionMode string

// Enum values for DataRetentionMode
const (
	DataRetentionModeDefault           DataRetentionMode = "default"
	DataRetentionModeNone              DataRetentionMode = "none"
	DataRetentionModeProviderDataShare DataRetentionMode = "provider_data_share"
	DataRetentionModeInherit           DataRetentionMode = "inherit"
)

// Values returns all known values for DataRetentionMode. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (DataRetentionMode) Values() []DataRetentionMode {
	return []DataRetentionMode{
		"default",
		"none",
		"provider_data_share",
		"inherit",
	}
}

type EntitlementAvailability string

// Enum values for EntitlementAvailability
const (
	EntitlementAvailabilityAvailable    EntitlementAvailability = "AVAILABLE"
	EntitlementAvailabilityNotAvailable EntitlementAvailability = "NOT_AVAILABLE"
)

// Values returns all known values for EntitlementAvailability. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (EntitlementAvailability) Values() []EntitlementAvailability {
	return []EntitlementAvailability{
		"AVAILABLE",
		"NOT_AVAILABLE",
	}
}

type EvaluationJobStatus string

// Enum values for EvaluationJobStatus
const (
	EvaluationJobStatusInProgress EvaluationJobStatus = "InProgress"
	EvaluationJobStatusCompleted  EvaluationJobStatus = "Completed"
	EvaluationJobStatusFailed     EvaluationJobStatus = "Failed"
	EvaluationJobStatusStopping   EvaluationJobStatus = "Stopping"
	EvaluationJobStatusStopped    EvaluationJobStatus = "Stopped"
	EvaluationJobStatusDeleting   EvaluationJobStatus = "Deleting"
)

// Values returns all known values for EvaluationJobStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (EvaluationJobStatus) Values() []EvaluationJobStatus {
	return []EvaluationJobStatus{
		"InProgress",
		"Completed",
		"Failed",
		"Stopping",
		"Stopped",
		"Deleting",
	}
}

type EvaluationJobType string

// Enum values for EvaluationJobType
const (
	EvaluationJobTypeHuman     EvaluationJobType = "Human"
	EvaluationJobTypeAutomated EvaluationJobType = "Automated"
)

// Values returns all known values for EvaluationJobType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (EvaluationJobType) Values() []EvaluationJobType {
	return []EvaluationJobType{
		"Human",
		"Automated",
	}
}

type EvaluationTaskType string

// Enum values for EvaluationTaskType
const (
	EvaluationTaskTypeSummarization     EvaluationTaskType = "Summarization"
	EvaluationTaskTypeClassification    EvaluationTaskType = "Classification"
	EvaluationTaskTypeQuestionAndAnswer EvaluationTaskType = "QuestionAndAnswer"
	EvaluationTaskTypeGeneration        EvaluationTaskType = "Generation"
	EvaluationTaskTypeCustom            EvaluationTaskType = "Custom"
)

// Values returns all known values for EvaluationTaskType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (EvaluationTaskType) Values() []EvaluationTaskType {
	return []EvaluationTaskType{
		"Summarization",
		"Classification",
		"QuestionAndAnswer",
		"Generation",
		"Custom",
	}
}

type ExternalSourceType string

// Enum values for ExternalSourceType
const (
	ExternalSourceTypeS3          ExternalSourceType = "S3"
	ExternalSourceTypeByteContent ExternalSourceType = "BYTE_CONTENT"
)

// Values returns all known values for ExternalSourceType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ExternalSourceType) Values() []ExternalSourceType {
	return []ExternalSourceType{
		"S3",
		"BYTE_CONTENT",
	}
}

type FineTuningJobStatus string

// Enum values for FineTuningJobStatus
const (
	FineTuningJobStatusInProgress FineTuningJobStatus = "InProgress"
	FineTuningJobStatusCompleted  FineTuningJobStatus = "Completed"
	FineTuningJobStatusFailed     FineTuningJobStatus = "Failed"
	FineTuningJobStatusStopping   FineTuningJobStatus = "Stopping"
	FineTuningJobStatusStopped    FineTuningJobStatus = "Stopped"
)

// Values returns all known values for FineTuningJobStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (FineTuningJobStatus) Values() []FineTuningJobStatus {
	return []FineTuningJobStatus{
		"InProgress",
		"Completed",
		"Failed",
		"Stopping",
		"Stopped",
	}
}

type FoundationModelLifecycleStatus string

// Enum values for FoundationModelLifecycleStatus
const (
	FoundationModelLifecycleStatusActive FoundationModelLifecycleStatus = "ACTIVE"
	FoundationModelLifecycleStatusLegacy FoundationModelLifecycleStatus = "LEGACY"
)

// Values returns all known values for FoundationModelLifecycleStatus. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (FoundationModelLifecycleStatus) Values() []FoundationModelLifecycleStatus {
	return []FoundationModelLifecycleStatus{
		"ACTIVE",
		"LEGACY",
	}
}

type GuardrailContentFilterAction string

// Enum values for GuardrailContentFilterAction
const (
	GuardrailContentFilterActionBlock GuardrailContentFilterAction = "BLOCK"
	GuardrailContentFilterActionNone  GuardrailContentFilterAction = "NONE"
)

// Values returns all known values for GuardrailContentFilterAction. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailContentFilterAction) Values() []GuardrailContentFilterAction {
	return []GuardrailContentFilterAction{
		"BLOCK",
		"NONE",
	}
}

type GuardrailContentFiltersTierName string

// Enum values for GuardrailContentFiltersTierName
const (
	GuardrailContentFiltersTierNameClassic  GuardrailContentFiltersTierName = "CLASSIC"
	GuardrailContentFiltersTierNameStandard GuardrailContentFiltersTierName = "STANDARD"
)

// Values returns all known values for GuardrailContentFiltersTierName. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailContentFiltersTierName) Values() []GuardrailContentFiltersTierName {
	return []GuardrailContentFiltersTierName{
		"CLASSIC",
		"STANDARD",
	}
}

type GuardrailContentFilterType string

// Enum values for GuardrailContentFilterType
const (
	GuardrailContentFilterTypeSexual       GuardrailContentFilterType = "SEXUAL"
	GuardrailContentFilterTypeViolence     GuardrailContentFilterType = "VIOLENCE"
	GuardrailContentFilterTypeHate         GuardrailContentFilterType = "HATE"
	GuardrailContentFilterTypeInsults      GuardrailContentFilterType = "INSULTS"
	GuardrailContentFilterTypeMisconduct   GuardrailContentFilterType = "MISCONDUCT"
	GuardrailContentFilterTypePromptAttack GuardrailContentFilterType = "PROMPT_ATTACK"
)

// Values returns all known values for GuardrailContentFilterType. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailContentFilterType) Values() []GuardrailContentFilterType {
	return []GuardrailContentFilterType{
		"SEXUAL",
		"VIOLENCE",
		"HATE",
		"INSULTS",
		"MISCONDUCT",
		"PROMPT_ATTACK",
	}
}

type GuardrailContextualGroundingAction string

// Enum values for GuardrailContextualGroundingAction
const (
	GuardrailContextualGroundingActionBlock GuardrailContextualGroundingAction = "BLOCK"
	GuardrailContextualGroundingActionNone  GuardrailContextualGroundingAction = "NONE"
)

// Values returns all known values for GuardrailContextualGroundingAction. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailContextualGroundingAction) Values() []GuardrailContextualGroundingAction {
	return []GuardrailContextualGroundingAction{
		"BLOCK",
		"NONE",
	}
}

type GuardrailContextualGroundingFilterType string

// Enum values for GuardrailContextualGroundingFilterType
const (
	GuardrailContextualGroundingFilterTypeGrounding GuardrailContextualGroundingFilterType = "GROUNDING"
	GuardrailContextualGroundingFilterTypeRelevance GuardrailContextualGroundingFilterType = "RELEVANCE"
)

// Values returns all known values for GuardrailContextualGroundingFilterType.
// Note that this can be expanded in the future, and so it is only as up to date as
// the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailContextualGroundingFilterType) Values() []GuardrailContextualGroundingFilterType {
	return []GuardrailContextualGroundingFilterType{
		"GROUNDING",
		"RELEVANCE",
	}
}

type GuardrailFilterStrength string

// Enum values for GuardrailFilterStrength
const (
	GuardrailFilterStrengthNone   GuardrailFilterStrength = "NONE"
	GuardrailFilterStrengthLow    GuardrailFilterStrength = "LOW"
	GuardrailFilterStrengthMedium GuardrailFilterStrength = "MEDIUM"
	GuardrailFilterStrengthHigh   GuardrailFilterStrength = "HIGH"
)

// Values returns all known values for GuardrailFilterStrength. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailFilterStrength) Values() []GuardrailFilterStrength {
	return []GuardrailFilterStrength{
		"NONE",
		"LOW",
		"MEDIUM",
		"HIGH",
	}
}

type GuardrailManagedWordsType string

// Enum values for GuardrailManagedWordsType
const (
	GuardrailManagedWordsTypeProfanity GuardrailManagedWordsType = "PROFANITY"
)

// Values returns all known values for GuardrailManagedWordsType. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailManagedWordsType) Values() []GuardrailManagedWordsType {
	return []GuardrailManagedWordsType{
		"PROFANITY",
	}
}

type GuardrailModality string

// Enum values for GuardrailModality
const (
	GuardrailModalityText  GuardrailModality = "TEXT"
	GuardrailModalityImage GuardrailModality = "IMAGE"
)

// Values returns all known values for GuardrailModality. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailModality) Values() []GuardrailModality {
	return []GuardrailModality{
		"TEXT",
		"IMAGE",
	}
}

type GuardrailPiiEntityType string

// Enum values for GuardrailPiiEntityType
const (
	GuardrailPiiEntityTypeAddress                             GuardrailPiiEntityType = "ADDRESS"
	GuardrailPiiEntityTypeAge                                 GuardrailPiiEntityType = "AGE"
	GuardrailPiiEntityTypeAwsAccessKey                        GuardrailPiiEntityType = "AWS_ACCESS_KEY"
	GuardrailPiiEntityTypeAwsSecretKey                        GuardrailPiiEntityType = "AWS_SECRET_KEY"
	GuardrailPiiEntityTypeCaHealthNumber                      GuardrailPiiEntityType = "CA_HEALTH_NUMBER"
	GuardrailPiiEntityTypeCaSocialInsuranceNumber             GuardrailPiiEntityType = "CA_SOCIAL_INSURANCE_NUMBER"
	GuardrailPiiEntityTypeCreditDebitCardCvv                  GuardrailPiiEntityType = "CREDIT_DEBIT_CARD_CVV"
	GuardrailPiiEntityTypeCreditDebitCardExpiry               GuardrailPiiEntityType = "CREDIT_DEBIT_CARD_EXPIRY"
	GuardrailPiiEntityTypeCreditDebitCardNumber               GuardrailPiiEntityType = "CREDIT_DEBIT_CARD_NUMBER"
	GuardrailPiiEntityTypeDriverId                            GuardrailPiiEntityType = "DRIVER_ID"
	GuardrailPiiEntityTypeEmail                               GuardrailPiiEntityType = "EMAIL"
	GuardrailPiiEntityTypeInternationalBankAccountNumber      GuardrailPiiEntityType = "INTERNATIONAL_BANK_ACCOUNT_NUMBER"
	GuardrailPiiEntityTypeIpAddress                           GuardrailPiiEntityType = "IP_ADDRESS"
	GuardrailPiiEntityTypeLicensePlate                        GuardrailPiiEntityType = "LICENSE_PLATE"
	GuardrailPiiEntityTypeMacAddress                          GuardrailPiiEntityType = "MAC_ADDRESS"
	GuardrailPiiEntityTypeName                                GuardrailPiiEntityType = "NAME"
	GuardrailPiiEntityTypePassword                            GuardrailPiiEntityType = "PASSWORD"
	GuardrailPiiEntityTypePhone                               GuardrailPiiEntityType = "PHONE"
	GuardrailPiiEntityTypePin                                 GuardrailPiiEntityType = "PIN"
	GuardrailPiiEntityTypeSwiftCode                           GuardrailPiiEntityType = "SWIFT_CODE"
	GuardrailPiiEntityTypeUkNationalHealthServiceNumber       GuardrailPiiEntityType = "UK_NATIONAL_HEALTH_SERVICE_NUMBER"
	GuardrailPiiEntityTypeUkNationalInsuranceNumber           GuardrailPiiEntityType = "UK_NATIONAL_INSURANCE_NUMBER"
	GuardrailPiiEntityTypeUkUniqueTaxpayerReferenceNumber     GuardrailPiiEntityType = "UK_UNIQUE_TAXPAYER_REFERENCE_NUMBER"
	GuardrailPiiEntityTypeUrl                                 GuardrailPiiEntityType = "URL"
	GuardrailPiiEntityTypeUsername                            GuardrailPiiEntityType = "USERNAME"
	GuardrailPiiEntityTypeUsBankAccountNumber                 GuardrailPiiEntityType = "US_BANK_ACCOUNT_NUMBER"
	GuardrailPiiEntityTypeUsBankRoutingNumber                 GuardrailPiiEntityType = "US_BANK_ROUTING_NUMBER"
	GuardrailPiiEntityTypeUsIndividualTaxIdentificationNumber GuardrailPiiEntityType = "US_INDIVIDUAL_TAX_IDENTIFICATION_NUMBER"
	GuardrailPiiEntityTypeUsPassportNumber                    GuardrailPiiEntityType = "US_PASSPORT_NUMBER"
	GuardrailPiiEntityTypeUsSocialSecurityNumber              GuardrailPiiEntityType = "US_SOCIAL_SECURITY_NUMBER"
	GuardrailPiiEntityTypeVehicleIdentificationNumber         GuardrailPiiEntityType = "VEHICLE_IDENTIFICATION_NUMBER"
)

// Values returns all known values for GuardrailPiiEntityType. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailPiiEntityType) Values() []GuardrailPiiEntityType {
	return []GuardrailPiiEntityType{
		"ADDRESS",
		"AGE",
		"AWS_ACCESS_KEY",
		"AWS_SECRET_KEY",
		"CA_HEALTH_NUMBER",
		"CA_SOCIAL_INSURANCE_NUMBER",
		"CREDIT_DEBIT_CARD_CVV",
		"CREDIT_DEBIT_CARD_EXPIRY",
		"CREDIT_DEBIT_CARD_NUMBER",
		"DRIVER_ID",
		"EMAIL",
		"INTERNATIONAL_BANK_ACCOUNT_NUMBER",
		"IP_ADDRESS",
		"LICENSE_PLATE",
		"MAC_ADDRESS",
		"NAME",
		"PASSWORD",
		"PHONE",
		"PIN",
		"SWIFT_CODE",
		"UK_NATIONAL_HEALTH_SERVICE_NUMBER",
		"UK_NATIONAL_INSURANCE_NUMBER",
		"UK_UNIQUE_TAXPAYER_REFERENCE_NUMBER",
		"URL",
		"USERNAME",
		"US_BANK_ACCOUNT_NUMBER",
		"US_BANK_ROUTING_NUMBER",
		"US_INDIVIDUAL_TAX_IDENTIFICATION_NUMBER",
		"US_PASSPORT_NUMBER",
		"US_SOCIAL_SECURITY_NUMBER",
		"VEHICLE_IDENTIFICATION_NUMBER",
	}
}

type GuardrailSensitiveInformationAction string

// Enum values for GuardrailSensitiveInformationAction
const (
	GuardrailSensitiveInformationActionBlock     GuardrailSensitiveInformationAction = "BLOCK"
	GuardrailSensitiveInformationActionAnonymize GuardrailSensitiveInformationAction = "ANONYMIZE"
	GuardrailSensitiveInformationActionNone      GuardrailSensitiveInformationAction = "NONE"
)

// Values returns all known values for GuardrailSensitiveInformationAction. Note
// that this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailSensitiveInformationAction) Values() []GuardrailSensitiveInformationAction {
	return []GuardrailSensitiveInformationAction{
		"BLOCK",
		"ANONYMIZE",
		"NONE",
	}
}

type GuardrailStatus string

// Enum values for GuardrailStatus
const (
	GuardrailStatusCreating   GuardrailStatus = "CREATING"
	GuardrailStatusUpdating   GuardrailStatus = "UPDATING"
	GuardrailStatusVersioning GuardrailStatus = "VERSIONING"
	GuardrailStatusReady      GuardrailStatus = "READY"
	GuardrailStatusFailed     GuardrailStatus = "FAILED"
	GuardrailStatusDeleting   GuardrailStatus = "DELETING"
)

// Values returns all known values for GuardrailStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailStatus) Values() []GuardrailStatus {
	return []GuardrailStatus{
		"CREATING",
		"UPDATING",
		"VERSIONING",
		"READY",
		"FAILED",
		"DELETING",
	}
}

type GuardrailTopicAction string

// Enum values for GuardrailTopicAction
const (
	GuardrailTopicActionBlock GuardrailTopicAction = "BLOCK"
	GuardrailTopicActionNone  GuardrailTopicAction = "NONE"
)

// Values returns all known values for GuardrailTopicAction. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailTopicAction) Values() []GuardrailTopicAction {
	return []GuardrailTopicAction{
		"BLOCK",
		"NONE",
	}
}

type GuardrailTopicsTierName string

// Enum values for GuardrailTopicsTierName
const (
	GuardrailTopicsTierNameClassic  GuardrailTopicsTierName = "CLASSIC"
	GuardrailTopicsTierNameStandard GuardrailTopicsTierName = "STANDARD"
)

// Values returns all known values for GuardrailTopicsTierName. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailTopicsTierName) Values() []GuardrailTopicsTierName {
	return []GuardrailTopicsTierName{
		"CLASSIC",
		"STANDARD",
	}
}

type GuardrailTopicType string

// Enum values for GuardrailTopicType
const (
	GuardrailTopicTypeDeny GuardrailTopicType = "DENY"
)

// Values returns all known values for GuardrailTopicType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailTopicType) Values() []GuardrailTopicType {
	return []GuardrailTopicType{
		"DENY",
	}
}

type GuardrailWordAction string

// Enum values for GuardrailWordAction
const (
	GuardrailWordActionBlock GuardrailWordAction = "BLOCK"
	GuardrailWordActionNone  GuardrailWordAction = "NONE"
)

// Values returns all known values for GuardrailWordAction. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (GuardrailWordAction) Values() []GuardrailWordAction {
	return []GuardrailWordAction{
		"BLOCK",
		"NONE",
	}
}

type InferenceProfileStatus string

// Enum values for InferenceProfileStatus
const (
	InferenceProfileStatusActive InferenceProfileStatus = "ACTIVE"
)

// Values returns all known values for InferenceProfileStatus. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (InferenceProfileStatus) Values() []InferenceProfileStatus {
	return []InferenceProfileStatus{
		"ACTIVE",
	}
}

type InferenceProfileType string

// Enum values for InferenceProfileType
const (
	InferenceProfileTypeSystemDefined InferenceProfileType = "SYSTEM_DEFINED"
	InferenceProfileTypeApplication   InferenceProfileType = "APPLICATION"
)

// Values returns all known values for InferenceProfileType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (InferenceProfileType) Values() []InferenceProfileType {
	return []InferenceProfileType{
		"SYSTEM_DEFINED",
		"APPLICATION",
	}
}

type InferenceType string

// Enum values for InferenceType
const (
	InferenceTypeOnDemand    InferenceType = "ON_DEMAND"
	InferenceTypeProvisioned InferenceType = "PROVISIONED"
)

// Values returns all known values for InferenceType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (InferenceType) Values() []InferenceType {
	return []InferenceType{
		"ON_DEMAND",
		"PROVISIONED",
	}
}

type InputTags string

// Enum values for InputTags
const (
	InputTagsHonor  InputTags = "HONOR"
	InputTagsIgnore InputTags = "IGNORE"
)

// Values returns all known values for InputTags. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (InputTags) Values() []InputTags {
	return []InputTags{
		"HONOR",
		"IGNORE",
	}
}

type JobStatusDetails string

// Enum values for JobStatusDetails
const (
	JobStatusDetailsInProgress JobStatusDetails = "InProgress"
	JobStatusDetailsCompleted  JobStatusDetails = "Completed"
	JobStatusDetailsStopping   JobStatusDetails = "Stopping"
	JobStatusDetailsStopped    JobStatusDetails = "Stopped"
	JobStatusDetailsFailed     JobStatusDetails = "Failed"
	JobStatusDetailsNotStarted JobStatusDetails = "NotStarted"
)

// Values returns all known values for JobStatusDetails. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (JobStatusDetails) Values() []JobStatusDetails {
	return []JobStatusDetails{
		"InProgress",
		"Completed",
		"Stopping",
		"Stopped",
		"Failed",
		"NotStarted",
	}
}

type ModelCopyJobStatus string

// Enum values for ModelCopyJobStatus
const (
	ModelCopyJobStatusInProgress ModelCopyJobStatus = "InProgress"
	ModelCopyJobStatusCompleted  ModelCopyJobStatus = "Completed"
	ModelCopyJobStatusFailed     ModelCopyJobStatus = "Failed"
)

// Values returns all known values for ModelCopyJobStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ModelCopyJobStatus) Values() []ModelCopyJobStatus {
	return []ModelCopyJobStatus{
		"InProgress",
		"Completed",
		"Failed",
	}
}

type ModelCustomization string

// Enum values for ModelCustomization
const (
	ModelCustomizationFineTuning           ModelCustomization = "FINE_TUNING"
	ModelCustomizationContinuedPreTraining ModelCustomization = "CONTINUED_PRE_TRAINING"
	ModelCustomizationDistillation         ModelCustomization = "DISTILLATION"
)

// Values returns all known values for ModelCustomization. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ModelCustomization) Values() []ModelCustomization {
	return []ModelCustomization{
		"FINE_TUNING",
		"CONTINUED_PRE_TRAINING",
		"DISTILLATION",
	}
}

type ModelCustomizationJobStatus string

// Enum values for ModelCustomizationJobStatus
const (
	ModelCustomizationJobStatusInProgress ModelCustomizationJobStatus = "InProgress"
	ModelCustomizationJobStatusCompleted  ModelCustomizationJobStatus = "Completed"
	ModelCustomizationJobStatusFailed     ModelCustomizationJobStatus = "Failed"
	ModelCustomizationJobStatusStopping   ModelCustomizationJobStatus = "Stopping"
	ModelCustomizationJobStatusStopped    ModelCustomizationJobStatus = "Stopped"
)

// Values returns all known values for ModelCustomizationJobStatus. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ModelCustomizationJobStatus) Values() []ModelCustomizationJobStatus {
	return []ModelCustomizationJobStatus{
		"InProgress",
		"Completed",
		"Failed",
		"Stopping",
		"Stopped",
	}
}

type ModelImportJobStatus string

// Enum values for ModelImportJobStatus
const (
	ModelImportJobStatusInProgress ModelImportJobStatus = "InProgress"
	ModelImportJobStatusCompleted  ModelImportJobStatus = "Completed"
	ModelImportJobStatusFailed     ModelImportJobStatus = "Failed"
)

// Values returns all known values for ModelImportJobStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ModelImportJobStatus) Values() []ModelImportJobStatus {
	return []ModelImportJobStatus{
		"InProgress",
		"Completed",
		"Failed",
	}
}

type ModelInvocationJobStatus string

// Enum values for ModelInvocationJobStatus
const (
	ModelInvocationJobStatusSubmitted          ModelInvocationJobStatus = "Submitted"
	ModelInvocationJobStatusInProgress         ModelInvocationJobStatus = "InProgress"
	ModelInvocationJobStatusCompleted          ModelInvocationJobStatus = "Completed"
	ModelInvocationJobStatusFailed             ModelInvocationJobStatus = "Failed"
	ModelInvocationJobStatusStopping           ModelInvocationJobStatus = "Stopping"
	ModelInvocationJobStatusStopped            ModelInvocationJobStatus = "Stopped"
	ModelInvocationJobStatusPartiallyCompleted ModelInvocationJobStatus = "PartiallyCompleted"
	ModelInvocationJobStatusExpired            ModelInvocationJobStatus = "Expired"
	ModelInvocationJobStatusValidating         ModelInvocationJobStatus = "Validating"
	ModelInvocationJobStatusScheduled          ModelInvocationJobStatus = "Scheduled"
)

// Values returns all known values for ModelInvocationJobStatus. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ModelInvocationJobStatus) Values() []ModelInvocationJobStatus {
	return []ModelInvocationJobStatus{
		"Submitted",
		"InProgress",
		"Completed",
		"Failed",
		"Stopping",
		"Stopped",
		"PartiallyCompleted",
		"Expired",
		"Validating",
		"Scheduled",
	}
}

type ModelInvocationType string

// Enum values for ModelInvocationType
const (
	ModelInvocationTypeInvokeModel ModelInvocationType = "InvokeModel"
	ModelInvocationTypeConverse    ModelInvocationType = "Converse"
)

// Values returns all known values for ModelInvocationType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ModelInvocationType) Values() []ModelInvocationType {
	return []ModelInvocationType{
		"InvokeModel",
		"Converse",
	}
}

type ModelModality string

// Enum values for ModelModality
const (
	ModelModalityText      ModelModality = "TEXT"
	ModelModalityImage     ModelModality = "IMAGE"
	ModelModalityEmbedding ModelModality = "EMBEDDING"
)

// Values returns all known values for ModelModality. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ModelModality) Values() []ModelModality {
	return []ModelModality{
		"TEXT",
		"IMAGE",
		"EMBEDDING",
	}
}

type ModelStatus string

// Enum values for ModelStatus
const (
	ModelStatusActive   ModelStatus = "Active"
	ModelStatusCreating ModelStatus = "Creating"
	ModelStatusFailed   ModelStatus = "Failed"
)

// Values returns all known values for ModelStatus. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ModelStatus) Values() []ModelStatus {
	return []ModelStatus{
		"Active",
		"Creating",
		"Failed",
	}
}

type OfferType string

// Enum values for OfferType
const (
	OfferTypeAll    OfferType = "ALL"
	OfferTypePublic OfferType = "PUBLIC"
)

// Values returns all known values for OfferType. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (OfferType) Values() []OfferType {
	return []OfferType{
		"ALL",
		"PUBLIC",
	}
}

type PerformanceConfigLatency string

// Enum values for PerformanceConfigLatency
const (
	PerformanceConfigLatencyStandard  PerformanceConfigLatency = "standard"
	PerformanceConfigLatencyOptimized PerformanceConfigLatency = "optimized"
)

// Values returns all known values for PerformanceConfigLatency. Note that this
// can be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PerformanceConfigLatency) Values() []PerformanceConfigLatency {
	return []PerformanceConfigLatency{
		"standard",
		"optimized",
	}
}

type PromptRouterStatus string

// Enum values for PromptRouterStatus
const (
	PromptRouterStatusAvailable PromptRouterStatus = "AVAILABLE"
)

// Values returns all known values for PromptRouterStatus. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PromptRouterStatus) Values() []PromptRouterStatus {
	return []PromptRouterStatus{
		"AVAILABLE",
	}
}

type PromptRouterType string

// Enum values for PromptRouterType
const (
	PromptRouterTypeCustom  PromptRouterType = "custom"
	PromptRouterTypeDefault PromptRouterType = "default"
)

// Values returns all known values for PromptRouterType. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (PromptRouterType) Values() []PromptRouterType {
	return []PromptRouterType{
		"custom",
		"default",
	}
}

type ProvisionedModelStatus string

// Enum values for ProvisionedModelStatus
const (
	ProvisionedModelStatusCreating  ProvisionedModelStatus = "Creating"
	ProvisionedModelStatusInService ProvisionedModelStatus = "InService"
	ProvisionedModelStatusUpdating  ProvisionedModelStatus = "Updating"
	ProvisionedModelStatusFailed    ProvisionedModelStatus = "Failed"
)

// Values returns all known values for ProvisionedModelStatus. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ProvisionedModelStatus) Values() []ProvisionedModelStatus {
	return []ProvisionedModelStatus{
		"Creating",
		"InService",
		"Updating",
		"Failed",
	}
}

type QueryTransformationType string

// Enum values for QueryTransformationType
const (
	QueryTransformationTypeQueryDecomposition QueryTransformationType = "QUERY_DECOMPOSITION"
)

// Values returns all known values for QueryTransformationType. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (QueryTransformationType) Values() []QueryTransformationType {
	return []QueryTransformationType{
		"QUERY_DECOMPOSITION",
	}
}

type ReasoningEffort string

// Enum values for ReasoningEffort
const (
	ReasoningEffortLow    ReasoningEffort = "low"
	ReasoningEffortMedium ReasoningEffort = "medium"
	ReasoningEffortHigh   ReasoningEffort = "high"
)

// Values returns all known values for ReasoningEffort. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (ReasoningEffort) Values() []ReasoningEffort {
	return []ReasoningEffort{
		"low",
		"medium",
		"high",
	}
}

type RegionAvailability string

// Enum values for RegionAvailability
const (
	RegionAvailabilityAvailable    RegionAvailability = "AVAILABLE"
	RegionAvailabilityNotAvailable RegionAvailability = "NOT_AVAILABLE"
)

// Values returns all known values for RegionAvailability. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RegionAvailability) Values() []RegionAvailability {
	return []RegionAvailability{
		"AVAILABLE",
		"NOT_AVAILABLE",
	}
}

type RerankingMetadataSelectionMode string

// Enum values for RerankingMetadataSelectionMode
const (
	RerankingMetadataSelectionModeSelective RerankingMetadataSelectionMode = "SELECTIVE"
	RerankingMetadataSelectionModeAll       RerankingMetadataSelectionMode = "ALL"
)

// Values returns all known values for RerankingMetadataSelectionMode. Note that
// this can be expanded in the future, and so it is only as up to date as the
// client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RerankingMetadataSelectionMode) Values() []RerankingMetadataSelectionMode {
	return []RerankingMetadataSelectionMode{
		"SELECTIVE",
		"ALL",
	}
}

type RetrieveAndGenerateType string

// Enum values for RetrieveAndGenerateType
const (
	RetrieveAndGenerateTypeKnowledgeBase   RetrieveAndGenerateType = "KNOWLEDGE_BASE"
	RetrieveAndGenerateTypeExternalSources RetrieveAndGenerateType = "EXTERNAL_SOURCES"
)

// Values returns all known values for RetrieveAndGenerateType. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (RetrieveAndGenerateType) Values() []RetrieveAndGenerateType {
	return []RetrieveAndGenerateType{
		"KNOWLEDGE_BASE",
		"EXTERNAL_SOURCES",
	}
}

type S3InputFormat string

// Enum values for S3InputFormat
const (
	S3InputFormatJsonl S3InputFormat = "JSONL"
)

// Values returns all known values for S3InputFormat. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (S3InputFormat) Values() []S3InputFormat {
	return []S3InputFormat{
		"JSONL",
	}
}

type SearchType string

// Enum values for SearchType
const (
	SearchTypeHybrid   SearchType = "HYBRID"
	SearchTypeSemantic SearchType = "SEMANTIC"
)

// Values returns all known values for SearchType. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (SearchType) Values() []SearchType {
	return []SearchType{
		"HYBRID",
		"SEMANTIC",
	}
}

type SelectiveGuardingMode string

// Enum values for SelectiveGuardingMode
const (
	SelectiveGuardingModeSelective     SelectiveGuardingMode = "SELECTIVE"
	SelectiveGuardingModeComprehensive SelectiveGuardingMode = "COMPREHENSIVE"
)

// Values returns all known values for SelectiveGuardingMode. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (SelectiveGuardingMode) Values() []SelectiveGuardingMode {
	return []SelectiveGuardingMode{
		"SELECTIVE",
		"COMPREHENSIVE",
	}
}

type SortByProvisionedModels string

// Enum values for SortByProvisionedModels
const (
	SortByProvisionedModelsCreationTime SortByProvisionedModels = "CreationTime"
)

// Values returns all known values for SortByProvisionedModels. Note that this can
// be expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (SortByProvisionedModels) Values() []SortByProvisionedModels {
	return []SortByProvisionedModels{
		"CreationTime",
	}
}

type SortJobsBy string

// Enum values for SortJobsBy
const (
	SortJobsByCreationTime SortJobsBy = "CreationTime"
)

// Values returns all known values for SortJobsBy. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (SortJobsBy) Values() []SortJobsBy {
	return []SortJobsBy{
		"CreationTime",
	}
}

type SortModelsBy string

// Enum values for SortModelsBy
const (
	SortModelsByCreationTime SortModelsBy = "CreationTime"
)

// Values returns all known values for SortModelsBy. Note that this can be
// expanded in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (SortModelsBy) Values() []SortModelsBy {
	return []SortModelsBy{
		"CreationTime",
	}
}

type SortOrder string

// Enum values for SortOrder
const (
	SortOrderAscending  SortOrder = "Ascending"
	SortOrderDescending SortOrder = "Descending"
)

// Values returns all known values for SortOrder. Note that this can be expanded
// in the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (SortOrder) Values() []SortOrder {
	return []SortOrder{
		"Ascending",
		"Descending",
	}
}

type Status string

// Enum values for Status
const (
	StatusRegistered           Status = "REGISTERED"
	StatusIncompatibleEndpoint Status = "INCOMPATIBLE_ENDPOINT"
)

// Values returns all known values for Status. Note that this can be expanded in
// the future, and so it is only as up to date as the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (Status) Values() []Status {
	return []Status{
		"REGISTERED",
		"INCOMPATIBLE_ENDPOINT",
	}
}

type VectorSearchRerankingConfigurationType string

// Enum values for VectorSearchRerankingConfigurationType
const (
	VectorSearchRerankingConfigurationTypeBedrockRerankingModel VectorSearchRerankingConfigurationType = "BEDROCK_RERANKING_MODEL"
)

// Values returns all known values for VectorSearchRerankingConfigurationType.
// Note that this can be expanded in the future, and so it is only as up to date as
// the client.
//
// The ordering of this slice is not guaranteed to be stable across updates.
func (VectorSearchRerankingConfigurationType) Values() []VectorSearchRerankingConfigurationType {
	return []VectorSearchRerankingConfigurationType{
		"BEDROCK_RERANKING_MODEL",
	}
}
