// Code generated by smithy-go-codegen DO NOT EDIT.

package codeconnections

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/codeconnections/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Updates a specified host with the provided configurations.
func (c *Client) UpdateHost(ctx context.Context, params *UpdateHostInput, optFns ...func(*Options)) (*UpdateHostOutput, error) {
	if params == nil {
		params = &UpdateHostInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "UpdateHost", params, optFns, c.addOperationUpdateHostMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*UpdateHostOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type UpdateHostInput struct {

	// The Amazon Resource Name (ARN) of the host to be updated.
	//
	// This member is required.
	HostArn *string

	// The URL or endpoint of the host to be updated.
	ProviderEndpoint *string

	// The VPC configuration of the host to be updated. A VPC must be configured and
	// the infrastructure to be represented by the host must already be connected to
	// the VPC.
	VpcConfiguration *types.VpcConfiguration

	noSmithyDocumentSerde
}

type UpdateHostOutput struct {
	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationUpdateHostMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson10_serializeOpUpdateHost{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson10_deserializeOpUpdateHost{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpUpdateHostValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "UpdateHost"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
