// Code generated by smithy-go-codegen DO NOT EDIT.

// Package databasemigrationservice provides the API client, operations, and
// parameter types for AWS Database Migration Service.
//
// # Database Migration Service
//
// Database Migration Service (DMS) can migrate your data to and from the most
// widely used commercial and open-source databases such as Oracle, PostgreSQL,
// Microsoft SQL Server, Amazon Redshift, MariaDB, Amazon Aurora, MySQL, and SAP
// Adaptive Server Enterprise (ASE). The service supports homogeneous migrations
// such as Oracle to Oracle, as well as heterogeneous migrations between different
// database platforms, such as Oracle to MySQL or SQL Server to PostgreSQL.
//
// For more information about DMS, see [What Is Database Migration Service?] in the Database Migration Service User
// Guide.
//
// [What Is Database Migration Service?]: https://docs.aws.amazon.com/dms/latest/userguide/Welcome.html
package databasemigrationservice
