// Code generated by smithy-go-codegen DO NOT EDIT.

package datazone

import (
	"context"
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/datazone/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Creates a group profile in Amazon DataZone.
func (c *Client) CreateGroupProfile(ctx context.Context, params *CreateGroupProfileInput, optFns ...func(*Options)) (*CreateGroupProfileOutput, error) {
	if params == nil {
		params = &CreateGroupProfileInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "CreateGroupProfile", params, optFns, c.addOperationCreateGroupProfileMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*CreateGroupProfileOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type CreateGroupProfileInput struct {

	// The identifier of the Amazon DataZone domain in which the group profile is
	// created.
	//
	// This member is required.
	DomainIdentifier *string

	//  A unique, case-sensitive identifier that is provided to ensure the idempotency
	// of the request.
	ClientToken *string

	// The identifier of the group for which the group profile is created.
	GroupIdentifier *string

	// The ARN of the IAM role that will be associated with the group profile. This
	// role defines the permissions that group members will assume when accessing
	// Amazon DataZone resources.
	RolePrincipalArn *string

	noSmithyDocumentSerde
}

type CreateGroupProfileOutput struct {

	// The identifier of the Amazon DataZone domain in which the group profile is
	// created.
	DomainId *string

	// The name of the group for which group profile is created.
	GroupName *string

	// The identifier of the group profile.
	Id *string

	// The ARN of the IAM role principal. This role is associated with the group
	// profile.
	RolePrincipalArn *string

	// The unique identifier of the IAM role principal. This principal is associated
	// with the group profile.
	RolePrincipalId *string

	// The status of the group profile.
	Status types.GroupProfileStatus

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationCreateGroupProfileMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpCreateGroupProfile{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpCreateGroupProfile{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addIdempotencyToken_opCreateGroupProfileMiddleware(stack, options); err != nil {
		return err
	}
	if err = addOpCreateGroupProfileValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "CreateGroupProfile"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}

type idempotencyToken_initializeOpCreateGroupProfile struct {
	tokenProvider IdempotencyTokenProvider
}

func (*idempotencyToken_initializeOpCreateGroupProfile) ID() string {
	return "OperationIdempotencyTokenAutoFill"
}

func (m *idempotencyToken_initializeOpCreateGroupProfile) HandleInitialize(ctx context.Context, in middleware.InitializeInput, next middleware.InitializeHandler) (
	out middleware.InitializeOutput, metadata middleware.Metadata, err error,
) {
	if m.tokenProvider == nil {
		return next.HandleInitialize(ctx, in)
	}

	input, ok := in.Parameters.(*CreateGroupProfileInput)
	if !ok {
		return out, metadata, fmt.Errorf("expected middleware input to be of type *CreateGroupProfileInput ")
	}

	if input.ClientToken == nil {
		t, err := m.tokenProvider.GetIdempotencyToken()
		if err != nil {
			return out, metadata, err
		}
		input.ClientToken = &t
	}
	return next.HandleInitialize(ctx, in)
}
func addIdempotencyToken_opCreateGroupProfileMiddleware(stack *middleware.Stack, cfg Options) error {
	return stack.Initialize.Add(&idempotencyToken_initializeOpCreateGroupProfile{tokenProvider: cfg.IdempotencyTokenProvider}, middleware.Before)
}
