// Code generated by smithy-go-codegen DO NOT EDIT.

package configservice

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/configservice/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Adds all resource types specified in the ResourceTypes list to the [RecordingGroup] of
// specified configuration recorder and includes those resource types when
// recording.
//
// For this operation, the specified configuration recorder must use a [RecordingStrategy] that is
// either INCLUSION_BY_RESOURCE_TYPES or EXCLUSION_BY_RESOURCE_TYPES .
//
// [RecordingStrategy]: https://docs.aws.amazon.com/config/latest/APIReference/API_RecordingStrategy.html
// [RecordingGroup]: https://docs.aws.amazon.com/config/latest/APIReference/API_RecordingGroup.html
func (c *Client) AssociateResourceTypes(ctx context.Context, params *AssociateResourceTypesInput, optFns ...func(*Options)) (*AssociateResourceTypesOutput, error) {
	if params == nil {
		params = &AssociateResourceTypesInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "AssociateResourceTypes", params, optFns, c.addOperationAssociateResourceTypesMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*AssociateResourceTypesOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type AssociateResourceTypesInput struct {

	// The Amazon Resource Name (ARN) of the specified configuration recorder.
	//
	// This member is required.
	ConfigurationRecorderArn *string

	// The list of resource types you want to add to the recording group of the
	// specified configuration recorder.
	//
	// This member is required.
	ResourceTypes []types.ResourceType

	noSmithyDocumentSerde
}

type AssociateResourceTypesOutput struct {

	// Records configuration changes to the resource types in scope.
	//
	// For more information about the configuration recorder, see [Working with the Configuration Recorder] in the Config
	// Developer Guide.
	//
	// [Working with the Configuration Recorder]: https://docs.aws.amazon.com/config/latest/developerguide/stop-start-recorder.html
	//
	// This member is required.
	ConfigurationRecorder *types.ConfigurationRecorder

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationAssociateResourceTypesMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson11_serializeOpAssociateResourceTypes{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson11_deserializeOpAssociateResourceTypes{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpAssociateResourceTypesValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "AssociateResourceTypes"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
