// Code generated by smithy-go-codegen DO NOT EDIT.

// Package apprunner provides the API client, operations, and parameter types for
// AWS App Runner.
//
// # App Runner
//
// App Runner is an application service that provides a fast, simple, and
// cost-effective way to go directly from an existing container image or source
// code to a running service in the Amazon Web Services Cloud in seconds. You don't
// need to learn new technologies, decide which compute service to use, or
// understand how to provision and configure Amazon Web Services resources.
//
// App Runner connects directly to your container registry or source code
// repository. It provides an automatic delivery pipeline with fully managed
// operations, high performance, scalability, and security.
//
// For more information about App Runner, see the [App Runner Developer Guide]. For release information, see
// the [App Runner Release Notes].
//
// To install the Software Development Kits (SDKs), Integrated Development
// Environment (IDE) Toolkits, and command line tools that you can use to access
// the API, see [Tools for Amazon Web Services].
//
// # Endpoints
//
// For a list of Region-specific endpoints that App Runner supports, see [App Runner endpoints and quotas] in the
// Amazon Web Services General Reference.
//
// [Tools for Amazon Web Services]: http://aws.amazon.com/tools/
// [App Runner Developer Guide]: https://docs.aws.amazon.com/apprunner/latest/dg/
// [App Runner Release Notes]: https://docs.aws.amazon.com/apprunner/latest/relnotes/
// [App Runner endpoints and quotas]: https://docs.aws.amazon.com/general/latest/gr/apprunner.html
package apprunner
