// Code generated by smithy-go-codegen DO NOT EDIT.

package ec2

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/ec2/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Deletes an IPAM prefix list resolver. Before deleting a resolver, you must
// first delete all resolver targets associated with it.
func (c *Client) DeleteIpamPrefixListResolver(ctx context.Context, params *DeleteIpamPrefixListResolverInput, optFns ...func(*Options)) (*DeleteIpamPrefixListResolverOutput, error) {
	if params == nil {
		params = &DeleteIpamPrefixListResolverInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DeleteIpamPrefixListResolver", params, optFns, c.addOperationDeleteIpamPrefixListResolverMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DeleteIpamPrefixListResolverOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DeleteIpamPrefixListResolverInput struct {

	// The ID of the IPAM prefix list resolver to delete.
	//
	// This member is required.
	IpamPrefixListResolverId *string

	// A check for whether you have the required permissions for the action without
	// actually making the request and provides an error response. If you have the
	// required permissions, the error response is DryRunOperation . Otherwise, it is
	// UnauthorizedOperation .
	DryRun *bool

	noSmithyDocumentSerde
}

type DeleteIpamPrefixListResolverOutput struct {

	// Information about the IPAM prefix list resolver that was deleted.
	IpamPrefixListResolver *types.IpamPrefixListResolver

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDeleteIpamPrefixListResolverMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsEc2query_serializeOpDeleteIpamPrefixListResolver{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsEc2query_deserializeOpDeleteIpamPrefixListResolver{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpDeleteIpamPrefixListResolverValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DeleteIpamPrefixListResolver"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
