// Code generated by smithy-go-codegen DO NOT EDIT.

package customerprofiles

import (
	"context"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
	"time"
)

// Retrieve a calculated attribute for a customer profile.
func (c *Client) GetCalculatedAttributeForProfile(ctx context.Context, params *GetCalculatedAttributeForProfileInput, optFns ...func(*Options)) (*GetCalculatedAttributeForProfileOutput, error) {
	if params == nil {
		params = &GetCalculatedAttributeForProfileInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetCalculatedAttributeForProfile", params, optFns, c.addOperationGetCalculatedAttributeForProfileMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetCalculatedAttributeForProfileOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetCalculatedAttributeForProfileInput struct {

	// The unique name of the calculated attribute.
	//
	// This member is required.
	CalculatedAttributeName *string

	// The unique name of the domain.
	//
	// This member is required.
	DomainName *string

	// The unique identifier of a customer profile.
	//
	// This member is required.
	ProfileId *string

	noSmithyDocumentSerde
}

type GetCalculatedAttributeForProfileOutput struct {

	// The unique name of the calculated attribute.
	CalculatedAttributeName *string

	// The display name of the calculated attribute.
	DisplayName *string

	// Indicates whether the calculated attribute’s value is based on partial data. If
	// data is partial, it is set to true.
	IsDataPartial *string

	// The timestamp of the newest object included in the calculated attribute
	// calculation.
	LastObjectTimestamp *time.Time

	// The value of the calculated attribute.
	Value *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetCalculatedAttributeForProfileMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpGetCalculatedAttributeForProfile{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpGetCalculatedAttributeForProfile{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetCalculatedAttributeForProfileValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetCalculatedAttributeForProfile"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
