// Code generated by smithy-go-codegen DO NOT EDIT.

package cleanrooms

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/cleanrooms/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Retrieves a schema analysis rule.
func (c *Client) GetSchemaAnalysisRule(ctx context.Context, params *GetSchemaAnalysisRuleInput, optFns ...func(*Options)) (*GetSchemaAnalysisRuleOutput, error) {
	if params == nil {
		params = &GetSchemaAnalysisRuleInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetSchemaAnalysisRule", params, optFns, c.addOperationGetSchemaAnalysisRuleMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetSchemaAnalysisRuleOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetSchemaAnalysisRuleInput struct {

	// A unique identifier for the collaboration that the schema belongs to. Currently
	// accepts a collaboration ID.
	//
	// This member is required.
	CollaborationIdentifier *string

	// The name of the schema to retrieve the analysis rule for.
	//
	// This member is required.
	Name *string

	// The type of the schema analysis rule to retrieve. Schema analysis rules are
	// uniquely identified by a combination of the collaboration, the schema name, and
	// their type.
	//
	// This member is required.
	Type types.AnalysisRuleType

	noSmithyDocumentSerde
}

type GetSchemaAnalysisRuleOutput struct {

	// A specification about how data from the configured table can be used.
	//
	// This member is required.
	AnalysisRule *types.AnalysisRule

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetSchemaAnalysisRuleMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpGetSchemaAnalysisRule{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpGetSchemaAnalysisRule{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetSchemaAnalysisRuleValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetSchemaAnalysisRule"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
