// Code generated by smithy-go-codegen DO NOT EDIT.

package customerprofiles

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/customerprofiles/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Creates an Upload job to ingest data for segment imports. The metadata is
// created for the job with the provided field mapping and unique key.
func (c *Client) CreateUploadJob(ctx context.Context, params *CreateUploadJobInput, optFns ...func(*Options)) (*CreateUploadJobOutput, error) {
	if params == nil {
		params = &CreateUploadJobInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "CreateUploadJob", params, optFns, c.addOperationCreateUploadJobMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*CreateUploadJobOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type CreateUploadJobInput struct {

	// The unique name of the upload job. Could be a file name to identify the upload
	// job.
	//
	// This member is required.
	DisplayName *string

	// The unique name of the domain. Domain should be exists for the upload job to be
	// created.
	//
	// This member is required.
	DomainName *string

	// The mapping between CSV Columns and Profile Object attributes. A map of the
	// name and ObjectType field.
	//
	// This member is required.
	Fields map[string]types.ObjectTypeField

	// The unique key columns for de-duping the profiles used to map data to the
	// profile.
	//
	// This member is required.
	UniqueKey *string

	// The expiry duration for the profiles ingested with the job. If not provided,
	// the system default of 2 weeks is used.
	DataExpiry *int32

	noSmithyDocumentSerde
}

type CreateUploadJobOutput struct {

	// The unique identifier for the created upload job.
	//
	// This member is required.
	JobId *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationCreateUploadJobMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpCreateUploadJob{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpCreateUploadJob{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpCreateUploadJobValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "CreateUploadJob"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
