// Code generated by smithy-go-codegen DO NOT EDIT.

// Package configservice provides the API client, operations, and parameter types
// for AWS Config.
//
// # Config
//
// Config provides a way to keep track of the configurations of all the Amazon Web
// Services resources associated with your Amazon Web Services account. You can use
// Config to get the current and historical configurations of each Amazon Web
// Services resource and also to get information about the relationship between the
// resources. An Amazon Web Services resource can be an Amazon Compute Cloud
// (Amazon EC2) instance, an Elastic Block Store (EBS) volume, an elastic network
// Interface (ENI), or a security group. For a complete list of resources currently
// supported by Config, see [Supported Amazon Web Services resources].
//
// You can access and manage Config through the Amazon Web Services Management
// Console, the Amazon Web Services Command Line Interface (Amazon Web Services
// CLI), the Config API, or the Amazon Web Services SDKs for Config. This reference
// guide contains documentation for the Config API and the Amazon Web Services CLI
// commands that you can use to manage Config. The Config API uses the Signature
// Version 4 protocol for signing requests. For more information about how to sign
// a request with this protocol, see [Signature Version 4 Signing Process]. For detailed information about Config
// features and their associated actions or commands, as well as how to work with
// Amazon Web Services Management Console, see [What Is Config]in the Config Developer Guide.
//
// [What Is Config]: https://docs.aws.amazon.com/config/latest/developerguide/WhatIsConfig.html
// [Supported Amazon Web Services resources]: https://docs.aws.amazon.com/config/latest/developerguide/resource-config-reference.html#supported-resources
// [Signature Version 4 Signing Process]: https://docs.aws.amazon.com/general/latest/gr/signature-version-4.html
package configservice
