// Code generated by smithy-go-codegen DO NOT EDIT.

package codedeploy

import (
	"context"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Deletes resources linked to an external ID. This action only applies if you
// have configured blue/green deployments through CloudFormation.
//
// It is not necessary to call this action directly. CloudFormation calls it on
// your behalf when it needs to delete stack resources. This action is offered
// publicly in case you need to delete resources to comply with General Data
// Protection Regulation (GDPR) requirements.
func (c *Client) DeleteResourcesByExternalId(ctx context.Context, params *DeleteResourcesByExternalIdInput, optFns ...func(*Options)) (*DeleteResourcesByExternalIdOutput, error) {
	if params == nil {
		params = &DeleteResourcesByExternalIdInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DeleteResourcesByExternalId", params, optFns, c.addOperationDeleteResourcesByExternalIdMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DeleteResourcesByExternalIdOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DeleteResourcesByExternalIdInput struct {

	// The unique ID of an external resource (for example, a CloudFormation stack ID)
	// that is linked to one or more CodeDeploy resources.
	ExternalId *string

	noSmithyDocumentSerde
}

type DeleteResourcesByExternalIdOutput struct {
	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDeleteResourcesByExternalIdMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson11_serializeOpDeleteResourcesByExternalId{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson11_deserializeOpDeleteResourcesByExternalId{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DeleteResourcesByExternalId"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
