// Code generated by smithy-go-codegen DO NOT EDIT.

package comprehendmedical

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/comprehendmedical/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Gets a list of InferSNOMEDCT jobs a user has submitted.
func (c *Client) ListSNOMEDCTInferenceJobs(ctx context.Context, params *ListSNOMEDCTInferenceJobsInput, optFns ...func(*Options)) (*ListSNOMEDCTInferenceJobsOutput, error) {
	if params == nil {
		params = &ListSNOMEDCTInferenceJobsInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "ListSNOMEDCTInferenceJobs", params, optFns, c.addOperationListSNOMEDCTInferenceJobsMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*ListSNOMEDCTInferenceJobsOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type ListSNOMEDCTInferenceJobsInput struct {

	// Provides information for filtering a list of detection jobs.
	Filter *types.ComprehendMedicalAsyncJobFilter

	//  The maximum number of results to return in each page. The default is 100.
	MaxResults *int32

	//  Identifies the next page of InferSNOMEDCT results to return.
	NextToken *string

	noSmithyDocumentSerde
}

type ListSNOMEDCTInferenceJobsOutput struct {

	//  A list containing the properties of each job that is returned.
	ComprehendMedicalAsyncJobPropertiesList []types.ComprehendMedicalAsyncJobProperties

	//  Identifies the next page of results to return.
	NextToken *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationListSNOMEDCTInferenceJobsMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&smithyRpcv2cbor_serializeOpListSNOMEDCTInferenceJobs{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&smithyRpcv2cbor_deserializeOpListSNOMEDCTInferenceJobs{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addUserAgentFeatureProtocolRPCV2CBOR(stack, options); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "ListSNOMEDCTInferenceJobs"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
