// Code generated by smithy-go-codegen DO NOT EDIT.

package devopsagent

import (
	"context"
	"fmt"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Deletes an AgentSpace. This operation is idempotent and returns a 204 No
// Content response on success.
func (c *Client) DeleteAgentSpace(ctx context.Context, params *DeleteAgentSpaceInput, optFns ...func(*Options)) (*DeleteAgentSpaceOutput, error) {
	if params == nil {
		params = &DeleteAgentSpaceInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DeleteAgentSpace", params, optFns, c.addOperationDeleteAgentSpaceMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DeleteAgentSpaceOutput)
	out.ResultMetadata = metadata
	return out, nil
}

// Input for deleting an AgentSpace.
type DeleteAgentSpaceInput struct {

	// The unique identifier of the AgentSpace
	//
	// This member is required.
	AgentSpaceId *string

	noSmithyDocumentSerde
}

// Empty output for successful AgentSpace deletion.
type DeleteAgentSpaceOutput struct {
	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDeleteAgentSpaceMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpDeleteAgentSpace{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpDeleteAgentSpace{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addEndpointPrefix_opDeleteAgentSpaceMiddleware(stack); err != nil {
		return err
	}
	if err = addOpDeleteAgentSpaceValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DeleteAgentSpace"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}

type endpointPrefix_opDeleteAgentSpaceMiddleware struct {
}

func (*endpointPrefix_opDeleteAgentSpaceMiddleware) ID() string {
	return "EndpointHostPrefix"
}

func (m *endpointPrefix_opDeleteAgentSpaceMiddleware) HandleFinalize(ctx context.Context, in middleware.FinalizeInput, next middleware.FinalizeHandler) (
	out middleware.FinalizeOutput, metadata middleware.Metadata, err error,
) {
	if smithyhttp.GetHostnameImmutable(ctx) || smithyhttp.IsEndpointHostPrefixDisabled(ctx) {
		return next.HandleFinalize(ctx, in)
	}

	req, ok := in.Request.(*smithyhttp.Request)
	if !ok {
		return out, metadata, fmt.Errorf("unknown transport type %T", in.Request)
	}

	req.URL.Host = "cp." + req.URL.Host

	return next.HandleFinalize(ctx, in)
}
func addEndpointPrefix_opDeleteAgentSpaceMiddleware(stack *middleware.Stack) error {
	return stack.Finalize.Insert(&endpointPrefix_opDeleteAgentSpaceMiddleware{}, "ResolveEndpointV2", middleware.After)
}
