// Code generated by smithy-go-codegen DO NOT EDIT.

package bedrock

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/bedrock/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
	"time"
)

// Retrieves the properties associated with import model job, including the status
// of the job. For more information, see [Import a customized model]in the [Amazon Bedrock User Guide].
//
// [Import a customized model]: https://docs.aws.amazon.com/bedrock/latest/userguide/model-customization-import-model.html
// [Amazon Bedrock User Guide]: https://docs.aws.amazon.com/bedrock/latest/userguide/what-is-service.html
func (c *Client) GetModelImportJob(ctx context.Context, params *GetModelImportJobInput, optFns ...func(*Options)) (*GetModelImportJobOutput, error) {
	if params == nil {
		params = &GetModelImportJobInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetModelImportJob", params, optFns, c.addOperationGetModelImportJobMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetModelImportJobOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetModelImportJobInput struct {

	// The identifier of the import job.
	//
	// This member is required.
	JobIdentifier *string

	noSmithyDocumentSerde
}

type GetModelImportJobOutput struct {

	// The time the resource was created.
	CreationTime *time.Time

	// Time that the resource transitioned to terminal state.
	EndTime *time.Time

	// Information about why the import job failed.
	FailureMessage *string

	// The Amazon Resource Name (ARN) of the imported model.
	ImportedModelArn *string

	// The imported model is encrypted at rest using this key.
	ImportedModelKmsKeyArn *string

	// The name of the imported model.
	ImportedModelName *string

	// The Amazon Resource Name (ARN) of the import job.
	JobArn *string

	// The name of the import job.
	JobName *string

	// Time the resource was last modified.
	LastModifiedTime *time.Time

	// The data source for the imported model.
	ModelDataSource types.ModelDataSource

	// The Amazon Resource Name (ARN) of the IAM role associated with this job.
	RoleArn *string

	// The status of the job. A successful job transitions from in-progress to
	// completed when the imported model is ready to use. If the job failed, the
	// failure message contains information about why the job failed.
	Status types.ModelImportJobStatus

	// The Virtual Private Cloud (VPC) configuration of the import model job.
	VpcConfig *types.VpcConfig

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetModelImportJobMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpGetModelImportJob{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpGetModelImportJob{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetModelImportJobValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetModelImportJob"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
