// Code generated by smithy-go-codegen DO NOT EDIT.

package clouddirectory

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/clouddirectory/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Retrieves metadata about an object.
func (c *Client) GetObjectInformation(ctx context.Context, params *GetObjectInformationInput, optFns ...func(*Options)) (*GetObjectInformationOutput, error) {
	if params == nil {
		params = &GetObjectInformationInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetObjectInformation", params, optFns, c.addOperationGetObjectInformationMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetObjectInformationOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetObjectInformationInput struct {

	// The ARN of the directory being retrieved.
	//
	// This member is required.
	DirectoryArn *string

	// A reference to the object.
	//
	// This member is required.
	ObjectReference *types.ObjectReference

	// The consistency level at which to retrieve the object information.
	ConsistencyLevel types.ConsistencyLevel

	noSmithyDocumentSerde
}

type GetObjectInformationOutput struct {

	// The ObjectIdentifier of the specified object.
	ObjectIdentifier *string

	// The facets attached to the specified object. Although the response does not
	// include minor version information, the most recently applied minor version of
	// each Facet is in effect. See GetAppliedSchemaVersionfor details.
	SchemaFacets []types.SchemaFacet

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetObjectInformationMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpGetObjectInformation{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpGetObjectInformation{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetObjectInformationValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetObjectInformation"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
