// Code generated by smithy-go-codegen DO NOT EDIT.

package devicefarm

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/devicefarm/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Retrieves information about a Selenium testing project.
func (c *Client) GetTestGridProject(ctx context.Context, params *GetTestGridProjectInput, optFns ...func(*Options)) (*GetTestGridProjectOutput, error) {
	if params == nil {
		params = &GetTestGridProjectInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetTestGridProject", params, optFns, c.addOperationGetTestGridProjectMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetTestGridProjectOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetTestGridProjectInput struct {

	// The ARN of the Selenium testing project, from either CreateTestGridProject or ListTestGridProjects.
	//
	// This member is required.
	ProjectArn *string

	noSmithyDocumentSerde
}

type GetTestGridProjectOutput struct {

	// A TestGridProject.
	TestGridProject *types.TestGridProject

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetTestGridProjectMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson11_serializeOpGetTestGridProject{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson11_deserializeOpGetTestGridProject{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetTestGridProjectValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetTestGridProject"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
