// Code generated by smithy-go-codegen DO NOT EDIT.

package deadline

import (
	"context"
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/deadline/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Allows a user to assume a role for a queue.
func (c *Client) AssumeQueueRoleForUser(ctx context.Context, params *AssumeQueueRoleForUserInput, optFns ...func(*Options)) (*AssumeQueueRoleForUserOutput, error) {
	if params == nil {
		params = &AssumeQueueRoleForUserInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "AssumeQueueRoleForUser", params, optFns, c.addOperationAssumeQueueRoleForUserMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*AssumeQueueRoleForUserOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type AssumeQueueRoleForUserInput struct {

	// The farm ID of the queue that the user assumes the role for.
	//
	// This member is required.
	FarmId *string

	// The queue ID of the queue that the user assumes the role for.
	//
	// This member is required.
	QueueId *string

	noSmithyDocumentSerde
}

// Shared response body for AssumeRole operations where credentials are required.
// AssumeQueueRoleForWorkerResponse is excluded because credentials is optional
// there because Queue.roleArn is optional, so the mixin's @required trait would be
// incorrect.
type AssumeQueueRoleForUserOutput struct {

	// The credentials for the queue role that a user has access to.
	//
	// This member is required.
	Credentials *types.AwsCredentials

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationAssumeQueueRoleForUserMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpAssumeQueueRoleForUser{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpAssumeQueueRoleForUser{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addEndpointPrefix_opAssumeQueueRoleForUserMiddleware(stack); err != nil {
		return err
	}
	if err = addOpAssumeQueueRoleForUserValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "AssumeQueueRoleForUser"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}

type endpointPrefix_opAssumeQueueRoleForUserMiddleware struct {
}

func (*endpointPrefix_opAssumeQueueRoleForUserMiddleware) ID() string {
	return "EndpointHostPrefix"
}

func (m *endpointPrefix_opAssumeQueueRoleForUserMiddleware) HandleFinalize(ctx context.Context, in middleware.FinalizeInput, next middleware.FinalizeHandler) (
	out middleware.FinalizeOutput, metadata middleware.Metadata, err error,
) {
	if smithyhttp.GetHostnameImmutable(ctx) || smithyhttp.IsEndpointHostPrefixDisabled(ctx) {
		return next.HandleFinalize(ctx, in)
	}

	req, ok := in.Request.(*smithyhttp.Request)
	if !ok {
		return out, metadata, fmt.Errorf("unknown transport type %T", in.Request)
	}

	req.URL.Host = "management." + req.URL.Host

	return next.HandleFinalize(ctx, in)
}
func addEndpointPrefix_opAssumeQueueRoleForUserMiddleware(stack *middleware.Stack) error {
	return stack.Finalize.Insert(&endpointPrefix_opAssumeQueueRoleForUserMiddleware{}, "ResolveEndpointV2", middleware.After)
}
