// Code generated by smithy-go-codegen DO NOT EDIT.

package controltower

import (
	"context"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Decommissions a landing zone. This API call starts an asynchronous operation
// that deletes Amazon Web Services Control Tower resources deployed in accounts
// managed by Amazon Web Services Control Tower.
//
// Decommissioning a landing zone is a process with significant consequences, and
// it cannot be undone. We strongly recommend that you perform this decommissioning
// process only if you intend to stop using your landing zone.
func (c *Client) DeleteLandingZone(ctx context.Context, params *DeleteLandingZoneInput, optFns ...func(*Options)) (*DeleteLandingZoneOutput, error) {
	if params == nil {
		params = &DeleteLandingZoneInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DeleteLandingZone", params, optFns, c.addOperationDeleteLandingZoneMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DeleteLandingZoneOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DeleteLandingZoneInput struct {

	// The unique identifier of the landing zone.
	//
	// This member is required.
	LandingZoneIdentifier *string

	noSmithyDocumentSerde
}

type DeleteLandingZoneOutput struct {

	// >A unique identifier assigned to a DeleteLandingZone operation. You can use
	// this identifier as an input parameter of GetLandingZoneOperation to check the
	// operation's status.
	//
	// This member is required.
	OperationIdentifier *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDeleteLandingZoneMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpDeleteLandingZone{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpDeleteLandingZone{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpDeleteLandingZoneValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DeleteLandingZone"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
