// Code generated by smithy-go-codegen DO NOT EDIT.

package costoptimizationhub

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/costoptimizationhub/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Updates a set of preferences for an account in order to add account-specific
// preferences into the service. These preferences impact how the savings
// associated with recommendations are presented.
func (c *Client) UpdatePreferences(ctx context.Context, params *UpdatePreferencesInput, optFns ...func(*Options)) (*UpdatePreferencesOutput, error) {
	if params == nil {
		params = &UpdatePreferencesInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "UpdatePreferences", params, optFns, c.addOperationUpdatePreferencesMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*UpdatePreferencesOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type UpdatePreferencesInput struct {

	// Sets the "member account discount visibility" preference.
	MemberAccountDiscountVisibility types.MemberAccountDiscountVisibility

	// Sets the preferences for how Reserved Instances and Savings Plans cost-saving
	// opportunities are prioritized in terms of payment option and term length.
	PreferredCommitment *types.PreferredCommitment

	// Sets the "savings estimation mode" preference.
	SavingsEstimationMode types.SavingsEstimationMode

	noSmithyDocumentSerde
}

type UpdatePreferencesOutput struct {

	// Shows the status of the "member account discount visibility" preference.
	MemberAccountDiscountVisibility types.MemberAccountDiscountVisibility

	// Shows the updated preferences for how Reserved Instances and Savings Plans
	// cost-saving opportunities are prioritized in terms of payment option and term
	// length.
	PreferredCommitment *types.PreferredCommitment

	// Shows the status of the "savings estimation mode" preference.
	SavingsEstimationMode types.SavingsEstimationMode

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationUpdatePreferencesMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson10_serializeOpUpdatePreferences{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson10_deserializeOpUpdatePreferences{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "UpdatePreferences"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
