// Code generated by smithy-go-codegen DO NOT EDIT.

// Package backupsearch provides the API client, operations, and parameter types
// for AWS Backup Search.
//
// # Backup Search
//
// Backup Search is the recovery point and item level search for Backup.
//
// For additional information, see:
//
// [Backup API Reference]
//
// [Backup Developer Guide]
//
// [Backup API Reference]: https://docs.aws.amazon.com/aws-backup/latest/devguide/api-reference.html
// [Backup Developer Guide]: https://docs.aws.amazon.com/aws-backup/latest/devguide/whatisbackup.html
package backupsearch
