// Code generated by smithy-go-codegen DO NOT EDIT.

package datazone

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/datazone/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
	"time"
)

// Gets the blueprint configuration in Amazon DataZone.
func (c *Client) GetEnvironmentBlueprintConfiguration(ctx context.Context, params *GetEnvironmentBlueprintConfigurationInput, optFns ...func(*Options)) (*GetEnvironmentBlueprintConfigurationOutput, error) {
	if params == nil {
		params = &GetEnvironmentBlueprintConfigurationInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetEnvironmentBlueprintConfiguration", params, optFns, c.addOperationGetEnvironmentBlueprintConfigurationMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetEnvironmentBlueprintConfigurationOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetEnvironmentBlueprintConfigurationInput struct {

	// The ID of the Amazon DataZone domain where this blueprint exists.
	//
	// This member is required.
	DomainIdentifier *string

	// He ID of the blueprint.
	//
	// This member is required.
	EnvironmentBlueprintIdentifier *string

	noSmithyDocumentSerde
}

type GetEnvironmentBlueprintConfigurationOutput struct {

	// The ID of the Amazon DataZone domain where this blueprint exists.
	//
	// This member is required.
	DomainId *string

	// The ID of the blueprint.
	//
	// This member is required.
	EnvironmentBlueprintId *string

	// Specifies whether user-provided resource configurations are allowed for the
	// environment blueprint.
	AllowUserProvidedConfigurations *bool

	// The timestamp of when this blueprint was created.
	CreatedAt *time.Time

	// The Amazon Web Services regions in which this blueprint is enabled.
	EnabledRegions []string

	// The environment role permissions boundary.
	EnvironmentRolePermissionBoundary *string

	// The ARN of the manage access role with which this blueprint is created.
	ManageAccessRoleArn *string

	// The provisioning configuration of a blueprint.
	ProvisioningConfigurations []types.ProvisioningConfiguration

	// The ARN of the provisioning role with which this blueprint is created.
	ProvisioningRoleArn *string

	// The regional parameters of the blueprint.
	RegionalParameters map[string]map[string]string

	// The resource configurations of the environment blueprint.
	ResourceConfigurations []types.ResourceConfiguration

	// The timestamp of when this blueprint was upated.
	UpdatedAt *time.Time

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetEnvironmentBlueprintConfigurationMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpGetEnvironmentBlueprintConfiguration{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpGetEnvironmentBlueprintConfiguration{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetEnvironmentBlueprintConfigurationValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetEnvironmentBlueprintConfiguration"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
