// Code generated by smithy-go-codegen DO NOT EDIT.

package budgets

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/budgets/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Deletes a notification.
//
// Deleting a notification also deletes the subscribers that are associated with
// the notification.
func (c *Client) DeleteNotification(ctx context.Context, params *DeleteNotificationInput, optFns ...func(*Options)) (*DeleteNotificationOutput, error) {
	if params == nil {
		params = &DeleteNotificationInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DeleteNotification", params, optFns, c.addOperationDeleteNotificationMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DeleteNotificationOutput)
	out.ResultMetadata = metadata
	return out, nil
}

// Request of DeleteNotification
type DeleteNotificationInput struct {

	// The accountId that is associated with the budget whose notification you want to
	// delete.
	//
	// This member is required.
	AccountId *string

	// The name of the budget whose notification you want to delete.
	//
	// This member is required.
	BudgetName *string

	// The notification that you want to delete.
	//
	// This member is required.
	Notification *types.Notification

	noSmithyDocumentSerde
}

// Response of DeleteNotification
type DeleteNotificationOutput struct {
	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDeleteNotificationMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson11_serializeOpDeleteNotification{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson11_deserializeOpDeleteNotification{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpDeleteNotificationValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DeleteNotification"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
