// Code generated by smithy-go-codegen DO NOT EDIT.

package drs

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/drs/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Allows you to update the failback replication configuration of a Recovery
// Instance by ID.
func (c *Client) UpdateFailbackReplicationConfiguration(ctx context.Context, params *UpdateFailbackReplicationConfigurationInput, optFns ...func(*Options)) (*UpdateFailbackReplicationConfigurationOutput, error) {
	if params == nil {
		params = &UpdateFailbackReplicationConfigurationInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "UpdateFailbackReplicationConfiguration", params, optFns, c.addOperationUpdateFailbackReplicationConfigurationMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*UpdateFailbackReplicationConfigurationOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type UpdateFailbackReplicationConfigurationInput struct {

	// The ID of the Recovery Instance.
	//
	// This member is required.
	RecoveryInstanceID *string

	// Configure bandwidth throttling for the outbound data transfer rate of the
	// Recovery Instance in Mbps.
	BandwidthThrottling int64

	// Which version of the Internet Protocol to use for replication of data. (IPv4 or
	// IPv6)
	InternetProtocol types.InternetProtocol

	// The name of the Failback Replication Configuration.
	Name *string

	// Whether to use Private IP for the failback replication of the Recovery Instance.
	UsePrivateIP *bool

	noSmithyDocumentSerde
}

type UpdateFailbackReplicationConfigurationOutput struct {
	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationUpdateFailbackReplicationConfigurationMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpUpdateFailbackReplicationConfiguration{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpUpdateFailbackReplicationConfiguration{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpUpdateFailbackReplicationConfigurationValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "UpdateFailbackReplicationConfiguration"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
