// Code generated by smithy-go-codegen DO NOT EDIT.

package connect

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/connect/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
	"time"
)

// Retrieves an overview of a test execution that includes the status of the
// execution, start and end time, and observation summary.
func (c *Client) GetTestCaseExecutionSummary(ctx context.Context, params *GetTestCaseExecutionSummaryInput, optFns ...func(*Options)) (*GetTestCaseExecutionSummaryOutput, error) {
	if params == nil {
		params = &GetTestCaseExecutionSummaryInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetTestCaseExecutionSummary", params, optFns, c.addOperationGetTestCaseExecutionSummaryMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetTestCaseExecutionSummaryOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetTestCaseExecutionSummaryInput struct {

	// The identifier of the Amazon Connect instance.
	//
	// This member is required.
	InstanceId *string

	// The identifier of the test case execution.
	//
	// This member is required.
	TestCaseExecutionId *string

	// The identifier of the test case.
	//
	// This member is required.
	TestCaseId *string

	noSmithyDocumentSerde
}

type GetTestCaseExecutionSummaryOutput struct {

	// The timestamp when the test case execution ended.
	EndTime *time.Time

	// Summary statistics for the test case execution.
	ObservationSummary *types.ObservationSummary

	// The timestamp when the test case execution started.
	StartTime *time.Time

	// The status of the test case execution.
	Status types.TestCaseExecutionStatus

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetTestCaseExecutionSummaryMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpGetTestCaseExecutionSummary{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpGetTestCaseExecutionSummary{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetTestCaseExecutionSummaryValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetTestCaseExecutionSummary"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
