// Code generated by smithy-go-codegen DO NOT EDIT.

package customerprofiles

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/customerprofiles/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Gets the result of a segment estimate query.
func (c *Client) GetSegmentEstimate(ctx context.Context, params *GetSegmentEstimateInput, optFns ...func(*Options)) (*GetSegmentEstimateOutput, error) {
	if params == nil {
		params = &GetSegmentEstimateInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetSegmentEstimate", params, optFns, c.addOperationGetSegmentEstimateMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetSegmentEstimateOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetSegmentEstimateInput struct {

	// The unique name of the domain.
	//
	// This member is required.
	DomainName *string

	// The query Id passed by a previous CreateSegmentEstimate operation.
	//
	// This member is required.
	EstimateId *string

	noSmithyDocumentSerde
}

type GetSegmentEstimateOutput struct {

	// The unique name of the domain.
	DomainName *string

	// The estimated number of profiles contained in the segment.
	Estimate *string

	// The QueryId which is the same as the value passed in QueryId .
	EstimateId *string

	// The error message if there is any error.
	Message *string

	// The current status of the query.
	Status types.EstimateStatus

	// The status code of the segment estimate.
	StatusCode int32

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetSegmentEstimateMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpGetSegmentEstimate{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpGetSegmentEstimate{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetSegmentEstimateValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetSegmentEstimate"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
