// Code generated by smithy-go-codegen DO NOT EDIT.

package datasync

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/datasync/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Modifies the following configuration parameters of the Server Message Block
// (SMB) transfer location that you're using with DataSync.
//
// For more information, see [Configuring DataSync transfers with an SMB file server].
//
// [Configuring DataSync transfers with an SMB file server]: https://docs.aws.amazon.com/datasync/latest/userguide/create-smb-location.html
func (c *Client) UpdateLocationSmb(ctx context.Context, params *UpdateLocationSmbInput, optFns ...func(*Options)) (*UpdateLocationSmbOutput, error) {
	if params == nil {
		params = &UpdateLocationSmbInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "UpdateLocationSmb", params, optFns, c.addOperationUpdateLocationSmbMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*UpdateLocationSmbOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type UpdateLocationSmbInput struct {

	// Specifies the ARN of the SMB location that you want to update.
	//
	// This member is required.
	LocationArn *string

	// Specifies the DataSync agent (or agents) that can connect to your SMB file
	// server. You specify an agent by using its Amazon Resource Name (ARN).
	AgentArns []string

	// Specifies the authentication protocol that DataSync uses to connect to your SMB
	// file server. DataSync supports NTLM (default) and KERBEROS authentication.
	//
	// For more information, see [Providing DataSync access to SMB file servers].
	//
	// [Providing DataSync access to SMB file servers]: https://docs.aws.amazon.com/datasync/latest/userguide/create-smb-location.html#configuring-smb-permissions
	AuthenticationType types.SmbAuthenticationType

	// Specifies configuration information for a DataSync-managed secret, such as a
	// Password or KerberosKeytab or set of credentials that DataSync uses to access a
	// specific transfer location, and a customer-managed KMS key.
	CmkSecretConfig *types.CmkSecretConfig

	// Specifies configuration information for a customer-managed secret, such as a
	// Password or KerberosKeytab or set of credentials that DataSync uses to access a
	// specific transfer location, and a customer-managed Identity and Access
	// Management (IAM) role that provides access to the secret.
	CustomSecretConfig *types.CustomSecretConfig

	// Specifies the IP addresses (IPv4 or IPv6) for the DNS servers that your SMB
	// file server belongs to. This parameter applies only if AuthenticationType is
	// set to KERBEROS .
	//
	// If you have multiple domains in your environment, configuring this parameter
	// makes sure that DataSync connects to the right SMB file server.
	DnsIpAddresses []string

	// Specifies the Windows domain name that your SMB file server belongs to. This
	// parameter applies only if AuthenticationType is set to NTLM .
	//
	// If you have multiple domains in your environment, configuring this parameter
	// makes sure that DataSync connects to the right file server.
	Domain *string

	// Specifies your Kerberos key table (keytab) file, which includes mappings
	// between your Kerberos principal and encryption keys.
	//
	// To avoid task execution errors, make sure that the Kerberos principal that you
	// use to create the keytab file matches exactly what you specify for
	// KerberosPrincipal .
	KerberosKeytab []byte

	// Specifies a Kerberos configuration file ( krb5.conf ) that defines your Kerberos
	// realm configuration.
	//
	// The file must be base64 encoded. If you're using the CLI, the encoding is done
	// for you.
	KerberosKrb5Conf []byte

	// Specifies a Kerberos prinicpal, which is an identity in your Kerberos realm
	// that has permission to access the files, folders, and file metadata in your SMB
	// file server.
	//
	// A Kerberos principal might look like HOST/kerberosuser@MYDOMAIN.ORG .
	//
	// Principal names are case sensitive. Your DataSync task execution will fail if
	// the principal that you specify for this parameter doesn’t exactly match the
	// principal that you use to create the keytab file.
	KerberosPrincipal *string

	// Specifies the version of the Server Message Block (SMB) protocol that DataSync
	// uses to access an SMB file server.
	MountOptions *types.SmbMountOptions

	// Specifies the password of the user who can mount your SMB file server and has
	// permission to access the files and folders involved in your transfer. This
	// parameter applies only if AuthenticationType is set to NTLM .
	Password *string

	// Specifies the domain name or IP address (IPv4 or IPv6) of the SMB file server
	// that your DataSync agent connects to.
	//
	// If you're using Kerberos authentication, you must specify a domain name.
	ServerHostname *string

	// Specifies the name of the share exported by your SMB file server where DataSync
	// will read or write data. You can include a subdirectory in the share path (for
	// example, /path/to/subdirectory ). Make sure that other SMB clients in your
	// network can also mount this path.
	//
	// To copy all data in the specified subdirectory, DataSync must be able to mount
	// the SMB share and access all of its data. For more information, see [Providing DataSync access to SMB file servers].
	//
	// [Providing DataSync access to SMB file servers]: https://docs.aws.amazon.com/datasync/latest/userguide/create-smb-location.html#configuring-smb-permissions
	Subdirectory *string

	// Specifies the user name that can mount your SMB file server and has permission
	// to access the files and folders involved in your transfer. This parameter
	// applies only if AuthenticationType is set to NTLM .
	//
	// For information about choosing a user with the right level of access for your
	// transfer, see [Providing DataSync access to SMB file servers].
	//
	// [Providing DataSync access to SMB file servers]: https://docs.aws.amazon.com/datasync/latest/userguide/create-smb-location.html#configuring-smb-permissions
	User *string

	noSmithyDocumentSerde
}

type UpdateLocationSmbOutput struct {
	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationUpdateLocationSmbMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson11_serializeOpUpdateLocationSmb{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson11_deserializeOpUpdateLocationSmb{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpUpdateLocationSmbValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "UpdateLocationSmb"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
