// Code generated by smithy-go-codegen DO NOT EDIT.

package applicationdiscoveryservice

import (
	"context"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Associates one or more configuration items with an application.
func (c *Client) AssociateConfigurationItemsToApplication(ctx context.Context, params *AssociateConfigurationItemsToApplicationInput, optFns ...func(*Options)) (*AssociateConfigurationItemsToApplicationOutput, error) {
	if params == nil {
		params = &AssociateConfigurationItemsToApplicationInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "AssociateConfigurationItemsToApplication", params, optFns, c.addOperationAssociateConfigurationItemsToApplicationMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*AssociateConfigurationItemsToApplicationOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type AssociateConfigurationItemsToApplicationInput struct {

	// The configuration ID of an application with which items are to be associated.
	//
	// This member is required.
	ApplicationConfigurationId *string

	// The ID of each configuration item to be associated with an application.
	//
	// This member is required.
	ConfigurationIds []string

	noSmithyDocumentSerde
}

type AssociateConfigurationItemsToApplicationOutput struct {
	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationAssociateConfigurationItemsToApplicationMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson11_serializeOpAssociateConfigurationItemsToApplication{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson11_deserializeOpAssociateConfigurationItemsToApplication{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpAssociateConfigurationItemsToApplicationValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "AssociateConfigurationItemsToApplication"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
