// Code generated by smithy-go-codegen DO NOT EDIT.

package bedrockdataautomation

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/bedrockdataautomation/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// API used to get blueprint optimization status.
func (c *Client) GetBlueprintOptimizationStatus(ctx context.Context, params *GetBlueprintOptimizationStatusInput, optFns ...func(*Options)) (*GetBlueprintOptimizationStatusOutput, error) {
	if params == nil {
		params = &GetBlueprintOptimizationStatusInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetBlueprintOptimizationStatus", params, optFns, c.addOperationGetBlueprintOptimizationStatusMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetBlueprintOptimizationStatusOutput)
	out.ResultMetadata = metadata
	return out, nil
}

// Structure for request of GetBlueprintOptimizationStatus API.
type GetBlueprintOptimizationStatusInput struct {

	// Invocation arn.
	//
	// This member is required.
	InvocationArn *string

	noSmithyDocumentSerde
}

// Response of GetBlueprintOptimizationStatus API.
type GetBlueprintOptimizationStatusOutput struct {

	// Error Message.
	ErrorMessage *string

	// Error Type.
	ErrorType *string

	// Output configuration.
	OutputConfiguration *types.BlueprintOptimizationOutputConfiguration

	// Job Status.
	Status types.BlueprintOptimizationJobStatus

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetBlueprintOptimizationStatusMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpGetBlueprintOptimizationStatus{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpGetBlueprintOptimizationStatus{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetBlueprintOptimizationStatusValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetBlueprintOptimizationStatus"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
