// Code generated by smithy-go-codegen DO NOT EDIT.

package schemas

import (
	smithy "github.com/aws/smithy-go"
	smithyprelude "github.com/aws/smithy-go/prelude"
	smithytraits "github.com/aws/smithy-go/traits"
)

var EmptyInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "EmptyInputOutput",
}, smithy.ShapeTypeOperation, 0)

var Float16 = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "Float16",
}, smithy.ShapeTypeOperation, 0)

var FractionalSeconds = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "FractionalSeconds",
}, smithy.ShapeTypeOperation, 0)

var GreetingWithErrors = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "GreetingWithErrors",
}, smithy.ShapeTypeOperation, 0)

var NoInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "NoInputOutput",
}, smithy.ShapeTypeOperation, 0)

var OperationWithDefaults = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "OperationWithDefaults",
}, smithy.ShapeTypeOperation, 0)

var OptionalInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "OptionalInputOutput",
}, smithy.ShapeTypeOperation, 0)

var RecursiveShapes = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "RecursiveShapes",
}, smithy.ShapeTypeOperation, 0)

var RpcV2CborDenseMaps = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "RpcV2CborDenseMaps",
}, smithy.ShapeTypeOperation, 0)

var RpcV2CborLists = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "RpcV2CborLists",
}, smithy.ShapeTypeOperation, 0)

var RpcV2CborSparseMaps = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "RpcV2CborSparseMaps",
}, smithy.ShapeTypeOperation, 0)

var SimpleScalarProperties = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "SimpleScalarProperties",
}, smithy.ShapeTypeOperation, 0)

var SparseNullsOperation = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "SparseNullsOperation",
}, smithy.ShapeTypeOperation, 0)

var _RpcV2Protocol = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "RpcV2Protocol",
}, smithy.ShapeTypeService, 0)

var RpcV2Protocol = smithy.NewServiceSchema(_RpcV2Protocol, "2020-07-14")

var ValidationException = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.framework",
	Name:      "ValidationException",
}, smithy.ShapeTypeStructure, 2)
var ValidationException_message *smithy.Schema

var ValidationException_fieldList *smithy.Schema

var ValidationExceptionField = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.framework",
	Name:      "ValidationExceptionField",
}, smithy.ShapeTypeStructure, 2)
var ValidationExceptionField_path *smithy.Schema

var ValidationExceptionField_message *smithy.Schema

var _ValidationExceptionFieldList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.framework",
	Name:      "ValidationExceptionFieldList",
}, smithy.ShapeTypeList, 1)
var _ValidationExceptionFieldList_member *smithy.Schema

var EmptyStructure = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "EmptyStructure",
}, smithy.ShapeTypeStructure, 0)

var Float16Output = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "Float16Output",
}, smithy.ShapeTypeStructure, 1)
var Float16Output_value *smithy.Schema

var FractionalSecondsOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "FractionalSecondsOutput",
}, smithy.ShapeTypeStructure, 1)
var FractionalSecondsOutput_datetime *smithy.Schema

var GreetingWithErrorsOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "GreetingWithErrorsOutput",
}, smithy.ShapeTypeStructure, 1)
var GreetingWithErrorsOutput_greeting *smithy.Schema

var OperationWithDefaultsInput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "OperationWithDefaultsInput",
}, smithy.ShapeTypeStructure, 4)
var OperationWithDefaultsInput_defaults *smithy.Schema

var OperationWithDefaultsInput_clientOptionalDefaults *smithy.Schema

var OperationWithDefaultsInput_topLevelDefault *smithy.Schema

var OperationWithDefaultsInput_otherTopLevelDefault *smithy.Schema

var OperationWithDefaultsOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "OperationWithDefaultsOutput",
}, smithy.ShapeTypeStructure, 23)
var OperationWithDefaultsOutput_defaultString *smithy.Schema

var OperationWithDefaultsOutput_defaultBoolean *smithy.Schema

var OperationWithDefaultsOutput_defaultList *smithy.Schema

var OperationWithDefaultsOutput_defaultTimestamp *smithy.Schema

var OperationWithDefaultsOutput_defaultBlob *smithy.Schema

var OperationWithDefaultsOutput_defaultByte *smithy.Schema

var OperationWithDefaultsOutput_defaultShort *smithy.Schema

var OperationWithDefaultsOutput_defaultInteger *smithy.Schema

var OperationWithDefaultsOutput_defaultLong *smithy.Schema

var OperationWithDefaultsOutput_defaultFloat *smithy.Schema

var OperationWithDefaultsOutput_defaultDouble *smithy.Schema

var OperationWithDefaultsOutput_defaultMap *smithy.Schema

var OperationWithDefaultsOutput_defaultEnum *smithy.Schema

var OperationWithDefaultsOutput_defaultIntEnum *smithy.Schema

var OperationWithDefaultsOutput_emptyString *smithy.Schema

var OperationWithDefaultsOutput_falseBoolean *smithy.Schema

var OperationWithDefaultsOutput_emptyBlob *smithy.Schema

var OperationWithDefaultsOutput_zeroByte *smithy.Schema

var OperationWithDefaultsOutput_zeroShort *smithy.Schema

var OperationWithDefaultsOutput_zeroInteger *smithy.Schema

var OperationWithDefaultsOutput_zeroLong *smithy.Schema

var OperationWithDefaultsOutput_zeroFloat *smithy.Schema

var OperationWithDefaultsOutput_zeroDouble *smithy.Schema

var SimpleStructure = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "SimpleStructure",
}, smithy.ShapeTypeStructure, 1)
var SimpleStructure_value *smithy.Schema

var RecursiveShapesInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "RecursiveShapesInputOutput",
}, smithy.ShapeTypeStructure, 1)
var RecursiveShapesInputOutput_nested *smithy.Schema

var RpcV2CborDenseMapsInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "RpcV2CborDenseMapsInputOutput",
}, smithy.ShapeTypeStructure, 5)
var RpcV2CborDenseMapsInputOutput_denseStructMap *smithy.Schema

var RpcV2CborDenseMapsInputOutput_denseNumberMap *smithy.Schema

var RpcV2CborDenseMapsInputOutput_denseBooleanMap *smithy.Schema

var RpcV2CborDenseMapsInputOutput_denseStringMap *smithy.Schema

var RpcV2CborDenseMapsInputOutput_denseSetMap *smithy.Schema

var RpcV2CborListInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "RpcV2CborListInputOutput",
}, smithy.ShapeTypeStructure, 10)
var RpcV2CborListInputOutput_stringList *smithy.Schema

var RpcV2CborListInputOutput_stringSet *smithy.Schema

var RpcV2CborListInputOutput_integerList *smithy.Schema

var RpcV2CborListInputOutput_booleanList *smithy.Schema

var RpcV2CborListInputOutput_timestampList *smithy.Schema

var RpcV2CborListInputOutput_enumList *smithy.Schema

var RpcV2CborListInputOutput_intEnumList *smithy.Schema

var RpcV2CborListInputOutput_nestedStringList *smithy.Schema

var RpcV2CborListInputOutput_structureList *smithy.Schema

var RpcV2CborListInputOutput_blobList *smithy.Schema

var RpcV2CborSparseMapsInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "RpcV2CborSparseMapsInputOutput",
}, smithy.ShapeTypeStructure, 5)
var RpcV2CborSparseMapsInputOutput_sparseStructMap *smithy.Schema

var RpcV2CborSparseMapsInputOutput_sparseNumberMap *smithy.Schema

var RpcV2CborSparseMapsInputOutput_sparseBooleanMap *smithy.Schema

var RpcV2CborSparseMapsInputOutput_sparseStringMap *smithy.Schema

var RpcV2CborSparseMapsInputOutput_sparseSetMap *smithy.Schema

var SimpleScalarStructure = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "SimpleScalarStructure",
}, smithy.ShapeTypeStructure, 10)
var SimpleScalarStructure_trueBooleanValue *smithy.Schema

var SimpleScalarStructure_falseBooleanValue *smithy.Schema

var SimpleScalarStructure_byteValue *smithy.Schema

var SimpleScalarStructure_doubleValue *smithy.Schema

var SimpleScalarStructure_floatValue *smithy.Schema

var SimpleScalarStructure_integerValue *smithy.Schema

var SimpleScalarStructure_longValue *smithy.Schema

var SimpleScalarStructure_shortValue *smithy.Schema

var SimpleScalarStructure_stringValue *smithy.Schema

var SimpleScalarStructure_blobValue *smithy.Schema

var SparseNullsOperationInputOutput = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "SparseNullsOperationInputOutput",
}, smithy.ShapeTypeStructure, 2)
var SparseNullsOperationInputOutput_sparseStringList *smithy.Schema

var SparseNullsOperationInputOutput_sparseStringMap *smithy.Schema

var ClientOptionalDefaults = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "ClientOptionalDefaults",
}, smithy.ShapeTypeStructure, 1)
var ClientOptionalDefaults_member *smithy.Schema

var ComplexError = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "ComplexError",
}, smithy.ShapeTypeStructure, 2)
var ComplexError_TopLevel *smithy.Schema

var ComplexError_Nested *smithy.Schema

var ComplexNestedErrorData = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "ComplexNestedErrorData",
}, smithy.ShapeTypeStructure, 1)
var ComplexNestedErrorData_Foo *smithy.Schema

var Defaults = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "Defaults",
}, smithy.ShapeTypeStructure, 23)
var Defaults_defaultString *smithy.Schema

var Defaults_defaultBoolean *smithy.Schema

var Defaults_defaultList *smithy.Schema

var Defaults_defaultTimestamp *smithy.Schema

var Defaults_defaultBlob *smithy.Schema

var Defaults_defaultByte *smithy.Schema

var Defaults_defaultShort *smithy.Schema

var Defaults_defaultInteger *smithy.Schema

var Defaults_defaultLong *smithy.Schema

var Defaults_defaultFloat *smithy.Schema

var Defaults_defaultDouble *smithy.Schema

var Defaults_defaultMap *smithy.Schema

var Defaults_defaultEnum *smithy.Schema

var Defaults_defaultIntEnum *smithy.Schema

var Defaults_emptyString *smithy.Schema

var Defaults_falseBoolean *smithy.Schema

var Defaults_emptyBlob *smithy.Schema

var Defaults_zeroByte *smithy.Schema

var Defaults_zeroShort *smithy.Schema

var Defaults_zeroInteger *smithy.Schema

var Defaults_zeroLong *smithy.Schema

var Defaults_zeroFloat *smithy.Schema

var Defaults_zeroDouble *smithy.Schema

var _DenseBooleanMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "DenseBooleanMap",
}, smithy.ShapeTypeMap, 2)
var _DenseBooleanMap_key *smithy.Schema

var _DenseBooleanMap_value *smithy.Schema

var _DenseNumberMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "DenseNumberMap",
}, smithy.ShapeTypeMap, 2)
var _DenseNumberMap_key *smithy.Schema

var _DenseNumberMap_value *smithy.Schema

var _DenseSetMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "DenseSetMap",
}, smithy.ShapeTypeMap, 2)
var _DenseSetMap_key *smithy.Schema

var _DenseSetMap_value *smithy.Schema

var _DenseStringMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "DenseStringMap",
}, smithy.ShapeTypeMap, 2)
var _DenseStringMap_key *smithy.Schema

var _DenseStringMap_value *smithy.Schema

var _DenseStructMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "DenseStructMap",
}, smithy.ShapeTypeMap, 2)
var _DenseStructMap_key *smithy.Schema

var _DenseStructMap_value *smithy.Schema

var InvalidGreeting = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "InvalidGreeting",
}, smithy.ShapeTypeStructure, 1)
var InvalidGreeting_Message *smithy.Schema

var RecursiveShapesInputOutputNested1 = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "RecursiveShapesInputOutputNested1",
}, smithy.ShapeTypeStructure, 2)
var RecursiveShapesInputOutputNested1_foo *smithy.Schema

var RecursiveShapesInputOutputNested1_nested *smithy.Schema

var RecursiveShapesInputOutputNested2 = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "RecursiveShapesInputOutputNested2",
}, smithy.ShapeTypeStructure, 2)
var RecursiveShapesInputOutputNested2_bar *smithy.Schema

var RecursiveShapesInputOutputNested2_recursiveMember *smithy.Schema

var _SparseBooleanMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "SparseBooleanMap",
}, smithy.ShapeTypeMap, 2)
var _SparseBooleanMap_key *smithy.Schema

var _SparseBooleanMap_value *smithy.Schema

var _SparseNumberMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "SparseNumberMap",
}, smithy.ShapeTypeMap, 2)
var _SparseNumberMap_key *smithy.Schema

var _SparseNumberMap_value *smithy.Schema

var _SparseSetMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "SparseSetMap",
}, smithy.ShapeTypeMap, 2)
var _SparseSetMap_key *smithy.Schema

var _SparseSetMap_value *smithy.Schema

var _SparseStructMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "SparseStructMap",
}, smithy.ShapeTypeMap, 2)
var _SparseStructMap_key *smithy.Schema

var _SparseStructMap_value *smithy.Schema

var _StructureList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "StructureList",
}, smithy.ShapeTypeList, 1)
var _StructureList_member *smithy.Schema

var StructureListMember = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "StructureListMember",
}, smithy.ShapeTypeStructure, 2)
var StructureListMember_a *smithy.Schema

var StructureListMember_b *smithy.Schema

var TestEnum = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "TestEnum",
}, smithy.ShapeTypeEnum, 3)
var TestEnum_FOO *smithy.Schema

var TestEnum_BAR *smithy.Schema

var TestEnum_BAZ *smithy.Schema

var _TestIntEnum = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "TestIntEnum",
}, smithy.ShapeTypeIntEnum, 2)
var _TestIntEnum_ONE *smithy.Schema

var _TestIntEnum_TWO *smithy.Schema

var _TestStringList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "TestStringList",
}, smithy.ShapeTypeList, 1)
var _TestStringList_member *smithy.Schema

var _TestStringMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.rpcv2Cbor",
	Name:      "TestStringMap",
}, smithy.ShapeTypeMap, 2)
var _TestStringMap_key *smithy.Schema

var _TestStringMap_value *smithy.Schema

var _BlobList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.shared",
	Name:      "BlobList",
}, smithy.ShapeTypeList, 1)
var _BlobList_member *smithy.Schema

var _BooleanList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.shared",
	Name:      "BooleanList",
}, smithy.ShapeTypeList, 1)
var _BooleanList_member *smithy.Schema

var _DateTime = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.shared",
	Name:      "DateTime",
}, smithy.ShapeTypeTimestamp, 0, &smithytraits.TimestampFormat{Format: "date-time"})

var FooEnum = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.shared",
	Name:      "FooEnum",
}, smithy.ShapeTypeEnum, 5)
var FooEnum_FOO *smithy.Schema

var FooEnum_BAZ *smithy.Schema

var FooEnum_BAR *smithy.Schema

var FooEnum_ONE *smithy.Schema

var FooEnum_ZERO *smithy.Schema

var _FooEnumList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.shared",
	Name:      "FooEnumList",
}, smithy.ShapeTypeList, 1)
var _FooEnumList_member *smithy.Schema

var GreetingStruct = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.shared",
	Name:      "GreetingStruct",
}, smithy.ShapeTypeStructure, 1)
var GreetingStruct_hi *smithy.Schema

var _IntegerEnum = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.shared",
	Name:      "IntegerEnum",
}, smithy.ShapeTypeIntEnum, 3)
var _IntegerEnum_A *smithy.Schema

var _IntegerEnum_B *smithy.Schema

var _IntegerEnum_C *smithy.Schema

var _IntegerEnumList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.shared",
	Name:      "IntegerEnumList",
}, smithy.ShapeTypeList, 1)
var _IntegerEnumList_member *smithy.Schema

var _IntegerList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.shared",
	Name:      "IntegerList",
}, smithy.ShapeTypeList, 1)
var _IntegerList_member *smithy.Schema

var _NestedStringList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.shared",
	Name:      "NestedStringList",
}, smithy.ShapeTypeList, 1)
var _NestedStringList_member *smithy.Schema

var _SparseStringList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.shared",
	Name:      "SparseStringList",
}, smithy.ShapeTypeList, 1)
var _SparseStringList_member *smithy.Schema

var _SparseStringMap = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.shared",
	Name:      "SparseStringMap",
}, smithy.ShapeTypeMap, 2)
var _SparseStringMap_key *smithy.Schema

var _SparseStringMap_value *smithy.Schema

var _StringList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.shared",
	Name:      "StringList",
}, smithy.ShapeTypeList, 1)
var _StringList_member *smithy.Schema

var _StringSet = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.shared",
	Name:      "StringSet",
}, smithy.ShapeTypeList, 1)
var _StringSet_member *smithy.Schema

var _TimestampList = smithy.NewSchema(smithy.ShapeID{
	Namespace: "smithy.protocoltests.shared",
	Name:      "TimestampList",
}, smithy.ShapeTypeList, 1)
var _TimestampList_member *smithy.Schema

// Initialize schema members after all schemas are declared to avoid
// initialization cycles
func init() {
	ValidationExceptionField_path = ValidationExceptionField.AddMember("path", smithyprelude.String)

	ValidationExceptionField_message = ValidationExceptionField.AddMember("message", smithyprelude.String)

	_ValidationExceptionFieldList_member = _ValidationExceptionFieldList.AddMember("member", ValidationExceptionField)

	ValidationException_message = ValidationException.AddMember("message", smithyprelude.String)

	ValidationException_fieldList = ValidationException.AddMember("fieldList", _ValidationExceptionFieldList)

	Float16Output_value = Float16Output.AddMember("value", smithyprelude.Double)

	FractionalSecondsOutput_datetime = FractionalSecondsOutput.AddMember("datetime", _DateTime)

	GreetingWithErrorsOutput_greeting = GreetingWithErrorsOutput.AddMember("greeting", smithyprelude.String)

	_TestStringList_member = _TestStringList.AddMember("member", smithyprelude.String)

	_TestStringMap_key = _TestStringMap.AddMember("key", smithyprelude.String)

	_TestStringMap_value = _TestStringMap.AddMember("value", smithyprelude.String)

	TestEnum_FOO = TestEnum.AddMember("FOO", smithyprelude.Unit)

	TestEnum_BAR = TestEnum.AddMember("BAR", smithyprelude.Unit)

	TestEnum_BAZ = TestEnum.AddMember("BAZ", smithyprelude.Unit)

	_TestIntEnum_ONE = _TestIntEnum.AddMember("ONE", smithyprelude.Unit)

	_TestIntEnum_TWO = _TestIntEnum.AddMember("TWO", smithyprelude.Unit)

	Defaults_defaultString = Defaults.AddMember("defaultString", smithyprelude.String)

	Defaults_defaultBoolean = Defaults.AddMember("defaultBoolean", smithyprelude.Boolean)

	Defaults_defaultList = Defaults.AddMember("defaultList", _TestStringList)

	Defaults_defaultTimestamp = Defaults.AddMember("defaultTimestamp", smithyprelude.Timestamp)

	Defaults_defaultBlob = Defaults.AddMember("defaultBlob", smithyprelude.Blob)

	Defaults_defaultByte = Defaults.AddMember("defaultByte", smithyprelude.Byte)

	Defaults_defaultShort = Defaults.AddMember("defaultShort", smithyprelude.Short)

	Defaults_defaultInteger = Defaults.AddMember("defaultInteger", smithyprelude.Integer)

	Defaults_defaultLong = Defaults.AddMember("defaultLong", smithyprelude.Long)

	Defaults_defaultFloat = Defaults.AddMember("defaultFloat", smithyprelude.Float)

	Defaults_defaultDouble = Defaults.AddMember("defaultDouble", smithyprelude.Double)

	Defaults_defaultMap = Defaults.AddMember("defaultMap", _TestStringMap)

	Defaults_defaultEnum = Defaults.AddMember("defaultEnum", TestEnum)

	Defaults_defaultIntEnum = Defaults.AddMember("defaultIntEnum", _TestIntEnum)

	Defaults_emptyString = Defaults.AddMember("emptyString", smithyprelude.String)

	Defaults_falseBoolean = Defaults.AddMember("falseBoolean", smithyprelude.Boolean)

	Defaults_emptyBlob = Defaults.AddMember("emptyBlob", smithyprelude.Blob)

	Defaults_zeroByte = Defaults.AddMember("zeroByte", smithyprelude.Byte)

	Defaults_zeroShort = Defaults.AddMember("zeroShort", smithyprelude.Short)

	Defaults_zeroInteger = Defaults.AddMember("zeroInteger", smithyprelude.Integer)

	Defaults_zeroLong = Defaults.AddMember("zeroLong", smithyprelude.Long)

	Defaults_zeroFloat = Defaults.AddMember("zeroFloat", smithyprelude.Float)

	Defaults_zeroDouble = Defaults.AddMember("zeroDouble", smithyprelude.Double)

	ClientOptionalDefaults_member = ClientOptionalDefaults.AddMember("member", smithyprelude.Integer)

	OperationWithDefaultsInput_defaults = OperationWithDefaultsInput.AddMember("defaults", Defaults)

	OperationWithDefaultsInput_clientOptionalDefaults = OperationWithDefaultsInput.AddMember("clientOptionalDefaults", ClientOptionalDefaults)

	OperationWithDefaultsInput_topLevelDefault = OperationWithDefaultsInput.AddMember("topLevelDefault", smithyprelude.String)

	OperationWithDefaultsInput_otherTopLevelDefault = OperationWithDefaultsInput.AddMember("otherTopLevelDefault", smithyprelude.Integer)

	OperationWithDefaultsOutput_defaultString = OperationWithDefaultsOutput.AddMember("defaultString", smithyprelude.String)

	OperationWithDefaultsOutput_defaultBoolean = OperationWithDefaultsOutput.AddMember("defaultBoolean", smithyprelude.Boolean)

	OperationWithDefaultsOutput_defaultList = OperationWithDefaultsOutput.AddMember("defaultList", _TestStringList)

	OperationWithDefaultsOutput_defaultTimestamp = OperationWithDefaultsOutput.AddMember("defaultTimestamp", smithyprelude.Timestamp)

	OperationWithDefaultsOutput_defaultBlob = OperationWithDefaultsOutput.AddMember("defaultBlob", smithyprelude.Blob)

	OperationWithDefaultsOutput_defaultByte = OperationWithDefaultsOutput.AddMember("defaultByte", smithyprelude.Byte)

	OperationWithDefaultsOutput_defaultShort = OperationWithDefaultsOutput.AddMember("defaultShort", smithyprelude.Short)

	OperationWithDefaultsOutput_defaultInteger = OperationWithDefaultsOutput.AddMember("defaultInteger", smithyprelude.Integer)

	OperationWithDefaultsOutput_defaultLong = OperationWithDefaultsOutput.AddMember("defaultLong", smithyprelude.Long)

	OperationWithDefaultsOutput_defaultFloat = OperationWithDefaultsOutput.AddMember("defaultFloat", smithyprelude.Float)

	OperationWithDefaultsOutput_defaultDouble = OperationWithDefaultsOutput.AddMember("defaultDouble", smithyprelude.Double)

	OperationWithDefaultsOutput_defaultMap = OperationWithDefaultsOutput.AddMember("defaultMap", _TestStringMap)

	OperationWithDefaultsOutput_defaultEnum = OperationWithDefaultsOutput.AddMember("defaultEnum", TestEnum)

	OperationWithDefaultsOutput_defaultIntEnum = OperationWithDefaultsOutput.AddMember("defaultIntEnum", _TestIntEnum)

	OperationWithDefaultsOutput_emptyString = OperationWithDefaultsOutput.AddMember("emptyString", smithyprelude.String)

	OperationWithDefaultsOutput_falseBoolean = OperationWithDefaultsOutput.AddMember("falseBoolean", smithyprelude.Boolean)

	OperationWithDefaultsOutput_emptyBlob = OperationWithDefaultsOutput.AddMember("emptyBlob", smithyprelude.Blob)

	OperationWithDefaultsOutput_zeroByte = OperationWithDefaultsOutput.AddMember("zeroByte", smithyprelude.Byte)

	OperationWithDefaultsOutput_zeroShort = OperationWithDefaultsOutput.AddMember("zeroShort", smithyprelude.Short)

	OperationWithDefaultsOutput_zeroInteger = OperationWithDefaultsOutput.AddMember("zeroInteger", smithyprelude.Integer)

	OperationWithDefaultsOutput_zeroLong = OperationWithDefaultsOutput.AddMember("zeroLong", smithyprelude.Long)

	OperationWithDefaultsOutput_zeroFloat = OperationWithDefaultsOutput.AddMember("zeroFloat", smithyprelude.Float)

	OperationWithDefaultsOutput_zeroDouble = OperationWithDefaultsOutput.AddMember("zeroDouble", smithyprelude.Double)

	SimpleStructure_value = SimpleStructure.AddMember("value", smithyprelude.String)

	RecursiveShapesInputOutputNested2_bar = RecursiveShapesInputOutputNested2.AddMember("bar", smithyprelude.String)

	RecursiveShapesInputOutputNested2_recursiveMember = RecursiveShapesInputOutputNested2.AddMember("recursiveMember", RecursiveShapesInputOutputNested1)

	RecursiveShapesInputOutputNested1_foo = RecursiveShapesInputOutputNested1.AddMember("foo", smithyprelude.String)

	RecursiveShapesInputOutputNested1_nested = RecursiveShapesInputOutputNested1.AddMember("nested", RecursiveShapesInputOutputNested2)

	RecursiveShapesInputOutput_nested = RecursiveShapesInputOutput.AddMember("nested", RecursiveShapesInputOutputNested1)

	GreetingStruct_hi = GreetingStruct.AddMember("hi", smithyprelude.String)

	_DenseStructMap_key = _DenseStructMap.AddMember("key", smithyprelude.String)

	_DenseStructMap_value = _DenseStructMap.AddMember("value", GreetingStruct)

	_DenseNumberMap_key = _DenseNumberMap.AddMember("key", smithyprelude.String)

	_DenseNumberMap_value = _DenseNumberMap.AddMember("value", smithyprelude.Integer)

	_DenseBooleanMap_key = _DenseBooleanMap.AddMember("key", smithyprelude.String)

	_DenseBooleanMap_value = _DenseBooleanMap.AddMember("value", smithyprelude.Boolean)

	_DenseStringMap_key = _DenseStringMap.AddMember("key", smithyprelude.String)

	_DenseStringMap_value = _DenseStringMap.AddMember("value", smithyprelude.String)

	_StringSet_member = _StringSet.AddMember("member", smithyprelude.String)

	_DenseSetMap_key = _DenseSetMap.AddMember("key", smithyprelude.String)

	_DenseSetMap_value = _DenseSetMap.AddMember("value", _StringSet)

	RpcV2CborDenseMapsInputOutput_denseStructMap = RpcV2CborDenseMapsInputOutput.AddMember("denseStructMap", _DenseStructMap)

	RpcV2CborDenseMapsInputOutput_denseNumberMap = RpcV2CborDenseMapsInputOutput.AddMember("denseNumberMap", _DenseNumberMap)

	RpcV2CborDenseMapsInputOutput_denseBooleanMap = RpcV2CborDenseMapsInputOutput.AddMember("denseBooleanMap", _DenseBooleanMap)

	RpcV2CborDenseMapsInputOutput_denseStringMap = RpcV2CborDenseMapsInputOutput.AddMember("denseStringMap", _DenseStringMap)

	RpcV2CborDenseMapsInputOutput_denseSetMap = RpcV2CborDenseMapsInputOutput.AddMember("denseSetMap", _DenseSetMap)

	_StringList_member = _StringList.AddMember("member", smithyprelude.String)

	_IntegerList_member = _IntegerList.AddMember("member", smithyprelude.Integer)

	_BooleanList_member = _BooleanList.AddMember("member", smithyprelude.Boolean)

	_TimestampList_member = _TimestampList.AddMember("member", smithyprelude.Timestamp)

	FooEnum_FOO = FooEnum.AddMember("FOO", smithyprelude.Unit)

	FooEnum_BAZ = FooEnum.AddMember("BAZ", smithyprelude.Unit)

	FooEnum_BAR = FooEnum.AddMember("BAR", smithyprelude.Unit)

	FooEnum_ONE = FooEnum.AddMember("ONE", smithyprelude.Unit)

	FooEnum_ZERO = FooEnum.AddMember("ZERO", smithyprelude.Unit)

	_FooEnumList_member = _FooEnumList.AddMember("member", FooEnum)

	_IntegerEnum_A = _IntegerEnum.AddMember("A", smithyprelude.Unit)

	_IntegerEnum_B = _IntegerEnum.AddMember("B", smithyprelude.Unit)

	_IntegerEnum_C = _IntegerEnum.AddMember("C", smithyprelude.Unit)

	_IntegerEnumList_member = _IntegerEnumList.AddMember("member", _IntegerEnum)

	_NestedStringList_member = _NestedStringList.AddMember("member", _StringList)

	StructureListMember_a = StructureListMember.AddMember("a", smithyprelude.String)

	StructureListMember_b = StructureListMember.AddMember("b", smithyprelude.String)

	_StructureList_member = _StructureList.AddMember("member", StructureListMember)

	_BlobList_member = _BlobList.AddMember("member", smithyprelude.Blob)

	RpcV2CborListInputOutput_stringList = RpcV2CborListInputOutput.AddMember("stringList", _StringList)

	RpcV2CborListInputOutput_stringSet = RpcV2CborListInputOutput.AddMember("stringSet", _StringSet)

	RpcV2CborListInputOutput_integerList = RpcV2CborListInputOutput.AddMember("integerList", _IntegerList)

	RpcV2CborListInputOutput_booleanList = RpcV2CborListInputOutput.AddMember("booleanList", _BooleanList)

	RpcV2CborListInputOutput_timestampList = RpcV2CborListInputOutput.AddMember("timestampList", _TimestampList)

	RpcV2CborListInputOutput_enumList = RpcV2CborListInputOutput.AddMember("enumList", _FooEnumList)

	RpcV2CborListInputOutput_intEnumList = RpcV2CborListInputOutput.AddMember("intEnumList", _IntegerEnumList)

	RpcV2CborListInputOutput_nestedStringList = RpcV2CborListInputOutput.AddMember("nestedStringList", _NestedStringList)

	RpcV2CborListInputOutput_structureList = RpcV2CborListInputOutput.AddMember("structureList", _StructureList)

	RpcV2CborListInputOutput_blobList = RpcV2CborListInputOutput.AddMember("blobList", _BlobList)

	_SparseStructMap_key = _SparseStructMap.AddMember("key", smithyprelude.String)

	_SparseStructMap_value = _SparseStructMap.AddMember("value", GreetingStruct)

	_SparseNumberMap_key = _SparseNumberMap.AddMember("key", smithyprelude.String)

	_SparseNumberMap_value = _SparseNumberMap.AddMember("value", smithyprelude.Integer)

	_SparseBooleanMap_key = _SparseBooleanMap.AddMember("key", smithyprelude.String)

	_SparseBooleanMap_value = _SparseBooleanMap.AddMember("value", smithyprelude.Boolean)

	_SparseStringMap_key = _SparseStringMap.AddMember("key", smithyprelude.String)

	_SparseStringMap_value = _SparseStringMap.AddMember("value", smithyprelude.String)

	_SparseSetMap_key = _SparseSetMap.AddMember("key", smithyprelude.String)

	_SparseSetMap_value = _SparseSetMap.AddMember("value", _StringSet)

	RpcV2CborSparseMapsInputOutput_sparseStructMap = RpcV2CborSparseMapsInputOutput.AddMember("sparseStructMap", _SparseStructMap)

	RpcV2CborSparseMapsInputOutput_sparseNumberMap = RpcV2CborSparseMapsInputOutput.AddMember("sparseNumberMap", _SparseNumberMap)

	RpcV2CborSparseMapsInputOutput_sparseBooleanMap = RpcV2CborSparseMapsInputOutput.AddMember("sparseBooleanMap", _SparseBooleanMap)

	RpcV2CborSparseMapsInputOutput_sparseStringMap = RpcV2CborSparseMapsInputOutput.AddMember("sparseStringMap", _SparseStringMap)

	RpcV2CborSparseMapsInputOutput_sparseSetMap = RpcV2CborSparseMapsInputOutput.AddMember("sparseSetMap", _SparseSetMap)

	SimpleScalarStructure_trueBooleanValue = SimpleScalarStructure.AddMember("trueBooleanValue", smithyprelude.Boolean)

	SimpleScalarStructure_falseBooleanValue = SimpleScalarStructure.AddMember("falseBooleanValue", smithyprelude.Boolean)

	SimpleScalarStructure_byteValue = SimpleScalarStructure.AddMember("byteValue", smithyprelude.Byte)

	SimpleScalarStructure_doubleValue = SimpleScalarStructure.AddMember("doubleValue", smithyprelude.Double)

	SimpleScalarStructure_floatValue = SimpleScalarStructure.AddMember("floatValue", smithyprelude.Float)

	SimpleScalarStructure_integerValue = SimpleScalarStructure.AddMember("integerValue", smithyprelude.Integer)

	SimpleScalarStructure_longValue = SimpleScalarStructure.AddMember("longValue", smithyprelude.Long)

	SimpleScalarStructure_shortValue = SimpleScalarStructure.AddMember("shortValue", smithyprelude.Short)

	SimpleScalarStructure_stringValue = SimpleScalarStructure.AddMember("stringValue", smithyprelude.String)

	SimpleScalarStructure_blobValue = SimpleScalarStructure.AddMember("blobValue", smithyprelude.Blob)

	_SparseStringList_member = _SparseStringList.AddMember("member", smithyprelude.String)

	SparseNullsOperationInputOutput_sparseStringList = SparseNullsOperationInputOutput.AddMember("sparseStringList", _SparseStringList)

	SparseNullsOperationInputOutput_sparseStringMap = SparseNullsOperationInputOutput.AddMember("sparseStringMap", _SparseStringMap)

	ComplexNestedErrorData_Foo = ComplexNestedErrorData.AddMember("Foo", smithyprelude.String)

	ComplexError_TopLevel = ComplexError.AddMember("TopLevel", smithyprelude.String)

	ComplexError_Nested = ComplexError.AddMember("Nested", ComplexNestedErrorData)

	InvalidGreeting_Message = InvalidGreeting.AddMember("Message", smithyprelude.String)

}
