// Code generated by smithy-go-codegen DO NOT EDIT.

// Package devicefarm provides the API client, operations, and parameter types for
// AWS Device Farm.
//
// Welcome to the AWS Device Farm API documentation, which contains APIs for:
//
//   - Testing on desktop browsers
//
// Device Farm makes it possible for you to test your web applications on desktop
//
//	browsers using Selenium. The APIs for desktop browser testing contain TestGrid
//	in their names. For more information, see [Testing Web Applications on Selenium with Device Farm].
//
//	- Testing on real mobile devices
//
// Device Farm makes it possible for you to test apps on physical phones, tablets,
//
//	and other devices in the cloud. For more information, see the [Device Farm Developer Guide].
//
// [Device Farm Developer Guide]: https://docs.aws.amazon.com/devicefarm/latest/developerguide/
// [Testing Web Applications on Selenium with Device Farm]: https://docs.aws.amazon.com/devicefarm/latest/testgrid/
package devicefarm
