// Code generated by smithy-go-codegen DO NOT EDIT.

package directconnect

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/directconnect/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Get and view a list of customer agreements, along with their signed status and
// whether the customer is an NNIPartner, NNIPartnerV2, or a nonPartner.
func (c *Client) DescribeCustomerMetadata(ctx context.Context, params *DescribeCustomerMetadataInput, optFns ...func(*Options)) (*DescribeCustomerMetadataOutput, error) {
	if params == nil {
		params = &DescribeCustomerMetadataInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DescribeCustomerMetadata", params, optFns, c.addOperationDescribeCustomerMetadataMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DescribeCustomerMetadataOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DescribeCustomerMetadataInput struct {
	noSmithyDocumentSerde
}

type DescribeCustomerMetadataOutput struct {

	// The list of customer agreements.
	Agreements []types.CustomerAgreement

	// The type of network-to-network interface (NNI) partner. The partner type will
	// be one of the following:
	//
	//   - V1: This partner can only allocate 50Mbps, 100Mbps, 200Mbps, 300Mbps,
	//   400Mbps, or 500Mbps subgigabit connections.
	//
	//   - V2: This partner can only allocate 1GB, 2GB, 5GB, or 10GB hosted
	//   connections.
	//
	//   - nonPartner: The customer is not a partner.
	NniPartnerType types.NniPartnerType

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDescribeCustomerMetadataMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson11_serializeOpDescribeCustomerMetadata{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson11_deserializeOpDescribeCustomerMetadata{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DescribeCustomerMetadata"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
