// Code generated by smithy-go-codegen DO NOT EDIT.

package datazone

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/datazone/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
	"time"
)

// Gets a project in Amazon DataZone.
func (c *Client) GetProject(ctx context.Context, params *GetProjectInput, optFns ...func(*Options)) (*GetProjectOutput, error) {
	if params == nil {
		params = &GetProjectInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetProject", params, optFns, c.addOperationGetProjectMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetProjectOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetProjectInput struct {

	// The ID of the Amazon DataZone domain in which the project exists.
	//
	// This member is required.
	DomainIdentifier *string

	// The ID of the project.
	//
	// This member is required.
	Identifier *string

	noSmithyDocumentSerde
}

type GetProjectOutput struct {

	// The Amazon DataZone user who created the project.
	//
	// This member is required.
	CreatedBy *string

	// The ID of the Amazon DataZone domain in which the project exists.
	//
	// This member is required.
	DomainId *string

	// >The ID of the project.
	//
	// This member is required.
	Id *string

	// The name of the project.
	//
	// This member is required.
	Name *string

	// The timestamp of when the project was created.
	CreatedAt *time.Time

	// The description of the project.
	Description *string

	// The ID of the domain unit.
	DomainUnitId *string

	// The environment deployment status of a project.
	EnvironmentDeploymentDetails *types.EnvironmentDeploymentDetails

	// Specifies the error message that is returned if the operation cannot be
	// successfully completed.
	FailureReasons []types.ProjectDeletionError

	// The business glossary terms that can be used in the project.
	GlossaryTerms []string

	// The timestamp of when the project was last updated.
	LastUpdatedAt *time.Time

	// The category of the project.
	ProjectCategory *string

	// The ID of the project profile of a project.
	ProjectProfileId *string

	// The status of the project.
	ProjectStatus types.ProjectStatus

	// The resource tags of the project.
	ResourceTags []types.ResourceTag

	// The user parameters of a project.
	UserParameters []types.EnvironmentConfigurationUserParameter

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetProjectMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpGetProject{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpGetProject{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetProjectValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetProject"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
