// Code generated by smithy-go-codegen DO NOT EDIT.

package appstream

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/appstream/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Retrieves license included application usage information.
func (c *Client) DescribeAppLicenseUsage(ctx context.Context, params *DescribeAppLicenseUsageInput, optFns ...func(*Options)) (*DescribeAppLicenseUsageOutput, error) {
	if params == nil {
		params = &DescribeAppLicenseUsageInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DescribeAppLicenseUsage", params, optFns, c.addOperationDescribeAppLicenseUsageMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DescribeAppLicenseUsageOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DescribeAppLicenseUsageInput struct {

	// Billing period for the usage record.
	//
	// Specify the value in yyyy-mm format. For example, for August 2025, use 2025-08.
	//
	// This member is required.
	BillingPeriod *string

	// The maximum number of results to return.
	MaxResults *int32

	// Token for pagination of results.
	NextToken *string

	noSmithyDocumentSerde
}

type DescribeAppLicenseUsageOutput struct {

	// Collection of license usage records.
	AppLicenseUsages []types.AdminAppLicenseUsageRecord

	// Token for pagination of results.
	NextToken *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDescribeAppLicenseUsageMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson11_serializeOpDescribeAppLicenseUsage{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson11_deserializeOpDescribeAppLicenseUsage{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpDescribeAppLicenseUsageValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DescribeAppLicenseUsage"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
