// Code generated by smithy-go-codegen DO NOT EDIT.

package bedrockagentcorecontrol

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/bedrockagentcorecontrol/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

//	Deletes a custom evaluator. Builtin evaluators cannot be deleted. The
//
// evaluator must not be referenced by any active online evaluation configurations.
func (c *Client) DeleteEvaluator(ctx context.Context, params *DeleteEvaluatorInput, optFns ...func(*Options)) (*DeleteEvaluatorOutput, error) {
	if params == nil {
		params = &DeleteEvaluatorInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DeleteEvaluator", params, optFns, c.addOperationDeleteEvaluatorMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DeleteEvaluatorOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DeleteEvaluatorInput struct {

	//  The unique identifier of the evaluator to delete.
	//
	// This member is required.
	EvaluatorId *string

	noSmithyDocumentSerde
}

type DeleteEvaluatorOutput struct {

	//  The Amazon Resource Name (ARN) of the deleted evaluator.
	//
	// This member is required.
	EvaluatorArn *string

	//  The unique identifier of the deleted evaluator.
	//
	// This member is required.
	EvaluatorId *string

	//  The status of the evaluator deletion operation.
	//
	// This member is required.
	Status types.EvaluatorStatus

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDeleteEvaluatorMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpDeleteEvaluator{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpDeleteEvaluator{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpDeleteEvaluatorValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DeleteEvaluator"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
