// Code generated by smithy-go-codegen DO NOT EDIT.

package connectcases

import (
	"context"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Deletes a case rule. In the Amazon Connect admin website, case rules are known
// as case field conditions. For more information about case field conditions, see [Add case field conditions to a case template]
// .
//
// [Add case field conditions to a case template]: https://docs.aws.amazon.com/connect/latest/adminguide/case-field-conditions.html
func (c *Client) DeleteCaseRule(ctx context.Context, params *DeleteCaseRuleInput, optFns ...func(*Options)) (*DeleteCaseRuleOutput, error) {
	if params == nil {
		params = &DeleteCaseRuleInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DeleteCaseRule", params, optFns, c.addOperationDeleteCaseRuleMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DeleteCaseRuleOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DeleteCaseRuleInput struct {

	// Unique identifier of a case rule.
	//
	// This member is required.
	CaseRuleId *string

	// Unique identifier of a Cases domain.
	//
	// This member is required.
	DomainId *string

	noSmithyDocumentSerde
}

type DeleteCaseRuleOutput struct {
	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDeleteCaseRuleMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpDeleteCaseRule{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpDeleteCaseRule{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpDeleteCaseRuleValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DeleteCaseRule"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
