// Code generated by smithy-go-codegen DO NOT EDIT.

package connect

import (
	"context"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Deletes a traffic distribution group. This API can be called only in the Region
// where the traffic distribution group is created.
//
// For more information about deleting traffic distribution groups, see [Delete traffic distribution groups] in the
// Connect Customer Administrator Guide.
//
// [Delete traffic distribution groups]: https://docs.aws.amazon.com/connect/latest/adminguide/delete-traffic-distribution-groups.html
func (c *Client) DeleteTrafficDistributionGroup(ctx context.Context, params *DeleteTrafficDistributionGroupInput, optFns ...func(*Options)) (*DeleteTrafficDistributionGroupOutput, error) {
	if params == nil {
		params = &DeleteTrafficDistributionGroupInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DeleteTrafficDistributionGroup", params, optFns, c.addOperationDeleteTrafficDistributionGroupMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DeleteTrafficDistributionGroupOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DeleteTrafficDistributionGroupInput struct {

	// The identifier of the traffic distribution group. This can be the ID or the ARN
	// of the traffic distribution group.
	//
	// This member is required.
	TrafficDistributionGroupId *string

	noSmithyDocumentSerde
}

type DeleteTrafficDistributionGroupOutput struct {
	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDeleteTrafficDistributionGroupMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpDeleteTrafficDistributionGroup{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpDeleteTrafficDistributionGroup{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpDeleteTrafficDistributionGroupValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DeleteTrafficDistributionGroup"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
