// Code generated by smithy-go-codegen DO NOT EDIT.

package backup

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/backup/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Returns RestoreTestingSelection, which displays resources and elements of the
// restore testing plan.
func (c *Client) GetRestoreTestingSelection(ctx context.Context, params *GetRestoreTestingSelectionInput, optFns ...func(*Options)) (*GetRestoreTestingSelectionOutput, error) {
	if params == nil {
		params = &GetRestoreTestingSelectionInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetRestoreTestingSelection", params, optFns, c.addOperationGetRestoreTestingSelectionMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetRestoreTestingSelectionOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetRestoreTestingSelectionInput struct {

	// Required unique name of the restore testing plan.
	//
	// This member is required.
	RestoreTestingPlanName *string

	// Required unique name of the restore testing selection.
	//
	// This member is required.
	RestoreTestingSelectionName *string

	noSmithyDocumentSerde
}

type GetRestoreTestingSelectionOutput struct {

	// Unique name of the restore testing selection.
	//
	// This member is required.
	RestoreTestingSelection *types.RestoreTestingSelectionForGet

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetRestoreTestingSelectionMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpGetRestoreTestingSelection{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpGetRestoreTestingSelection{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetRestoreTestingSelectionValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetRestoreTestingSelection"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
