// Code generated by smithy-go-codegen DO NOT EDIT.

package bedrockagentcore

import (
	"context"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Retrieves the API key associated with an API key credential provider.
func (c *Client) GetResourceApiKey(ctx context.Context, params *GetResourceApiKeyInput, optFns ...func(*Options)) (*GetResourceApiKeyOutput, error) {
	if params == nil {
		params = &GetResourceApiKeyInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetResourceApiKey", params, optFns, c.addOperationGetResourceApiKeyMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetResourceApiKeyOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetResourceApiKeyInput struct {

	// The credential provider name for the resource from which you are retrieving the
	// API key.
	//
	// This member is required.
	ResourceCredentialProviderName *string

	// The identity token of the workload from which you want to retrieve the API key.
	//
	// This member is required.
	WorkloadIdentityToken *string

	noSmithyDocumentSerde
}

type GetResourceApiKeyOutput struct {

	// The API key associated with the resource requested.
	//
	// This member is required.
	ApiKey *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetResourceApiKeyMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpGetResourceApiKey{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpGetResourceApiKey{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetResourceApiKeyValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetResourceApiKey"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
