// Code generated by smithy-go-codegen DO NOT EDIT.

package datazone

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/datazone/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
	"time"
)

// Gets the details of the specified domain unit.
func (c *Client) GetDomainUnit(ctx context.Context, params *GetDomainUnitInput, optFns ...func(*Options)) (*GetDomainUnitOutput, error) {
	if params == nil {
		params = &GetDomainUnitInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetDomainUnit", params, optFns, c.addOperationGetDomainUnitMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetDomainUnitOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetDomainUnitInput struct {

	// The ID of the domain where you want to get a domain unit.
	//
	// This member is required.
	DomainIdentifier *string

	// The identifier of the domain unit that you want to get.
	//
	// This member is required.
	Identifier *string

	noSmithyDocumentSerde
}

type GetDomainUnitOutput struct {

	// The ID of the domain in which the domain unit lives.
	//
	// This member is required.
	DomainId *string

	// The ID of the domain unit.
	//
	// This member is required.
	Id *string

	// The name of the domain unit.
	//
	// This member is required.
	Name *string

	// The owners of the domain unit.
	//
	// This member is required.
	Owners []types.DomainUnitOwnerProperties

	// The time stamp at which the domain unit was created.
	CreatedAt *time.Time

	// The user who created the domain unit.
	CreatedBy *string

	// The description of the domain unit.
	Description *string

	// The timestamp at which the domain unit was last updated.
	LastUpdatedAt *time.Time

	// The user who last updated the domain unit.
	LastUpdatedBy *string

	// The ID of the parent domain unit.
	ParentDomainUnitId *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetDomainUnitMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpGetDomainUnit{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpGetDomainUnit{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetDomainUnitValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetDomainUnit"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
