// Code generated by smithy-go-codegen DO NOT EDIT.

// Package nonquerycompatiblerpcv2protocol provides the API client, operations,
// and parameter types for Non Query Compatible RpcV2 Protocol Service.
package nonquerycompatiblerpcv2protocol
