// Code generated by smithy-go-codegen DO NOT EDIT.

package customerprofiles

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/customerprofiles/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Returns a list of history records for a specific profile, for a specific domain.
func (c *Client) ListProfileHistoryRecords(ctx context.Context, params *ListProfileHistoryRecordsInput, optFns ...func(*Options)) (*ListProfileHistoryRecordsOutput, error) {
	if params == nil {
		params = &ListProfileHistoryRecordsInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "ListProfileHistoryRecords", params, optFns, c.addOperationListProfileHistoryRecordsMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*ListProfileHistoryRecordsOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type ListProfileHistoryRecordsInput struct {

	// The unique name of the domain for which to return profile history records.
	//
	// This member is required.
	DomainName *string

	// The identifier of the profile to be taken.
	//
	// This member is required.
	ProfileId *string

	// Applies a filter to include profile history records only with the specified
	// ActionType value in the response.
	ActionType types.ActionType

	// The maximum number of results to return per page.
	MaxResults *int32

	// The token for the next set of results. Use the value returned in the previous
	// response in the next request to retrieve the next set of results.
	NextToken *string

	// Applies a filter to include profile history records only with the specified
	// ObjectTypeName value in the response.
	ObjectTypeName *string

	// Applies a filter to include profile history records only with the specified
	// PerformedBy value in the response. The PerformedBy value can be the Amazon
	// Resource Name (ARN) of the person or service principal who performed the action.
	PerformedBy *string

	noSmithyDocumentSerde
}

type ListProfileHistoryRecordsOutput struct {

	// If there are additional results, this is the token for the next set of results.
	NextToken *string

	// The list of profile history records.
	ProfileHistoryRecords []types.ProfileHistoryRecord

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationListProfileHistoryRecordsMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpListProfileHistoryRecords{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpListProfileHistoryRecords{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpListProfileHistoryRecordsValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "ListProfileHistoryRecords"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
