// Code generated by smithy-go-codegen DO NOT EDIT.

package ec2

import (
	"context"
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/ec2/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Describes IPAM pool allocations. You can describe all allocations owned by you
// across all pools, or you can describe specific allocations by ID.
//
// If you specify IpamPoolAllocationIds , the results include only the specified
// allocations. If you do not specify IpamPoolAllocationIds , the results include
// all allocations owned by you. You can use Filters to narrow the results.
//
// This action returns only allocations directly owned by you. To view all
// allocations in a pool you own or that has been shared with you, including
// allocations owned by other accounts, use [GetIpamPoolAllocations].
//
// [GetIpamPoolAllocations]: https://docs.aws.amazon.com/AWSEC2/latest/APIReference/API_GetIpamPoolAllocations.html
func (c *Client) DescribeIpamPoolAllocations(ctx context.Context, params *DescribeIpamPoolAllocationsInput, optFns ...func(*Options)) (*DescribeIpamPoolAllocationsOutput, error) {
	if params == nil {
		params = &DescribeIpamPoolAllocationsInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DescribeIpamPoolAllocations", params, optFns, c.addOperationDescribeIpamPoolAllocationsMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DescribeIpamPoolAllocationsOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DescribeIpamPoolAllocationsInput struct {

	// A check for whether you have the required permissions for the action without
	// actually making the request and provides an error response. If you have the
	// required permissions, the error response is DryRunOperation . Otherwise, it is
	// UnauthorizedOperation .
	DryRun *bool

	// One or more filters for the request. For more information about filtering, see [Filtering CLI output].
	//
	// [Filtering CLI output]: https://docs.aws.amazon.com/cli/latest/userguide/cli-usage-filter.html
	Filters []types.Filter

	// The IDs of the IPAM pool allocations you want to describe.
	IpamPoolAllocationIds []string

	// The maximum number of items to return for this request. To get the next page of
	// items, make another request with the token returned in the output. For more
	// information, see [Pagination].
	//
	// [Pagination]: https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
	MaxResults *int32

	// The token for the next page of results.
	NextToken *string

	noSmithyDocumentSerde
}

type DescribeIpamPoolAllocationsOutput struct {

	// Information about the IPAM pool allocations.
	IpamPoolAllocations []types.IpamPoolAllocation

	// The token to use to retrieve the next page of results. This value is null when
	// there are no more results to return.
	NextToken *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDescribeIpamPoolAllocationsMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsEc2query_serializeOpDescribeIpamPoolAllocations{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsEc2query_deserializeOpDescribeIpamPoolAllocations{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DescribeIpamPoolAllocations"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}

// DescribeIpamPoolAllocationsPaginatorOptions is the paginator options for
// DescribeIpamPoolAllocations
type DescribeIpamPoolAllocationsPaginatorOptions struct {
	// The maximum number of items to return for this request. To get the next page of
	// items, make another request with the token returned in the output. For more
	// information, see [Pagination].
	//
	// [Pagination]: https://docs.aws.amazon.com/AWSEC2/latest/APIReference/Query-Requests.html#api-pagination
	Limit int32

	// Set to true if pagination should stop if the service returns a pagination token
	// that matches the most recent token provided to the service.
	StopOnDuplicateToken bool
}

// DescribeIpamPoolAllocationsPaginator is a paginator for
// DescribeIpamPoolAllocations
type DescribeIpamPoolAllocationsPaginator struct {
	options   DescribeIpamPoolAllocationsPaginatorOptions
	client    DescribeIpamPoolAllocationsAPIClient
	params    *DescribeIpamPoolAllocationsInput
	nextToken *string
	firstPage bool
}

// NewDescribeIpamPoolAllocationsPaginator returns a new
// DescribeIpamPoolAllocationsPaginator
func NewDescribeIpamPoolAllocationsPaginator(client DescribeIpamPoolAllocationsAPIClient, params *DescribeIpamPoolAllocationsInput, optFns ...func(*DescribeIpamPoolAllocationsPaginatorOptions)) *DescribeIpamPoolAllocationsPaginator {
	if params == nil {
		params = &DescribeIpamPoolAllocationsInput{}
	}

	options := DescribeIpamPoolAllocationsPaginatorOptions{}
	if params.MaxResults != nil {
		options.Limit = *params.MaxResults
	}

	for _, fn := range optFns {
		fn(&options)
	}

	return &DescribeIpamPoolAllocationsPaginator{
		options:   options,
		client:    client,
		params:    params,
		firstPage: true,
		nextToken: params.NextToken,
	}
}

// HasMorePages returns a boolean indicating whether more pages are available
func (p *DescribeIpamPoolAllocationsPaginator) HasMorePages() bool {
	return p.firstPage || (p.nextToken != nil && len(*p.nextToken) != 0)
}

// NextPage retrieves the next DescribeIpamPoolAllocations page.
func (p *DescribeIpamPoolAllocationsPaginator) NextPage(ctx context.Context, optFns ...func(*Options)) (*DescribeIpamPoolAllocationsOutput, error) {
	if !p.HasMorePages() {
		return nil, fmt.Errorf("no more pages available")
	}

	params := *p.params
	params.NextToken = p.nextToken

	var limit *int32
	if p.options.Limit > 0 {
		limit = &p.options.Limit
	}
	params.MaxResults = limit

	optFns = append([]func(*Options){
		addIsPaginatorUserAgent,
	}, optFns...)
	result, err := p.client.DescribeIpamPoolAllocations(ctx, &params, optFns...)
	if err != nil {
		return nil, err
	}
	p.firstPage = false

	prevToken := p.nextToken
	p.nextToken = result.NextToken

	if p.options.StopOnDuplicateToken &&
		prevToken != nil &&
		p.nextToken != nil &&
		*prevToken == *p.nextToken {
		p.nextToken = nil
	}

	return result, nil
}

// DescribeIpamPoolAllocationsAPIClient is a client that implements the
// DescribeIpamPoolAllocations operation.
type DescribeIpamPoolAllocationsAPIClient interface {
	DescribeIpamPoolAllocations(context.Context, *DescribeIpamPoolAllocationsInput, ...func(*Options)) (*DescribeIpamPoolAllocationsOutput, error)
}

var _ DescribeIpamPoolAllocationsAPIClient = (*Client)(nil)
