// Code generated by smithy-go-codegen DO NOT EDIT.

package backup

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/backup/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Returns TieringConfiguration details for the specified TieringConfigurationName
// . The details are the body of a tiering configuration in JSON format, in
// addition to configuration metadata.
func (c *Client) GetTieringConfiguration(ctx context.Context, params *GetTieringConfigurationInput, optFns ...func(*Options)) (*GetTieringConfigurationOutput, error) {
	if params == nil {
		params = &GetTieringConfigurationInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetTieringConfiguration", params, optFns, c.addOperationGetTieringConfigurationMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetTieringConfigurationOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetTieringConfigurationInput struct {

	// The unique name of a tiering configuration.
	//
	// This member is required.
	TieringConfigurationName *string

	noSmithyDocumentSerde
}

type GetTieringConfigurationOutput struct {

	// Specifies the body of a tiering configuration. Includes TieringConfigurationName
	// .
	TieringConfiguration *types.TieringConfiguration

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetTieringConfigurationMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpGetTieringConfiguration{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpGetTieringConfiguration{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetTieringConfigurationValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetTieringConfiguration"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
