// Code generated by smithy-go-codegen DO NOT EDIT.

// Package deadline provides the API client, operations, and parameter types for
// AWSDeadlineCloud.
//
// The Amazon Web Services Deadline Cloud API provides infrastructure and
// centralized management for your projects. Use the Deadline Cloud API to onboard
// users, assign projects, and attach permissions specific to their job function.
//
// With Deadline Cloud, content production teams can deploy resources for their
// workforce securely in the cloud, reducing the costs of added physical
// infrastructure. Keep your content production operations secure, while allowing
// your contributors to access the tools they need, such as scalable high-speed
// storage, licenses, and cost management services.
package deadline
