// Code generated by smithy-go-codegen DO NOT EDIT.

// Package connectcontactlens provides the API client, operations, and parameter
// types for Amazon Connect Contact Lens.
//
// [Contact Lens actions]
//
// [Contact Lens data types]
//
// Amazon Connect Contact Lens enables you to analyze conversations between
// customer and agents, by using speech transcription, natural language processing,
// and intelligent search capabilities. It performs sentiment analysis, detects
// issues, and enables you to automatically categorize contacts.
//
// Amazon Connect Contact Lens provides both real-time and post-call analytics of
// customer-agent conversations. For more information, see [Analyze conversations using speech analytics]in the Amazon Connect
// Administrator Guide.
//
// [Contact Lens data types]: https://docs.aws.amazon.com/connect/latest/APIReference/API_Types_Amazon_Connect_Contact_Lens.html
// [Contact Lens actions]: https://docs.aws.amazon.com/connect/latest/APIReference/API_Operations_Amazon_Connect_Contact_Lens.html
// [Analyze conversations using speech analytics]: https://docs.aws.amazon.com/connect/latest/adminguide/analyze-conversations.html
package connectcontactlens
