// Code generated by smithy-go-codegen DO NOT EDIT.

package cloudwatchlogs

import (
	"context"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Disassociates a data source from an S3 Table Integration, removing query access
// and deleting all associated data from the integration.
func (c *Client) DisassociateSourceFromS3TableIntegration(ctx context.Context, params *DisassociateSourceFromS3TableIntegrationInput, optFns ...func(*Options)) (*DisassociateSourceFromS3TableIntegrationOutput, error) {
	if params == nil {
		params = &DisassociateSourceFromS3TableIntegrationInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DisassociateSourceFromS3TableIntegration", params, optFns, c.addOperationDisassociateSourceFromS3TableIntegrationMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DisassociateSourceFromS3TableIntegrationOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DisassociateSourceFromS3TableIntegrationInput struct {

	// The unique identifier of the association to remove between the data source and
	// S3 Table Integration.
	//
	// This member is required.
	Identifier *string

	noSmithyDocumentSerde
}

type DisassociateSourceFromS3TableIntegrationOutput struct {

	// The unique identifier of the association that was removed.
	Identifier *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDisassociateSourceFromS3TableIntegrationMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson11_serializeOpDisassociateSourceFromS3TableIntegration{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson11_deserializeOpDisassociateSourceFromS3TableIntegration{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpDisassociateSourceFromS3TableIntegrationValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DisassociateSourceFromS3TableIntegration"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
