// Code generated by smithy-go-codegen DO NOT EDIT.

package datasync

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/datasync/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Creates a transfer location for an Amazon FSx for Windows File Server file
// system. DataSync can use this location as a source or destination for
// transferring data.
//
// Before you begin, make sure that you understand how DataSync [accesses FSx for Windows File Server file systems].
//
// [accesses FSx for Windows File Server file systems]: https://docs.aws.amazon.com/datasync/latest/userguide/create-fsx-location.html#create-fsx-location-access
func (c *Client) CreateLocationFsxWindows(ctx context.Context, params *CreateLocationFsxWindowsInput, optFns ...func(*Options)) (*CreateLocationFsxWindowsOutput, error) {
	if params == nil {
		params = &CreateLocationFsxWindowsInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "CreateLocationFsxWindows", params, optFns, c.addOperationCreateLocationFsxWindowsMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*CreateLocationFsxWindowsOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type CreateLocationFsxWindowsInput struct {

	// Specifies the Amazon Resource Name (ARN) for the FSx for Windows File Server
	// file system.
	//
	// This member is required.
	FsxFilesystemArn *string

	// Specifies the ARNs of the Amazon EC2 security groups that provide access to
	// your file system's preferred subnet.
	//
	// The security groups that you specify must be able to communicate with your file
	// system's security groups. For information about configuring security groups for
	// file system access, see the [Amazon FSx for Windows File Server User Guide].
	//
	// If you choose a security group that doesn't allow connections from within
	// itself, do one of the following:
	//
	//   - Configure the security group to allow it to communicate within itself.
	//
	//   - Choose a different security group that can communicate with the mount
	//   target's security group.
	//
	// [Amazon FSx for Windows File Server User Guide]: https://docs.aws.amazon.com/fsx/latest/WindowsGuide/limit-access-security-groups.html
	//
	// This member is required.
	SecurityGroupArns []string

	// Specifies the user with the permissions to mount and access the files, folders,
	// and file metadata in your FSx for Windows File Server file system.
	//
	// For information about choosing a user with the right level of access for your
	// transfer, see [required permissions]for FSx for Windows File Server locations.
	//
	// [required permissions]: https://docs.aws.amazon.com/datasync/latest/userguide/create-fsx-location.html#create-fsx-windows-location-permissions
	//
	// This member is required.
	User *string

	// Specifies configuration information for a DataSync-managed secret, which
	// includes the password that DataSync uses to access a specific FSx Windows
	// storage location, with a customer-managed KMS key.
	//
	// When you include this parameter as part of a CreateLocationFsxWindows request,
	// you provide only the KMS key ARN. DataSync uses this KMS key together with the
	// Password you specify for to create a DataSync-managed secret to store the
	// location access credentials.
	//
	// Make sure that DataSync has permission to access the KMS key that you specify.
	// For more information, see [Using a service-managed secret encrypted with a custom KMS key].
	//
	// You can use either CmkSecretConfig (with Password ) or CustomSecretConfig
	// (without Password ) to provide credentials for a CreateLocationFsxWindows
	// request. Do not provide both parameters for the same request.
	//
	// [Using a service-managed secret encrypted with a custom KMS key]: https://docs.aws.amazon.com/datasync/latest/userguide/location-credentials.html#service-secret-custom-key
	CmkSecretConfig *types.CmkSecretConfig

	// Specifies configuration information for a customer-managed Secrets Manager
	// secret where the password for an FSx for Windows File Server storage location is
	// stored in plain text, in Secrets Manager. This configuration includes the secret
	// ARN, and the ARN for an IAM role that provides access to the secret. For more
	// information, see [Using a secret that you manage].
	//
	// You can use either CmkSecretConfig (with Password ) or CustomSecretConfig
	// (without Password ) to provide credentials for a CreateLocationFsxWindows
	// request. Do not provide both parameters for the same request.
	//
	// [Using a secret that you manage]: https://docs.aws.amazon.com/datasync/latest/userguide/location-credentials.html#custom-secret-custom-key
	CustomSecretConfig *types.CustomSecretConfig

	// Specifies the name of the Windows domain that the FSx for Windows File Server
	// file system belongs to.
	//
	// If you have multiple Active Directory domains in your environment, configuring
	// this parameter makes sure that DataSync connects to the right file system.
	Domain *string

	// Specifies the password of the user with the permissions to mount and access the
	// files, folders, and file metadata in your FSx for Windows File Server file
	// system.
	Password *string

	// Specifies a mount path for your file system using forward slashes. This is
	// where DataSync reads or writes data (depending on if this is a source or
	// destination location).
	Subdirectory *string

	// Specifies labels that help you categorize, filter, and search for your Amazon
	// Web Services resources. We recommend creating at least a name tag for your
	// location.
	Tags []types.TagListEntry

	noSmithyDocumentSerde
}

type CreateLocationFsxWindowsOutput struct {

	// The ARN of the FSx for Windows File Server file system location you created.
	LocationArn *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationCreateLocationFsxWindowsMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson11_serializeOpCreateLocationFsxWindows{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson11_deserializeOpCreateLocationFsxWindows{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpCreateLocationFsxWindowsValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "CreateLocationFsxWindows"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
