// Code generated by smithy-go-codegen DO NOT EDIT.

package devopsagent

import (
	"context"
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/devopsagent/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Retrieves given associations configured for a specific AgentSpace.
func (c *Client) GetAssociation(ctx context.Context, params *GetAssociationInput, optFns ...func(*Options)) (*GetAssociationOutput, error) {
	if params == nil {
		params = &GetAssociationInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetAssociation", params, optFns, c.addOperationGetAssociationMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetAssociationOutput)
	out.ResultMetadata = metadata
	return out, nil
}

// Input for retrieving a specific service association.
type GetAssociationInput struct {

	// The unique identifier of the AgentSpace
	//
	// This member is required.
	AgentSpaceId *string

	// The unique identifier of the given association.
	//
	// This member is required.
	AssociationId *string

	noSmithyDocumentSerde
}

// Output containing the requested association details.
type GetAssociationOutput struct {

	// Represents a service association within an AgentSpace, defining how the agent
	// interacts with external services.
	//
	// This member is required.
	Association *types.Association

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetAssociationMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpGetAssociation{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpGetAssociation{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addEndpointPrefix_opGetAssociationMiddleware(stack); err != nil {
		return err
	}
	if err = addOpGetAssociationValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetAssociation"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}

type endpointPrefix_opGetAssociationMiddleware struct {
}

func (*endpointPrefix_opGetAssociationMiddleware) ID() string {
	return "EndpointHostPrefix"
}

func (m *endpointPrefix_opGetAssociationMiddleware) HandleFinalize(ctx context.Context, in middleware.FinalizeInput, next middleware.FinalizeHandler) (
	out middleware.FinalizeOutput, metadata middleware.Metadata, err error,
) {
	if smithyhttp.GetHostnameImmutable(ctx) || smithyhttp.IsEndpointHostPrefixDisabled(ctx) {
		return next.HandleFinalize(ctx, in)
	}

	req, ok := in.Request.(*smithyhttp.Request)
	if !ok {
		return out, metadata, fmt.Errorf("unknown transport type %T", in.Request)
	}

	req.URL.Host = "cp." + req.URL.Host

	return next.HandleFinalize(ctx, in)
}
func addEndpointPrefix_opGetAssociationMiddleware(stack *middleware.Stack) error {
	return stack.Finalize.Insert(&endpointPrefix_opGetAssociationMiddleware{}, "ResolveEndpointV2", middleware.After)
}
