// Code generated by smithy-go-codegen DO NOT EDIT.

package cognitoidentityprovider

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/cognitoidentityprovider/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Lists all client secrets associated with a user pool app client. Returns
// metadata about the secrets. The response does not include pagination tokens as
// there are only 2 secrets at any given time and we return both with every
// ListUserPoolClientSecrets call. For security reasons, the response never reveals
// the actual secret value in ClientSecretValue.
func (c *Client) ListUserPoolClientSecrets(ctx context.Context, params *ListUserPoolClientSecretsInput, optFns ...func(*Options)) (*ListUserPoolClientSecretsOutput, error) {
	if params == nil {
		params = &ListUserPoolClientSecretsInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "ListUserPoolClientSecrets", params, optFns, c.addOperationListUserPoolClientSecretsMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*ListUserPoolClientSecretsOutput)
	out.ResultMetadata = metadata
	return out, nil
}

// The request to list client secrets for a user pool app client.
type ListUserPoolClientSecretsInput struct {

	// The ID of the app client whose secrets you want to list.
	//
	// This member is required.
	ClientId *string

	// The ID of the user pool that contains the app client.
	//
	// This member is required.
	UserPoolId *string

	// This API operation returns a limited number of results. The pagination token is
	// an identifier that you can present in an additional API request with the same
	// parameters. When you include the pagination token, Amazon Cognito returns the
	// next set of items after the current list. Subsequent requests return a new
	// pagination token. By use of this token, you can paginate through the full list
	// of items.
	NextToken *string

	noSmithyDocumentSerde
}

// The response containing the list of client secret metadata. This response does
// not include a NextToken field as all secrets are returned in a single response.
type ListUserPoolClientSecretsOutput struct {

	// A list of client secret descriptors containing the identifier and creation date
	// for each secret. For security reasons, the response never reveals the actual
	// secret value in ClientSecretValue.
	ClientSecrets []types.ClientSecretDescriptorType

	// The identifier that Amazon Cognito returned with the previous request to this
	// operation. When you include a pagination token in your request, Amazon Cognito
	// returns the next set of items in the list. By use of this token, you can
	// paginate through the full list of items.
	NextToken *string

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationListUserPoolClientSecretsMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson11_serializeOpListUserPoolClientSecrets{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson11_deserializeOpListUserPoolClientSecrets{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpListUserPoolClientSecretsValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "ListUserPoolClientSecrets"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
