// Code generated by smithy-go-codegen DO NOT EDIT.

package amp

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/amp/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
	"time"
)

// Describes the logging configuration for a Amazon Managed Service for Prometheus
// scraper.
func (c *Client) DescribeScraperLoggingConfiguration(ctx context.Context, params *DescribeScraperLoggingConfigurationInput, optFns ...func(*Options)) (*DescribeScraperLoggingConfigurationOutput, error) {
	if params == nil {
		params = &DescribeScraperLoggingConfigurationInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DescribeScraperLoggingConfiguration", params, optFns, c.addOperationDescribeScraperLoggingConfigurationMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DescribeScraperLoggingConfigurationOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DescribeScraperLoggingConfigurationInput struct {

	// The ID of the scraper whose logging configuration will be described.
	//
	// This member is required.
	ScraperId *string

	noSmithyDocumentSerde
}

type DescribeScraperLoggingConfigurationOutput struct {

	// The destination where scraper logs are sent.
	//
	// This member is required.
	LoggingDestination types.ScraperLoggingDestination

	// The date and time when the logging configuration was last modified.
	//
	// This member is required.
	ModifiedAt *time.Time

	// The list of scraper components configured for logging.
	//
	// This member is required.
	ScraperComponents []types.ScraperComponent

	// The ID of the scraper.
	//
	// This member is required.
	ScraperId *string

	// The status of the scraper logging configuration.
	//
	// This member is required.
	Status *types.ScraperLoggingConfigurationStatus

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDescribeScraperLoggingConfigurationMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpDescribeScraperLoggingConfiguration{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpDescribeScraperLoggingConfiguration{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpDescribeScraperLoggingConfigurationValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DescribeScraperLoggingConfiguration"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
