// Code generated by smithy-go-codegen DO NOT EDIT.

package connectcases

import (
	"context"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Deletes a layout from a cases template. You can delete up to 100 layouts per
// domain.
//
// After a layout is deleted:
//
//   - You can still retrieve the layout by calling GetLayout .
//
//   - You cannot update a deleted layout by calling UpdateLayout ; it throws a
//     ValidationException .
//
//   - Deleted layouts are not included in the ListLayouts response.
func (c *Client) DeleteLayout(ctx context.Context, params *DeleteLayoutInput, optFns ...func(*Options)) (*DeleteLayoutOutput, error) {
	if params == nil {
		params = &DeleteLayoutInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "DeleteLayout", params, optFns, c.addOperationDeleteLayoutMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*DeleteLayoutOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type DeleteLayoutInput struct {

	// The unique identifier of the Cases domain.
	//
	// This member is required.
	DomainId *string

	// The unique identifier of the layout.
	//
	// This member is required.
	LayoutId *string

	noSmithyDocumentSerde
}

type DeleteLayoutOutput struct {
	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationDeleteLayoutMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpDeleteLayout{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpDeleteLayout{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpDeleteLayoutValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "DeleteLayout"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
