// Code generated by smithy-go-codegen DO NOT EDIT.

package codestarconnections

import (
	"context"
	"github.com/aws/aws-sdk-go-v2/service/codestarconnections/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Returns the status of the sync with the Git repository for a specific Amazon
// Web Services resource.
func (c *Client) GetResourceSyncStatus(ctx context.Context, params *GetResourceSyncStatusInput, optFns ...func(*Options)) (*GetResourceSyncStatusOutput, error) {
	if params == nil {
		params = &GetResourceSyncStatusInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "GetResourceSyncStatus", params, optFns, c.addOperationGetResourceSyncStatusMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*GetResourceSyncStatusOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type GetResourceSyncStatusInput struct {

	// The name of the Amazon Web Services resource for the sync status with the Git
	// repository.
	//
	// This member is required.
	ResourceName *string

	// The sync type for the sync status with the Git repository.
	//
	// This member is required.
	SyncType types.SyncConfigurationType

	noSmithyDocumentSerde
}

type GetResourceSyncStatusOutput struct {

	// The latest sync for the sync status with the Git repository, whether successful
	// or not.
	//
	// This member is required.
	LatestSync *types.ResourceSyncAttempt

	// The desired state of the Amazon Web Services resource for the sync status with
	// the Git repository.
	DesiredState *types.Revision

	// The latest successful sync for the sync status with the Git repository.
	LatestSuccessfulSync *types.ResourceSyncAttempt

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationGetResourceSyncStatusMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsAwsjson10_serializeOpGetResourceSyncStatus{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsAwsjson10_deserializeOpGetResourceSyncStatus{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addOpGetResourceSyncStatusValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "GetResourceSyncStatus"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}
