// Code generated by smithy-go-codegen DO NOT EDIT.

package datazone

import (
	"context"
	"fmt"
	"github.com/aws/aws-sdk-go-v2/service/datazone/types"
	"github.com/aws/smithy-go/middleware"
	smithyhttp "github.com/aws/smithy-go/transport/http"
)

// Writes the attribute metadata.
func (c *Client) BatchPutAttributesMetadata(ctx context.Context, params *BatchPutAttributesMetadataInput, optFns ...func(*Options)) (*BatchPutAttributesMetadataOutput, error) {
	if params == nil {
		params = &BatchPutAttributesMetadataInput{}
	}

	result, metadata, err := c.invokeOperation(ctx, "BatchPutAttributesMetadata", params, optFns, c.addOperationBatchPutAttributesMetadataMiddlewares)
	if err != nil {
		return nil, err
	}

	out := result.(*BatchPutAttributesMetadataOutput)
	out.ResultMetadata = metadata
	return out, nil
}

type BatchPutAttributesMetadataInput struct {

	// The attributes of the metadata.
	//
	// This member is required.
	Attributes []types.AttributeInput

	// The domain ID where you want to write the attribute metadata.
	//
	// This member is required.
	DomainIdentifier *string

	// The entity ID for which you want to write the attribute metadata.
	//
	// This member is required.
	EntityIdentifier *string

	// The entity type for which you want to write the attribute metadata.
	//
	// This member is required.
	EntityType types.AttributeEntityType

	// A unique, case-sensitive identifier to ensure idempotency of the request. This
	// field is automatically populated if not provided.
	ClientToken *string

	noSmithyDocumentSerde
}

type BatchPutAttributesMetadataOutput struct {

	// The results of the BatchPutAttributeMetadata action.
	Attributes []types.BatchPutAttributeOutput

	// The errors generated when the BatchPutAttributeMetadata action is invoked.
	Errors []types.AttributeError

	// Metadata pertaining to the operation's result.
	ResultMetadata middleware.Metadata

	noSmithyDocumentSerde
}

func (c *Client) addOperationBatchPutAttributesMetadataMiddlewares(stack *middleware.Stack, options Options) (err error) {
	err = stack.Serialize.Add(&awsRestjson1_serializeOpBatchPutAttributesMetadata{}, middleware.After)
	if err != nil {
		return err
	}
	err = stack.Deserialize.Add(&awsRestjson1_deserializeOpBatchPutAttributesMetadata{}, middleware.After)
	if err != nil {
		return err
	}

	if err = addlegacyEndpointContextSetter(stack, options); err != nil {
		return err
	}
	if err = addComputeContentLength(stack); err != nil {
		return err
	}
	if err = addResolveEndpointMiddleware(stack, options); err != nil {
		return err
	}
	if err = addComputePayloadSHA256(stack); err != nil {
		return err
	}
	if err = addRecordResponseTiming(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddErrorCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = smithyhttp.AddCloseResponseBodyMiddleware(stack); err != nil {
		return err
	}
	if err = addCredentialSource(stack, options); err != nil {
		return err
	}
	if err = addIdempotencyToken_opBatchPutAttributesMetadataMiddleware(stack, options); err != nil {
		return err
	}
	if err = addOpBatchPutAttributesMetadataValidationMiddleware(stack); err != nil {
		return err
	}
	if err = stack.Initialize.Add(newServiceMetadataMiddleware(options.Region, "BatchPutAttributesMetadata"), middleware.Before); err != nil {
		return err
	}
	if err = addRequestIDRetrieverMiddleware(stack); err != nil {
		return err
	}
	if err = addResponseErrorMiddleware(stack); err != nil {
		return err
	}
	if err = addRequestResponseLogging(stack, options); err != nil {
		return err
	}
	if err = addDisableHTTPSMiddleware(stack, options); err != nil {
		return err
	}
	if err = addInterceptors(stack, options); err != nil {
		return err
	}
	return nil
}

type idempotencyToken_initializeOpBatchPutAttributesMetadata struct {
	tokenProvider IdempotencyTokenProvider
}

func (*idempotencyToken_initializeOpBatchPutAttributesMetadata) ID() string {
	return "OperationIdempotencyTokenAutoFill"
}

func (m *idempotencyToken_initializeOpBatchPutAttributesMetadata) HandleInitialize(ctx context.Context, in middleware.InitializeInput, next middleware.InitializeHandler) (
	out middleware.InitializeOutput, metadata middleware.Metadata, err error,
) {
	if m.tokenProvider == nil {
		return next.HandleInitialize(ctx, in)
	}

	input, ok := in.Parameters.(*BatchPutAttributesMetadataInput)
	if !ok {
		return out, metadata, fmt.Errorf("expected middleware input to be of type *BatchPutAttributesMetadataInput ")
	}

	if input.ClientToken == nil {
		t, err := m.tokenProvider.GetIdempotencyToken()
		if err != nil {
			return out, metadata, err
		}
		input.ClientToken = &t
	}
	return next.HandleInitialize(ctx, in)
}
func addIdempotencyToken_opBatchPutAttributesMetadataMiddleware(stack *middleware.Stack, cfg Options) error {
	return stack.Initialize.Add(&idempotencyToken_initializeOpBatchPutAttributesMetadata{tokenProvider: cfg.IdempotencyTokenProvider}, middleware.Before)
}
